(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    511657,       9375]
NotebookOptionsPosition[    502989,       9092]
NotebookOutlinePosition[    505343,       9148]
CellTagsIndexPosition[    505256,       9143]
WindowTitle->Interpolation, Method -> Voronoi - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[" ", "SymbolColorBar",
 CellMargins->{{Inherited, Inherited}, {-5, 0}}],

Cell[TextData[{
 ButtonBox["Mathematica",
  BaseStyle->{"Link", "LinkTrail"},
  ButtonData->"paclet:Obtuse/guide/Obtuse"],
 StyleBox[" > ", "LinkTrailSeparator"]
}], "LinkTrail"],

Cell[BoxData[GridBox[{
   {Cell["OBTUSE PACLET SYMBOL", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"Tutorials \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"Scattered Point Interpolation\"\>":>
       Documentation`HelpLookup[
       "paclet:Obtuse/tutorial/Scattered Point Interpolation"], \
"\<\"Interpolation interactive demo\"\>":>Documentation`HelpLookup[
       "paclet:Obtuse/tutorial/Interpolation interactive demo"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"See Also \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"Interpolation\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/Interpolation"], "\<\"Interpolation, Method -> \
\\\"ObtuseAngle\\\"\"\>":>Documentation`HelpLookup[
       "paclet:Obtuse/ref/InterpolationMethodObtuseAngle"], \
"\<\"Interpolation, Method -> \\\"Delaunay\\\"\"\>":>Documentation`HelpLookup[
       "paclet:Obtuse/ref/InterpolationMethodDelaunay"], "\<\"Interpolation, \
Method -> \\\"RBF\\\"\"\>":>Documentation`HelpLookup[
       "paclet:Obtuse/ref/InterpolationMethodRBF"], "\<\"Interpolation, \
Method -> \\\"Shepard\\\"\"\>":>Documentation`HelpLookup[
       "paclet:Obtuse/ref/InterpolationMethodShepard"], \
"\<\"DirectedDistanceMatrix\"\>":>Documentation`HelpLookup[
       "paclet:Obtuse/ref/DirectedDistanceMatrix"], "\<\"DistanceMatrix\"\>":>
       Documentation`HelpLookup[
       "paclet:HierarchicalClustering/ref/DistanceMatrix"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"More About \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"Obtuse Package\"\>":>
       Documentation`HelpLookup["paclet:Obtuse/guide/ObtusePackage"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"URL \[RightGuillemet]\"\>",
        StripOnInput->
         False], {"\<\"Obtuse/ref/InterpolationMethodVoronoi\"\>":>
       None, "\<\"Copy Mathematica url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["Obtuse/ref/InterpolationMethodVoronoi"]}, Visible -> 
            False]]; SelectionMove[
         DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://www.familydahl.se/mathematica/Obtuse/ref/\
InterpolationMethodVoronoi.html"], StandardForm]], "Input", TextClipboardType -> 
              "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web url\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://www.familydahl.se/mathematica/", 
             "Obtuse/ref/InterpolationMethodVoronoi", ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell["Interpolation, Method -> \"Voronoi\"", "ObjectName",
 CellID->1224892054],

Cell[BoxData[GridBox[{
   {"", Cell[TextData[{
     Cell[BoxData[
      RowBox[{
       RowBox[{"Interpolation", "[", 
        StyleBox[
         RowBox[{"funcvaluelist", ",", 
          RowBox[{"Method", "\[Rule]", "\"\<\!\(\*
StyleBox[\(\*
StyleBox[\"Vo\", \"TI\",
FontSlant->\"Italic\"]ro\*
StyleBox[
StyleBox[\"n\", \"TI\",
FontSlant->\"Italic\"], \"TI\",
FontSlant->\"Italic\"]oi\)]\)\>\""}], ",", 
          RowBox[{"(", "options", ")"}]}], "TI",
         FontSlant->"Italic"], "]"}], "[", 
       StyleBox["x", "TI"], "]"}]], "InlineFormula"],
     ", where ",
     StyleBox["funcvaluelist", "TI",
      FontSlant->"Italic"],
     " is a list of scattered control points together with the function \
values in these points, returns the function value of the nearest control \
point to ",
     StyleBox["x", "TI"],
     ". The function is thus constant in regions. \n\tIf two control points \
are at the same minimum distance, the function value of the first is \
returned. "
    }]]}
  }]], "Usage",
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, "Rows" -> {{None}}, 
   "RowsIndexed" -> {}}},
 CellID->982511436]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
 ButtonBox[
  FrameBox[
   StyleBox[
    RowBox[{"MORE", " ", "INFORMATION"}], "NotesFrameText"],
   StripOnInput->False],
  Appearance->{Automatic, None},
  BaseStyle->None,
  ButtonFunction:>(FrontEndExecute[{
     FrontEnd`SelectionMove[
      FrontEnd`SelectedNotebook[], All, ButtonCell], 
     FrontEndToken["OpenCloseGroup"], 
     FrontEnd`SelectionMove[
      FrontEnd`SelectedNotebook[], After, CellContents]}]& ),
  Evaluator->None,
  Method->"Preemptive"]]]], "NotesSection",
 CellGroupingRules->{"SectionGrouping", 50},
 CellID->230136585],

Cell[TextData[{
 "To use ",
 Cell[BoxData[
  RowBox[{"Interpolation", ",", 
   RowBox[{"Method", "\[Rule]", "\"\<Voronoi\>\""}]}]], "InlineFormula"],
 ", you first need to load the ",
 ButtonBox["Obtuse Package",
  BaseStyle->"Link",
  ButtonData->"paclet:Obtuse/guide/ObtusePackage"],
 " using ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["Needs",
    BaseStyle->"Link",
    ButtonData->"paclet:ref/Needs"], "[", "\"\<Obtuse`\>\"", "]"}]], 
  "InlineFormula"],
 "."
}], "Notes",
 CellID->1067943069],

Cell["The following options can be given:", "Notes",
 CellID->283978029],

Cell[BoxData[GridBox[{
   {Cell["      ", "TableRowIcon"], 
    ButtonBox["DistanceFunction",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/DistanceFunction"], 
    ButtonBox["Automatic",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/Automatic"], Cell["\<\
distance function to use in calculation of the distance matrix and the \
calculation of the distance from the interpolation point to the control \
points. Note, that the function here is expected to return the square of the \
distance\
\>", "TableText"]}
  },
  GridBoxAlignment->{
   "Columns" -> {Left, Left, {Left}}, "ColumnsIndexed" -> {}, 
    "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}]], "3ColumnTableMod",
 Editable->True,
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, "Rows" -> {{None}}, 
   "RowsIndexed" -> {}},
 GridBoxDividers->{"Rows" -> {{True, True}}}}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["EXAMPLES",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->462255656],

Cell[CellGroupData[{

Cell[TextData[{
 "Basic Examples",
 "\[NonBreakingSpace]\[NonBreakingSpace]",
 Cell["(1)", "ExampleCount"]
}], "ExampleSection",
 CellID->527923314],

Cell[BoxData[
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Obtuse`\>\"", "]"}], ";"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->139566013],

Cell["Some 2D points: ", "ExampleText",
 Editable->True,
 CellID->65039657],

Cell[BoxData[
 RowBox[{
  RowBox[{"cpts", "=", 
   RowBox[{"RandomReal", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"100", ",", "2"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[2]:=",
 CellID->614368519],

Cell["Add function values to the 2D point table: ", "ExampleText",
 Editable->True,
 CellID->472343579],

Cell[BoxData[
 RowBox[{
  RowBox[{"cptab", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"cpts", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"cpts", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "2"}], "]"}], "]"}], "]"}], "*", 
        RowBox[{"Sin", "[", 
         RowBox[{"cpts", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "1"}], "]"}], "]"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", 
       RowBox[{"Length", "[", "cpts", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellLabel->"In[3]:=",
 CellID->27569007],

Cell["Test interpolation in one point: ", "ExampleText",
 Editable->True,
 CellID->111279482],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Interpolation", "[", 
   RowBox[{"cptab", ",", 
    RowBox[{"Method", "\[Rule]", "\"\<Voronoi\>\""}]}], "]"}], "[", 
  RowBox[{"{", 
   RowBox[{"1.5", ",", "0.2"}], "}"}], "]"}]], "Input",
 CellLabel->"In[4]:=",
 CellID->213125124],

Cell[BoxData["0.2919105081888453`"], "Output",
 ImageSize->{60, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[4]=",
 CellID->321014514]
}, Open  ]],

Cell["Check with the original function in the same point: ", "ExampleText",
 Editable->True,
 CellID->96612022],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Sin", "[", "0.2", "]"}], "*", 
  RowBox[{"Sin", "[", "1.5", "]"}]}]], "Input",
 CellLabel->"In[5]:=",
 CellID->133901027],

Cell[BoxData["0.19817166146005605`"], "Output",
 ImageSize->{60, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[5]=",
 CellID->378076224]
}, Open  ]],

Cell["\<\
If the same interpolation should be used in many different points, the \
function can be precompiled without specifying in which point it will be \
used. Not very much time is gained by this, in this case.\
\>", "ExampleText",
 Editable->True,
 CellID->163562336],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"func", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"cptab", ",", 
     RowBox[{"Method", "->", "\"\<Voronoi\>\""}]}], "]"}]}], ";", 
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"ContourPlot", "[", 
     RowBox[{
      RowBox[{"func", "[", 
       RowBox[{"{", 
        RowBox[{"x", ",", "y"}], "}"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", 
        RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "1"}], "}"}]}], ",", 
      RowBox[{"ImageSize", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"400", ",", "400"}], "}"}]}]}], "]"}], ",", 
    RowBox[{"ListPlot", "[", "cpts", "]"}]}], "]"}]}]], "Input",
 CellLabel->"In[6]:=",
 CellID->187990255],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJyUvXe8VNX1/j9ze7935jYisWM0GvtHLETnYIvYYiUqsXcjBpWoiUnsBbsY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    "], {{{}, 
      {RGBColor[0.293416, 0.0574044, 0.529412], EdgeForm[None], 
       GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFmH1s1tUVx29LoZS+8NI+0NKW2tLWPs8DtLaV4gRbZoTAQtyIhq3QLSFG
ibAxE8te7BShGerEStEsm2JGQVzMNtDNLAplRo0BnPGfvajbmNkfE9C9u2WZ
VPb99HsIfzT3Pvd377nn5Xu+59w2bt6+/iuFKaUnClKaovG5spQOV2ii8VKp
x+PasDZ+31dw5du/Nb04P6UJ/b2iPU2LUrqpOKUNDSmdmx/ftKdA4wX9Jf3l
p6b0wsyU3tRl5+Mse8/HHuSMFfks83M1Kb2vv1PzUvrjrJTKNZ+ps0f1e9Zc
yzs2z7+rpdMu7VkxI6XlWr843eNeri71d+59qcpyzmrvsGz9m9Yrp3mtIuSv
qrHsbOjL/D+SM1t39kh+Tr+PV3k/8ibCBnT+7CyfYT9+aiiz386WWw90uNgl
naXfzxqtB7b9WDrsy0hnyaycLT/orq9Xp3RQY7X21urskO690GOd72lNqUr7
dsT+iem2H5vvmeK9t0iH+hJ/Yx0/IvPX8vEHkvOk7vtQ43uhw8yICzHZWeCY
nY95b9gCHpB/LuKLL7Dh1mQfIoff2H6k2jh5tyWlj6XDgibf+fsy29A/x3s+
0Xyj5s9Uew0cgjPOEgPuQP6aMv9mjm6cY35Hu23YonFU5x/VX1Wx/fOa4jOm
M5WK9R3a/7H8seGqlH6nPW91yn7h9WntXaX54HUSpvgeWJjSg/mUHtKZBzTu
ulr+0t27NS7utPysxkbJ+7ni+qJsG4l7a+SrY1p7R2dHC4wTMAJuPp91/Hvr
hYESx3WkwLpyfqnisr/WMorbtH9pSid0dlNzStMXWeY0ja2Nxtl3lwhn2t+m
mHyk/ZkK67xPel3U7+Va79SdG6X3b6T/C5I3LlkvSpehDtlbY/zgn9GM8Uf+
nJdPDkunvk7HfXC+MXw64/l4occdMWf8Gjgp9chvzuEXbMMu4gwmiBmcsCfy
ZUj+3SOdd2p8u8U5Oaj5s8XeQ17cmbHcSZkzbEteMgek54D8dmOnfQzuwMqJ
BuOgXesfXGv8Nwh7fw67cvLhQ/LLbsm4X7HOZxwz4jWet84vK79Gcl4/KH/f
KTlrdccWjd9ekNLnFL/vZ+0z8o/8GssaDwezXsO/8M+O8A2+wr+TeVpoLK8J
fiAG+AtfvSGZZzLWLzPbOP6RcLOh1jndXGvOg/uIPbHEL/dqrG8yt/y00X5C
T3wFXx6N/dy5Nu4ll58qMg4nurwf+16W7Z2Kxasan1jovCA/blGMFsFTPY7p
M5Hj2yX7q/OsM9x1aK55Bj5D/8rgKubYSh5y76uF5mZ0g2fxI3vxG3mJXPyG
P7aHfOJcON+5D5+NxV2n9f3MPPN5lXTvL3ee4Q/24Ie7a8ypyAeL+AI51C3q
17OK++st5oqj11k+vMmZddekdLPkPS0fb5b9y6XT7RrH5aMO3feLnHmN2oMO
3Hkw7v2i8m5c+Olf6jVkogM17nToDEcyx5asZF/SXYeKHBNsQM6jpV6biPpC
HLGD3ARPxBSfPhV73igxNvJRV8di/fV6+5I8gI/gpe8t9v6R4LGGqPVwPvW5
IHKW9d7oB/ARvnpNPuvTuFJ/q5LtOBe1mxrOHBvJY/KZfGDsi/3kxO7IC77t
inyBp9+L2jRS6v3o848WnzvcZh6l3oFhfE/NA0fEejD4jfHuyMfrlymPJeel
WseCdfIOzmEdH4FP7ELmZRs4Sx7lojdgP3vxyZeFg/Xav6/FPlgfdqHP+2H7
O+LrYdnytsZDy6z3yatco6gl6PlJhe3Exm26a+tc8/lYxP5yT5UC/3xfnPE3
cJCiXn+m0z7cVWe/DodvOVsYvJqpuCK7MOKLzH92mDP/1eGzxIbf1G18i03k
Kn0Sfc6O8DN52xi8jy1gkj2TNTxjTNeVmgPgBTiNvF5d473UoBU15lTOrQ75
+I878T/nVsRZcpGcIV+o3/DF3xuMvVORRxPRi9KvkN8nCs2h6IE+5BK1jPvB
M7xF3pJv9MLPRy8C7nojLuQ4vkAn+hZ6FuRSJ6gXj2WNS+Kfcs5j7qK+PNhm
XnpY46kW4w08HgouJL736veAcvZTzT6Xi7OLYo7u+A2dyZHfLnGcPlRtejxr
Hahd6A6e0JkaCx7IrR9I/ojkX6qLvJlhn9C7vTvH2ACD36iw3Ut0T0fce8OM
6LGDY8gTcgTfHg7/ojvr2DO80HGhz/pC8DH7U4V5Cb4Bw2D9W1PMCVuDHx4O
Xx1pMCexd2lwOPhiTk04k7lSI6idYOYPysf9mg+0Wt62kAmmzsQe4kbOkC/0
SdjUnrUP6PfwA/tXBT73RI6wDiaej364KOd8f1zxLGwzd9LHURMei57qQNTQ
k/r+vya/B6br3G2K2Rrl/+0aS662zPsUl83a+5My+xD/k+P4h3FJxIKcXxwY
xu/Ygy3UQHKA3OjrcexulW439FhGec72bS03h1HDwTF1nHFTzFk/Ej05uMsH
DnkHzYm30M4Ox/K2nNfhR3oMxtnBlb3Ntud+4W5vnfEBxv+adY9Cf9oa70fe
kdTV9VFLPspZ56mqUb+6xrr1N5i3iT91jT6MGnmkyTx2Nt5T2Ih9zPHT1sDY
lujltl1rzA5E/s4JndH/rbzz4pvN7q0n+yb58L91zo0Dy8ydyCQOhfXmc3id
M5wlz+BJfAEHki/0W+Q4vTV305Pui1jCw7wR76pwTzRU57fQNPnnZPQY9Bp3
Re9BD0KOXp+xr8An9lKPvtTj9U09jjM8wzcwOLfCnETd6cqYs8lr5INV4sN7
iRzmndFb6Tftd7o8f6DLuB4NbPPuGYk314V4M6Z4BwxG345/wSY8w93gAWyD
CeajdeZ1ZMLtN/ZYt0+HjSuj9pPHk++FUufHQMjZvMC+W6cYnWp333y63W/0
8nin038dj7cYf6xdfsvzzqLHYP/xmN+cdyzW5Z3bYJI6T+zBQHGrcVUXPdlQ
vL3htx/mbMfqvP2Njdhd1Oy7pzWbl+A76sTO6MXxT1/0RviNusU63+n11kS/
B2Y3Bm7hVfpduJV3DrWaGg6GwB+9HXGa/P/CVGOB2g/eOhocN949z3Wn9CfF
91i3Y7E8anF55CC52LTQfSP9I/X3zUrzzPAC/6ZHxheXgv+pk8ikb1jRY+7q
1fiXHr/1ePP1txiDK7U20m2Zj3Qbq8iBc6hd1BF4PtNsvKas8bI/MMP7g3rA
vl+WmJeoGfzvhHwkPvR0+IsYsYfv8DX/m8COvd1+e7OW7/Q7il6A/9m8Em8i
3kaT77R4W8Hf3IW8/wPNncIo
          "]], PolygonBox[CompressedData["
1:eJwtlVlslVUUhZel0pZSwE6gHbDY1su9lF46cFEQRKIGCalUFKwUk4YUoo2C
xgcDKtJGiwYLFUNUHhQLMcZoMRBTLXUiilOIiROK45uCUxRitKDfyubh5D/n
P3tce+19qjrubL0jS9JGVjbr4GXSB5Olf3Olr2qkpayL8qVvC6R/pkmrMtLc
EuneCdLqlLSH8+2cr0H3D2SXsKYgv4H7Fu5PNkvdk6Qz2Dvh/aV8x2O7ENsX
SzuQb0V+HjY2YGt3HTFMlBYUSY82YnS6NH+c1IC9t5PSXcS3nvj25kg9l0jP
cB6cHD7te2CqdDOxruX8LufuaulwsVR8gfRevTSUIN6CiGELsZxNhP15gDDK
/kZ00sQyk3UF8fTisxTfQuZp/L2PjRJsvThGep67Vdgfxv7rrJtmE26DtJ3c
+lnDxLKIczv7AeL9ifMIOU8Bi9E8aRf2NoPRw9jvwt8pfH8yS7qlMHTakd8L
5i3IfkZxciqlzkxgtZD8SsFzIecq9o38W8T+8BzpuVLpZXxUoHsDNlPcJVlz
ud+HzTbyL8bnQ8mIwbH439bEOZv5UeNbkX+zFlliH8LeW+w3sn7jvgf9X7i/
KhO+jbGxPggGn4PtEHgd4tyK//L8wPRKZOunB9Y9cOLYTOqcCazvA8/57LOJ
4SPiufA8KSsRNXPtjPkR9l3Ed11xyFi2viGwdoxpchslvpfw34H/BfhXMrhp
jmWzry6TlnPu4/4o2L+TDG6ZA+bCPvDrAr8dyI/D1lPgU8L9Os5HyOVu9E+j
/yExVyI7Fh8ZdAvRWTYndKz7CDpbsd+bir1t2NZIIrjUT37D9keNluUFZr+C
TQs+yvKDI1kV0j2pwLpoLHhxtxOZwYKoqWubm4ze/Bj8VnKXC0eOY2s39yfA
c0s5Kz84tikVHDVXD7FWE/sD3L+C/AD3B7jfRU2unxQ5Otf+8sDSPeBe+HJm
1M49/QX7ttlhyxhkY+8F8r86JzBeURY97l7/DvlO6pecEb1gmVr2h2uiV4uw
34P9H+jJiWOip1Zi+7WywN496979fWr0vnNaQu1TDcEV91wd+074sfgcPzrY
HweDfrDYyVpNbP+VR+2NsbFej/1TxLoK/U9nRY+4V2awlnPfNjXu3JPuTcfo
WNuxsQ1b96eD6+Lf5nT0lHvLM8izKAefffg6y7828l2MzURWzCzPrgfhRHd2
zDTPtjXJsOUc1jRHzV17z2TP5surw7c5bq6vA9PvwfZr4lsB1vMyEbt7zr3X
2xiz1DWtrYKv4Lt/fOTs3I2RsXJP3dYcNXKtbHMt+2fh1KsFMWPaaoLj5rpz
OI3++RXRu+4Z945nhGeFdfagO5acj00Izj7B+bEmuFoUM60Hrv4FZhXsf+Tf
fu6WpuLt8JvTURk95l4zRtPA6kBVzDb3zBlye7IuuO83w2+HZ6hnqd8kv03m
tLntnDdRr6MNgZU5Zq55pnq2emZ6dvpN89vmmv2N/BvUI31uPpRUR8+6d51T
Lrn9mY63zTk4F3PMXLPOCLrXpuKteJx/3xBPe23szUlzc7ApcnfPundPZqJ3
PWN/Zr+tKd5iY9bXFBwyl9yzecT/Py7ZJ0k=
          "]]}]}, 
      {RGBColor[
       0.36718098824422524`, 0.18566179321500195`, 0.6330976145498944], 
       EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFmHuQ1lUZxw+32AuwLrsLLLG7LOz13X33CryQgBrqrjZigmmakDqWjYhR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          "]], PolygonBox[CompressedData["
1:eJwtmHl0VdUVxg+Q8AIhxEiQKGaeeEleRsLDSiEKQgEBESUQMlhGaxsqiNZC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          "]], 
         PolygonBox[{{8125, 8124, 12847, 3360, 10246}, {10649, 1512, 7814, 
          10650, 10651}, {10646, 10645, 10895, 3608, 9121}, {11994, 11993, 
          11992, 2620, 10545}, {10211, 2016, 8279, 13007, 13008}, {8313, 3456,
           10946, 10944, 10945}}]}]}, 
      {RGBColor[0.4546890376993396, 0.3378146583558852, 0.7561007641711703], 
       EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFnHl4l9WVx1+yEAJhi2RPCAnZCVnISrUWUXCBcatFkE0ERJFFIlZbFQSx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          "]], PolygonBox[CompressedData["
1:eJwtmndgllWWxt8QQhJIgIROElJIvvSQ5EtIUERAIKgsgiICIkVhROqIWJES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          "]], 
         PolygonBox[{{11659, 11658, 7876, 1710, 11657}, {11835, 11834, 7560, 
          1052, 11832}, {10647, 2561, 9121, 10892, 10893}, {14187, 4832, 
          13019, 9606, 9607}, {10379, 10378, 10381, 2279, 7646}, {11330, 
          11329, 10953, 665, 7209}, {7441, 906, 14503, 14504, 14505}, {10587, 
          2445, 8955, 10761, 10762}}]}]}, 
      {RGBColor[0.5421970871544541, 0.4899675234967686, 0.8791039137924462], 
       EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNnHl4VtW1xg9TQgZCEoYMZCLzROAjJCEWrAMyaW9FRWYURIoVEa1IW9AC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          "]], PolygonBox[CompressedData["
1:eJwtmweUVtXVhi9F+tCLwjC9wQxTgRkQCx2MBQtiiRiRIh1RQYOioAZBwK4o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          "]], 
         PolygonBox[{{11420, 11419, 10594, 1036, 7544}, {11301, 11300, 8025, 
          3962, 11561}, {12874, 2541, 9094, 8174, 8175}, {10817, 3571, 10816, 
          7648, 7649}, {14181, 14180, 14184, 5136, 8915}, {10169, 3331, 11204,
           6934, 6935}, {13791, 3522, 10684, 9201, 9202}, {10557, 3239, 9973, 
          8447, 8448}, {9809, 9808, 14789, 6113, 14790}, {10301, 3388, 11934, 
          11930, 11931}, {10312, 10311, 7047, 2498, 10315}, {11305, 3817, 
          11304, 11300, 11301}, {9151, 9150, 10231, 3357, 13738}, {10220, 
          2497, 11256, 11258, 11259}, {10822, 10821, 10820, 1045, 10818}}]}]}, 
      {RGBColor[0.6122610481524358, 0.6053953282651008, 0.9106030282436572], 
       EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNnXd4lVX2tk8qoacRkpOQHkJ6SAIh2EAQFcXys6AjNhSxYcOOgg3sDbti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          "]], PolygonBox[CompressedData["
1:eJwtnHmc19P3xz8V2tdp00yzL00106xNK9KiEEJ2SijaiUpRtkRIiiRJP1sL
IfueLdklFSlFpSwlkuz5PZ/f8/nj9Zg7n/f7fe+5555777lnuVlDxpw8unoi
kbj70ETiEP7e2j6RaNUwkRhWK5GYQXlxfiKx6rBE4qFWiURmF36rSCS+rpFI
rE7hXcrv5iYStRslEj81TSRe7ci3vNOId8dRR2VGIlFenEiUgd486wNmUe7F
+y82SCQ2tEsktqYlEtfWSSSO5v/dbROJIwsSiXfqJRJrqG8hdQ/plEicD47h
vb7gM75ZC66nnhvAizmJxAtgYWUicT/4sXMi0Zy2e7ZMJPZQXkKb26lrBX14
Jz2RyKGNyvqJxP/VTiRa8N1X/N+Vti+ChvupfyxtjQEdMhOJEtCYtgbwfC00
TWidSGTQpxo1eUYf0+jrYGi8jm938vwqaG9PHQtg6OP0MadDIrGrMJH4hPY+
o/3ttN+L397g2ZugN+UheYnEfL5fDv+v4nkGfToe2j6B/prUn1oFT8E8+nYP
OI32BoKT6NcAcBXvl1LXN7TxT3YicXZRIjGX/u+E5gzG7/vyROI78DX4BnSh
rvxmiUSzuolEZ8qd4UEnsIh6/g88zPcPgbZZiUQ78DRtjoV/l4J3eW82/59P
OQMZeJz/fy5NJPaCo+h3D3AL/LmX9vfDoxvg36nQegroC639wBXQ2Jb+jaC/
n/LupbT1f7z/F/T25PtyaMqFvhToy6H8KzzdB2ZTxxxQoySRGIVsjgTVKDek
jUNpK785Msu49bMt8Ctyux/8Dg6AibR7Jfi3MsamnG/+pLyR8e9C24MZg1m0
v5X/t4CnKD8NxjAmD0HrBuWZfq5DHlLhdU/quB1+9eO3r3l+JP8fS3kn334L
vgc/gBxoPLZxInEcyKO8ATxH+Vkm2z7kaV+bROIXUA2aq4NU5OEfaGkLTXXo
fxbvZ4LWIB204522oCG8bwQmIeNXgo78VgWOKEP+miQS94Ev4O+30LgDVPCs
MjfmmHPtVvi7if6lgDvp24e8/wjfbkqFZtqvDj97ws/hPL8kLeaEc+Nk6hgA
TmAsTwQ30fZ0cCe/3SUNfN8RDAKDwfXw61raOgR5mUp5H336BfwO/gB1aHMS
bU8G90JvZ+pcinw9CrpT3zK+WQpmMg63g3/py1jGrgljcJDyNt5PIC8boflL
yvN4927QlHebgUuRnbHgMmRgHFhBX55MizF2rIcwBzczdl+BCykPRB7vgB8L
wUjKDzIeD4AF4D5wOTwYB0ZRx2jnOm3dAz+7834R7d1UEWvje6AR8taSOluA
ViAV7KCOTNrqAP3ZjPul0DQWXEZfxoETQH+QxbqRDY7k2S/07asWrBnw+W3k
fTFtPQImQt8weNSb9m/mnRGUv4W2Txk7F/XPoGcUv/Xh+S08v5Ty3awJp7G2
DAT7qK8DMjWNuVTEGJVQ/gYc4P9V0H8DfRlAGyeB/uAEMI4+H6DuCtoYT1tb
6NNXYJN8BFfIM2ibh4y/inyfDn/m09djqXMg5dc6xl5RCx7cQj8n08YkcAUY
D/ohDw8ri2Av8jCKOn6rETTvh97V9H8p9S8B10gXMtSJ8a/BfJoMb3d3jrW/
MfWX8e0A17i68c7AqqBZ2kciQ3t5/yxoPgXeLOKb//j26NzYC1bxfT+evUZ/
X02LOe3cPpY272Wtv4XvV0LfHfzfnb49CT1zKN9WHGvBp4jlsch/GSgFB3n3
P3CQNv4FT/Hu0+ANaHwdHOC330F1ZLUa+ICx/xA8yRo12rWX/q1ivnel/1vY
S6row0TnJHUsou3/oOkpvutMXavhV1/685O8oO0VidhjbqNvnenTC9C3CPo7
dYg569ydBe4An/FN45axJrg23Eh/prnPUvdLBSHzyv6byPZbYCV7yubaIUOj
2S/GIT9TGPupYDzlldDzJPy/Axm8g/H/gz7l1I019QDl2tRRC1TRbicwivIe
ZO9H8BLycAHyOgRcwVwZD/4GU5CnIxnPmxi/3xjT/eBf2jkI5lHnCp63oL1F
ObEGuBa8B6/e7xRz0rm5mHeu5N1HoPlhsJs+7gGLqP9+MJU2rwGX8WwvtGYz
/wqgrzNj2AmkwffW4Ja20dZDjM8bfHcfbfU5LPqwEvq38ts42uoIj6bQdle+
GejeCH97UG5InQ3AWYzr2eAvxutPcCHli8Bu+833J8Kzrvxezrtl4AB0/Q66
Ue4KWlL34WAuv90F+jBWx4BDqKMGmMuY3Q06gvsbhswoOy/Ak1uQpVnQvx7+
TeSbCeAT+r4GjObbUWAD8/LzslgTXRsdgz+grQX9bZ4ea65rr3POuecYn8P4
bEN+r0d+j0Qmf2c8bqDO60El73UEP1D3DOr6AHzBeEwqjLFJh6ef8X4l60UF
WE/fNoCOPK8E3eBFd1Afma0HfqaeX0B73r2f9v4PFPP7OH67DHwK7WtBU+pI
yQ6eybvj2sdcliej6du/7OHjWHuGqR9Q7s07vRx3vukC8uFfHtgFj74DCfjX
hrm3FHmsRfktxvwnxn4P9dWlfz+yfv8AdoM9IB8Z+5Nn9eFRZ8pd6UsXUEpb
ZeDailh776HOD3g/izbLGZtuyN9R0LGLNnYwXuuRsW/h+9/UMZe6RkPzn5QT
4GT41xx568O3DcpDF7ioGm1SrgbtCTCQek4DHzKGH4A14FPwFW1sBnvhxc+g
CTxmeiUep3913PuQrfbUlQs9beQhPJ3XJPaELpQP6xS8WMb4TYP+T2lzEvRv
Yn1YS/no1Fj7n+edCyn3pe/HgKG0PQwcQbk7SNBONTAV+TmdsbyZOm5FHr7j
ncvrh46irqLOp+73Ke2fRb+OKIq55R7uXt6S31qA83hvEOgCzzqDI5HVo8CH
8Px06N8Fz5+B97czt2e6riMzs8Em1rDfoL0l/NxCeQ/tT6T9LNrfSPvdqKMr
yEPW88HT1P0U+Iw61oH+tFkf+qZTx7/Qn08bD9HWw+AL+vc931zJXGnIOyfy
bkFJ6Ip383wNz0+GhwPAO+594IW00K3PgZ5XGd8cvs/OCxqkpTHrUSPQiXJn
0I41fkWjOJOU8O0saLgdHIOc9AWfUucPDWLNX095K/y+Bn7XYM17mXH4gN/e
B5dAw3BwI3V8QfsX0P6q7OCpvJ1DX+/MCJ3u9+Sa7No8mDZy3evp47mU7+Dd
WeBj6vkEnKE+ztj2os2zKRdB8xDoOQRcTD86MwadMkNHVlcuhIY2YCU0vQ7G
McYPNAydQ91jDW3ejGzdAvrz3iW5oRs9yXy6kva2KfPwegvr0SeM09HQ1AMM
goeDwR71V94/hTG+mvbW8v2n4HPwBfib+v9yvwEHwQbaXE/bsxmvNxmvj6nj
1Zqx5m/n+6bQ/lrNOOPOZ35s5rdNYAP4HJyoLp0bZ2TPyrtyQrZ+hicF8Pdl
np0GLyaB8+HNXvrwU1rMUefqHNqcDTYyt74sD51C3WImv90ONhfG2lrFeLVh
vcoGhcjia9A7BFl8kf7+y7MX+H8A/1+kDntotJnWLvYM9w7XCNeKqUWhe73k
/pUVMqvs5iJf+6irBjxZh/zupo7qlO+kP3PAdMb2Js9btPEbbb3NeJS7V0Bf
I1AP1AeLeH4/+Av8Db6njc9rxZh04f8boOF691lkbSF4gTq+4Hkd8DC8bsk7
86n/XrCWb5fwfDFojiy08AzAGLzgeqhNALoOLwpbxXbwJ+VV9PUvxms16+vn
8GIuY3Ii8vsLS1Ip7faEf0eDFM8YYAdtrKXtuXzzAfS05LcW4EL6chG4g/be
bxRn1FmUX2RMXwBPghXZocOpy/0O/ybQ9tW8c1VZrNGu1Qc8I1J/NviC/o2k
fyPAWHApeBD6HtCmAm29wTp4PIm+fYf8bKV/p1TE2H7H9ye6t2TFWVaZVXZ3
Uv+34BHWwcXgCr65jXd3Mn/Koe01ZOxVcDi8a5Ufc8C5cBu/zXTtoI5N1PUp
4zmCeh4HbzNWW5CpYdS1jTq/Aen0JcPzNbR+h2z1gR9bPD/zTl+QQ1u54E5o
/My1j/qGUdeHlXFWn0Cf1lD+jvY+qhVt7i4KGqV1IHvSMuRvBm3UYm5vhOeD
O0Sd1j2DZ7eAB9APvqKureAZz8vwrDu4F1oWgO18v1PdSP23KHRSddMajNUh
6qbtYm/dhHz8SDmFupuAbTzbDrKqQrYbsd51Zy1YQpvHQNt2aCzlvTNZ0/a6
dzDeAynfxG/TO4XNQtuFe65771j0kkvBYzybgHysYT71Zez6QWtfcBw4HlTC
r4qKWBNcG96mjrfAy/TzFbCAdx6FH13g2X2uOfCkR+2Yg5v47iZ+mw5eg9aV
oA5jURtsRMa/BGfz/vpGcUbyrFSADDxB366mP69VxZrp2nke7w4CXRjrzqWx
prq2joZHo8A19PVasBra3gEvQNuLHcPGqK3xFfj9GP2uDTLh13D1J8rLiuKZ
OpO60+P8/2rDsFEeg3wsZ2we6xxndM/q2kS0jVzCb8NdI+H/ZXVDZ1B32Mw3
n9GXQ+l/c9bLFPrUBDQADT3DQtsm8Aa0vQlW0+Yo909oesu9gTGuzA6dUN3w
FsozwHp4uQHksgaMZ/reCY8P8nsxKMqONc217Vza+Jz6ToOGcyh3Kw5d8HP+
Pw3+/ZMXe+VSZOg8ns2BP5Phz+v0dwV9/yczxlIdRF3kUdaoe5HFt5GRzcjK
emhfp80NWTjVc6v/U3cO31cVh01P294i7W7gVHhwCjgbnAO6M0b3HxLfHEF5
Ln1uRd/XMd6F1N88J2ynp/I8m+cX0n4p/58HPXOgZxftbeDZPv7PZ9xnF8XZ
+ClwF+VdJaFLaWPYQflmvi+jv9v4bQJ1z+Wdfjx7RhtCUegY6hobWQNuoj/7
4OEvyTXQtdA6rbuY8RwJ/T9A7z/VQudS91qtPRnczLjMAJOQ359oL5U5caf7
KDy50fFgPtbyjFQUbe9jD5sEbdczRteBG8F08DbPn4e+j3nn/aJYc1x7LuP/
FkWhk6mb/Qa9L1Hf6qJ4dzJtrE+NM7NnZ21q2tZWwMOKGiGjT1N+nTZXpoeN
QFvBZ7yzVhsdfblL/ZA1cBV1t2T9KqT8fU7Y6tSH91D+gr4upP3fkYl6GbFH
uFcMBcPATOTrNtDQs7BnP/o0A8wEt4MJYDy4DIzrEDqiumI/5vqxYCzogSz0
BPOo56HM2Hu/RV4nu2ZQ58rmIbMj4PXqtrEW9mb9WkW5PCN4pY9AX0E5c6wM
dARVHcOmf33S5qDt4RBk9Sjqek+dEz5UuOaDjqBKOzWY3DD2lI3wbT//b+X/
+dDzL/y+g/k+q3V847f1aeMjxuJM6qtNuRdj0RNMoq+TQXX6VA3cAe9ngyeL
Yu6l880Z0LOJ/r1J/36kP9PTw0ahrWI3uIR6DnqGBBuZt1+CM/ktt3bsKe4t
A/jmJPCg5wDQEJ7dAH+WwY9s+NGHOVNH2zz192oXZ1zPuu4x7jVPqqtCyxfU
+XhxjKFjqc1V2+ve7DgbvsT4HM7vNyqjtP0t8tyadXk5bT5WETYnbU/uSe5N
t8DjccjPBYzP1bx/FWjHtzfyfFqnsJlqO81B5rIr48zq2XVkfuh68kTepMDT
JiCTdSAL9GT8Xk7a69QdT6aOF6tHG13gdweeF4MdzN1vwd9FoYvdBb1H0Zef
wWbqfx0a06j/nLTYOx3DU/h+EX3eBC8G8/9T8ONs+nAWGAeNl1eGTVHbYonr
FJhNfT2Ybz/TRmvlmu/fYL1+k/pb62ui/ndrhswpe/90DN1jMd/8QXlDZuhi
bVnfWrHebWQ+fAEGwofTwD3UPy875qxz9xreGcn6cD5jei3l7YzpOQ3DR3Vt
+ziDehY9EtqOAm2RvULQkjoPd75B4xgw0n2oOM7Unq3fQ76PL4gzlGcp27Rt
z6yeXT1jedZ62v2ZtmvzzUzqm8GaOx3eHsEav0i7IzQMgpZ3ef4tdGyBZ1Ob
xhlwH3x8nd9WauOGtvnKOzQMpr6L4PfLlM91/eP/U8F82nqJOd4TXmXw/Cx1
KtroRls30OY02v4PmTgI5vP7veCE1nEWU8dR18mmjd9Zy9agoy8vizniXCml
b2VgFrTMgta7qe8Vvn2C9vL4fx9tpKbHmdezr2diz8ZtQAFoQt9TqsJmp+0u
jX63bh9j7thr4/uF+gcj04PAOeDcwvA56nvU56LvZR/fnAW/3qTNre3Cx6Gv
437aWASuoo3J4BHKi0ExMvMAvFzCnHwZ+hbQl3srQidQN7ilMnxZm6jvNsoX
w6Mr6dtyfrvc9vPCV/d4C9pgPboPWi6sEz5LfZeLef8RsBQsK4kzk2enA+B3
UAtaGjQLn9IhlDsgP4/UDpuftj9tstpm1eleg5/nIvMTabsHNDShviXIwGLw
DrK7uk34xPSNqbOqu35H3zvUCZvZ36wvzfNibVoCvfd2Dp1I3aiTtmkwxzkI
nqHvz4Lz6HOfpuFTTWPtuQf+vtEgeLyf8hT9A/XCBlMvO2y42nK70I+u4Ffo
3ZcVNlFto1eWhO1Zm5m2s+3UMaBh7AnuDa21H9HXKtrrS3tP0v9FDcKnl8n/
r/H/o/y/jjZPh97nGYNdzN9xfPNiYewJ7g3KsLI8pU3Y1pxjUyk3ov/PIc+P
0P97eG8CMjwe1HafBMfS3670dzn0VcLXY6nzy7qh8/aivA16nzksaN5BeRz1
/cD69Cr1Le4cPkp9lc/B71FlsSa6NrqG9WUsPuT/DzqFTVbbrDYSbSXt4FV7
8Ca/vQGGMlbDwHH0d0yDoOE4fp/EnC1m7u7m//G837JT2Ore4Z0WlI+CpjLG
dyr8O7J92BC1JWqD1RY7lDV8Cs97MF6HMi4LGIO+tcOn3x35Gk79lyTXNNc2
fVj6smqyf76RGXPIuaROr24/Krn2vc+3H4DnK8MXnQZNHfPiTOTZSJ/5A7TV
nz40qRt9sm/qxOrGn0DPwpLwsehrcY92rz7AGKziWU3q+M1zKPRng4+g5WOw
gG9Ope6PeWc+5fWM0brCsGlo2+jPb4OQt8HgRMprmWN9E2GDWuf6LX/B69D6
BpiVHbx5lPYuUw9gPB9IC5u0tun3XbOMr2C8V3QOG4K2hAXw+j7wHN88C4Yw
dheAS1hfLgYjwSjwN9/f3CBsboPg2yOFQbtn0Ico30tb0+DPTdpn9WUXx154
CBhE/d9Aw9fZsce713emT6vqhE2givKPeaHLrWb891DOqwxd1DPmd65n/DYj
qWOqa57N/H0C3uxCps+kfBYydSZYo5+yU/g89X1eAcYXh41TW+cGePc5eCg1
bAl5zM9GbUKnUbfRp6VvyzOrZ1fPmJ41DyZtc/qY9TU/lhpni3y+b9om9mj3
6i95tqkqbELahrRxaOvozNgfjiy2AjsZ/yJjOkAZKAfL6eNjYA28/LQwdEJ1
wxz4+Rjr8XN5sdfX1d9F/SWMUQdQBIrBtrzYGw+D3xfD7xraVOHvx4z3c64X
/F/E8/ZgAnWfQp9OBhMZ8yvBK3x/IfU3ov6r9V/zzfmdw6akbaknz4/OC5u3
tu/9/PZrdvzms43w7xX9w4zhudQ3nD5eAmoyt2qBp+HXBdTfRh8C/CrmmyLw
MOP8iPoU31yRHjRJ28u8f2e1oHki9E6grYG1og3bqtYxdG1t0IdS/gwZerpx
2Hy/bx0+BX0L+syWp4fPSd+Te4R7RRt4XFAYMqPsjOC3+w+NM4Znjc3U+R/y
94H6UOvQEdQV3GPda12DXYv1oTfJC5+QvqF68G88/KvvmEDPN4z38X7L8web
RkzAkOQZyLPQYni0JDN8QPqC1OHV5Q+BhiXNwgekL2gddW6DvhJ4uIHyq9D8
CjgMuaoJzusQtil1gg60tZn2NzmP2XuGZ4SOqq6qT1TfaB/q2M9YvIAMl7He
rEEG96P/LuL7IvpelzrrlMcZzrNcW35baOwU+8NGY5V4Vh08Cu2PgWv4bWpG
2Ny0vb2HjGbDi7fcE6HzatbTYfBiKHid76bC0ynaB2l3MRjB8+HgRZ69BIpy
gxZ9bvre5tPGgSZx5jkb+utnxFl0HjKwme/vYQx61Is91r1Wm7C2YX0S+ib+
4JvfwVDGbRg4g/pPBydT9ymgEW02VzeHvqaUm5RH+TDnLOXj+aZ/i/BZnZsd
ZxDPIul8mwGqGXPSLGLajG27APm9j3evhqaH+f/B/Ch7BsjPjJgaY2umQeON
YHhhjEU1ZP5iyln0r2m90CHUJe5LxoroI9BXcBVjOxmMBZeCibwzrUH4fPT9
uOe596njzKPti3k+tUHIuLJe2DFsLY5pu47h09e335L1Y5v+Y+Z4A9CcZy3A
g/T5BG39jMHWitCR1JVeAC/mx57m3pYPrwrAWn2jmbHnufepk6ib9OH7l6D3
8IwoawN7h/n9D33+uzBiPoz96Moa0QXsMNYI5GWEbUUbmLYw27CtKYz9VPAs
9T8D5sPLe9V9qWMXvN6pD5PykrQo76PNH8oihspYKn0k+krmO8YpEQNmLNjZ
6mDwpwc8G0j/61N3PWPa3LsqI6bH2J6GPJ9MPfOqQpe7ABlYkLRpaNvoDfpU
hQ1EW8g+6PjV8y59yM6IGDRj0ZzDhyXnnHOvLc8KwWzqngMaMFd+bxQ+YH3B
B/nmX/AH+BN8lBG+gunQ/Fta6Ozq7m9pNwc7i+Isro1bW/eR1HEE6AGOBnXg
dU79sAEsQHZ7gCn1IkbAWIE9jNlusA/8Ch6zv80iRshYoR3tQpfzDOpZdLb2
Heoqgt93UH4LGt8EK8Hr4OmCiC0xhnEmsnUXvGldK/o4j3I/5ZH5tpc+nZ4d
MUDGAm0EX4Jr4FFneHGyNsvyiCExlqQFdLcEe3inHetvW/Aj5b+Q+T/BA9D+
IFgG/TPrRh8ep3wWa8+EWnFGWUx9g5CR88D5YAh4ht/OoL1dyODTlL+wvnph
I9JWNE77U0b00b5eDXbVixhPYz0943rW/QUZ31cYMZ3Gdr7DeH0E/45jjI4F
/0LrwQ5h89L2tRF6dkNbIX3qlwgf6cz88Nnru9dmmAt/UpHNBfS1yJgI5PMG
aOwGvUeAbL5/tiJ80R2MeUr6iPQVnUs954E05upb1D2Z7z+vDB1CXcKYMmPL
NvHbFJ6dxnj2pp8r3C9Z62bT/gbe3U/71zaNM75n/W05UZc+I31Hh4EaTcPn
dgjlH5Rh6BnDmrAMOj6mv/yc6M5vN7q36LOk/e/BRTxfyBgNZawuBjuh5wA8
uoC6evP+HN7/kHdG1A6dsiEVXUn7O/i/JvyfmBM8kBeeGRbybh4yXVo/bLra
dgciE6eCM8CZpWGT1jatDbWWfvvyaCuLPpRVRsyQsUP6GPU1phrHVC90ZHXl
3RXhy7GPP1H+km8y6wQPN1vOir46Ro7VLfBzRnrEFBpbaEyWsVkn8nwhz3ul
h+1uDN8/xff/x28DUiIm6lT9pVnxbnf+b8i87+0aUC9iYI2FPYnnl8Ovy/j+
Zb4/E/59ZjwZ49ktM2z62vYPJGNb+xeErWAr/T8RuVzGs2frhQ2xnP49Sh3L
KmONcq1aAT0LEzFHnqJ8DDztA25mHGeAKayhNZtGzN1VHUMHVRf1TDiR9mpT
1xeHxTt1KT/EO980jRjr55kff3qmRj6H8P8cnnenP31p6xhwl3t1RpwFtGEs
Z/ymt4uziDZQbaEf5kTfjTk29nhVesRuW+fXyO8Z6gQtwoanLS/VmPOkzVHb
4yXUcTE4BVpPBb1Tw5d7N/I0NDViXI11NWammX5taBjYJGJA+mRETLWx1eoc
6h57krE7xlwbe/0t9GXUCRlZzno/GnpGQ09txmAMz2bQ3zH0dTT4pDx88Pri
11PeABbT/kf05RPae5TyaxVhO1anuywtdBx1HWNsjbWdnB6x4Z5Rz2c8l5bF
tycwJ8Yi12OMySuIGFJjSY/j22M7xpg6tsZcG3t9POjfMWLMjDUrTcYmGhNl
bJQxXsZ6zaQPZzSNmBtjb5Q5Ze9G4wup/wrauhzMNeYrPWKAjQU2xttY78+N
/64ZdVxbGW0en6RJ2oxpMLZhLzg8PWLijY3XZvAs9W4pi71kF21+Tbkx60kj
UF87FuhKHYdWixjh7pSPMb41N2zU2qqrkr4EY8aMHTMmztg4Y8CMBRtE/84D
E6BtYmXkNJjboE9laX7ESBsrrU9C38RHjNnIlIhhNJZxfPKsqg1DW4YxccbG
ncpYDGwTOQ7mOvQAR3eMGGZjmY0x39Q2zryefY1BMhZpcbvwJeyg/iWUh0HD
0PyIuTH2RpuhtkPPJCXUt7UseOOe796fQh/qNY01tX5l6EzqTq4BrgUjqyJW
Uh1rIv3/sDz2Avv0MeV50HR329BR1FVG5QctZaxHS+nvVNafKUkfmL6wdva/
YfjYC4vDZzIp6TPSdzS2LHIDzHG4tCxyHMx1UEe+lrqPLopYwBupo5fxsqyB
M1gLbwa3Uv7OuI+UsLksyY4cCHMhxkJzv6yIYTCW4UXeOV0/RlWcXa7VRkX5
/YKwbVvnzJLYA9wLMnjn9LyI6TW2921wDOX29P0h2vqB+VRC+SB7xKvagvj+
SGMX4PG3yFtf2nw7P2wG2g4Kkrblt5D3WfD2Euo4jv48URTrsTbcEbTfiufV
ed4NGo6Dljs9nzcLH5q+tO6l0dZ+0LU0zvie9fWh60s/wTlUGTka5mrok9Q3
aUz1QGjdy7OfwC9gX2X45PXNuwatUZ/Xv9g2bNLapm9tHbZNz6zVtbcjI1lp
4QPXF/5ZeaxdxuwZu3c7788EF9GXoSVh09a2PZG6rgTv8s7FvH87fe5qPgbj
9Z3xw9BYl/JvfLu/dfg09G0cVhyx2uoMdYrDB6AvQJlX9o0hMJbAmJ0lSZuf
tj998vrmjZExVsY90b2xQdvIfbkC/n+FvBwH2sHvcsawY3rE3Bt73xqkg7P1
p1aPmJwT+P8L9pQ+DUNHWk+5QXHoMsP5/2G+71oRsYsr3LONj6LPo2vHGF6u
rmOMSM2kPYfyhWBBw/jtU/rTrSK+VcdU1xzAmJ6U1GEGJnUYdRlzHMx1UCdU
NzTm6K7iiMkxNudfaDkIvgFroe0u6kwxVopnC0tDZ1Z31iaobdAYRGMR1aHV
pbWRayv/MCu+1Qd0U0nESBkrpQ6+13mMvF4BToGOUyvDZ6LvpLm2sqqwIWhL
cE1wbWiRfNYUNKuKM4RnibnU9zD1f0z9c1PCR3cR8vsWa9ivTUMHVhf+Oj18
N57BPYubw2EuhzadLZQPMiZ76W836nyiNHxiLZM5UeZGGSNprOQJ6tS0dygy
9yzy1x+ZqNYlYjKNzXQPcS/R5q3tWx+7vvZmSdqVUWW1gr6VZ0aOh7ke+rj1
dX9FfTWN/8+Ktcg57lzXp6pv1ZyMyfy/meePpESMp7GeE3k+IWkD0BZgTtP/
cpuos502yrZxFtQGeGFu2Ai0FWyCts1gW+eIJR6ojt0+bJDaIrXJaZvL4J0/
4N9H0PAv/f+ANt8H74DVniXSwxZQAKZTb256xHYao1ed/1vwTnMwhL5fYDwe
v21vHDYxbWO720fbzzMGOyn/rA5jfBjPf/HsYk4COAlZGVAZMcylSZuntk9z
KsytMGfhl/Sw2Wu7t41mPM8sjbqMITGWZBVtdGkYMVKD4c0F9GmINkNk4Rn3
9pxYS/Wh6Eu5nneuM97V3IbcOMN7lldHV1cfqc0qqSOpK5lDZC6RY+LY6EPU
l+ga8Dlt16KtrvzfBRxK+WL62C4lfEA1GduHSkK2jTk09rAM3i1NiTP0yNSI
CTc23DXVtbUmc/o/9rtz+ea4kjjDe5bXZ6fvrl1JyG5/UFgSZ0rPln+Df8DK
4oi1vJf230wNnUvdS5+svtm90PdTeZxJPZvugic7K8NmoO1AG4i2EGO6jO1q
WBSxVcpM/aIYc8feHDNzzT7Oj9gJ11DXUn0m+k7ck3dSXx/9qc0ih7AKPn+P
zvNrvTiTejbd3jpyIbT5ry4JH6K+RM9AnoW2GZOZEjGTOynPrwpbTAH60TOM
4zJ13LzwweqL3VIQuV6uuWuzwwegL2AzdSyBngt4t0J7nv4l7SutI1bc9WV5
Sfjo9dUfijytTA2btrbtfeqb/P8ybfZifIZRx/3ql+Vh+38Efq9KDZ+BvgPP
qMtT40zr2baE33LbRI6TuU76pPVN/wP+BteZ+wYu4fmpjSOm0djG0pKIBfe3
csp1WWvrZESMkrFKl9F+WUqcsX5knPuVhOycA46hfD/vvFwnfOoLCiJGwlgJ
99z6rHd3lUTstO/MLgkblrYsYwSNFeym/7EybGTaykaVR+yUMVfGXn2bF7zw
DO9Zvilj1L9WnMHHlkeOrbm2K40NAGlZYdtxzSum/o+YU9dXj5iqj0sjptLY
SnNKzS0dlhe2cc+8vY1dLQldYQ5YVBIxn8Z+6rM+zP1V3aN1rFGuVfqE9A0N
pe/DQFXrGPt1tD+3InwA//MF8P+88ogBNxbcHL2F7q9tIzbNGDdj3dRpLkqu
Ma41b7aJuTYC+t/SJ6VdsFnYrLVdP0ud56RETNxQ+n5FVcQ++M4Eyify/Qlt
IubI2KMGybOLMfzG8ptjuygZs2vs7ovFEUthDPsK5OVp3n2qKnQuda/Xi4MW
c96uLwqbvLZ5UySupP3VOWFrMEfMXDF5MjR5BvYsXFAVe00W348x3kf7LHO1
IfLcuCh88vrmu0Fbd3AzFY+pFnO8k7HutDc9JWLCjQ1vAI/npIQOoi4ygjV5
uGdM6u7XOnKO+iRjpI2V7t06YlWM2TR2c2BF6O7GCH5j7DYy8jnYCL5076G/
24ojZ9Xc1dzSiC3U55xTGjla5mp9D34AdSsi9v5J5nA785cY0/eoexrjO8H4
Rc4gXetEDH4j48O7RGyvPGjeJWLyjM1bSxs/0vd3wKrC8Pnp+zuYFbHy5uya
u/szbe4F+8Cv2kur4uxhzoK5C+/xzrslEVNtbPVHlD9M/uazftD0R/2IdzCX
/Gj3TMbuZ7ASPl6dGr4FbSZ3w/uj0yIWVBv3WdofoecEnt3Mb8/qDzPe6ZCw
QWiLWMj36xqEjVhbsTEWxlroI9RXOI3v76gVPh59PWnJfHZpOrZt6BzqHh/D
108qwgejL0Yfor7E45Oxxz1ptxfYA492F8Sa59p3Er+dmBMxdMbSGYNrLG4T
fkvJCRumtkx9qPpSXyuPvU8d75XykCFlyT3NvW2ROYnwZi24Af58z55Yp3as
SbsoX+mYt44zjmcdY5aNXT6ccivQFOygb/P12dB+Ov/vqh8y8gl1p4L7jc/j
t9Y8S2sbZd/x3URO2I4G63OAXw1SY+5J000d4w4A7wJQJ/q5IGy22m61iWsb
V2dVdzXHJlEUOQvmLhgTYGyAPhF9I+Y0mNtQP5kLYQ6SuUjnZ8dZRJ+Wvq3R
bUK3dYwd6xN4tz+Yxrs3ZsSe495jDrG5xMY4GeukTqtuuzqpG5rDZi7by8n1
7ivqa8J7d9LeHzXDxqatbS51nlY/7kwo5N2btbk2CR/nNcjJCY5fecQMGDvQ
uCRsm94RMdA1rDR8VcaYzaF8MrQOSNIs7ebYmGujjf8w5HlXWdi2pGEG9H5P
X7Y3CJttq4LI2TV31xy3SW0iJ+OXRNB4HeX90Pso9C0FJ1JX/fYRW6WP+lXq
mpYWueiLtaHxPKV99P1/+lWb8EHoi3APbq4ttm348o3ZnqxPKCO+NUfZXOWH
jK9uGncWdGAt+LZ9xH4bw7Pa/LycyOU35mhrXvhk9c2ao2+u/gM8b9Ugcti/
9n6EtuGbHkidVydjGI1l1Gal7cqcAHMDvuds8oN56Lw/sm3EPBr7OLw0cuGa
Uv/I0ojxNtbbGEtjLWeWxbNhvHNrWdhAtIWYE/M3tB1pjgF9X4A835sVMQbG
GpzFfLk1LWz02uq98+L83IhpMrbJnBVzV6bnhK/NGIKX6O+4thF7aA7BJO9U
4JstTSMHw1yMx2jjRtqbBg4gR391iLb1GfxB+RLqfLZJ5CiZq6TNQduDOqK6
ojku5rrow15KWweQ+d+KI6fX3F59vvp+T+O908Ew6nuiZtQ5oixy6s2t1yZ+
BPJ3XnrERihDA43dKo+98iToaZkVOfDmwutz0vdkzIexH55ZUtLDB6UvShup
tlJ9grOTNjZtbTfnhO5pDoK5CE1pP6VzxGAYi/GeMXBNIqeyY1mc+T37e8b3
rP9mfsSWa5PSNqXOrO5szKSxk9MKY60zZuzawrhDxbtUjFEyVskcT3M9jekz
tm9R28i11eeg76Ea9Q+pFjR0Kos7PbzbYzjfjGgTOT/m/phjYK6Bd3J4N4d3
QHgXhDZQbaHm6Jqra8yisYvqhMcYL54Turgyr+yro6uraxPYQj1P0P/6tL+n
OfsK8v0csv4sWAcv14Psisg1ehd612XFHHAumJNtbvadjE2vWpGTXz0rcqgv
zAwey+tG6rjNI4fWXNqBlZF7aAxi95yIATEWRJ2hUW7EXBl75R7jXuOdJd5d
sp/v/+D7QsakMfQv5Lc8yo/S92VgsGs3GKzNOTNyvM31zkCeaqWED1Vf6qLM
8B2YM/Un/O7PN8dnhI6urj6A8kkZERNhbIQ6nLqce5p727r0sKV754N3P2zv
FLYvcxx3dIo7KbybwpiD8e7R5jDmxh7tXu0dE1nJGBtjbcwhMJfAmNofcyJn
wNwB72jwroYz9cG0D5+/vv9TymKtNeZtAOVjy+LuBnXIp1LD563v2xg3Y93+
LglbhTEYh5srmRl3ERyOjOTAn/UdwtZqjpK5SsqcsteNb7unRUypsaXGWDbN
i5wuc7vMiTI36mQwIKmDq4ubE2dunDYtbVs/w5NnWIv2wp/95oa1ibOce4x7
zR5zmOnLfu+f0JbeKd4dw/+vm2+YF7qlMU4v5oWNXFv5l9TxZ2HEWBprac6o
uaPmeJrracyNsTejkrF66szqzp5hPcvqI78q6SPSV2TMjbE3y6lrLm0Ngaaz
UiOGzFgyc47MPTLmwtgLZU7Z+zcv7nZxDjmX9LHrax8ITgNPlEVstT4ofVHm
rJm75h7uXp6TGbF9xlA+yPMJ8Ht8i9CR1JWG5sVdIcbkG5u/uixyPz+nzvco
z4KG28FI+wp0Fus71qdcnXIqMtjTvcE9lfKU3LDd3uoa0TlgWRvt1TzrkBrv
GmNurPn6dnF3lHceefeRd/B4F493Snm31HGpcffG67wzszhitozdOght/4Ef
y2JsjVEyVumaZD6rORLvGxtTFn25lP59QPm6jnH2NsfqGsqToW9qi/AB9oa+
Xrlx14q/+UwblLYo7+Txbp7rsuPuB+84+IH6M9vE3S/GTBs7/b87QbwbBDlL
dI4cI3ONzEkxN8WYEGNDzNkwd8M+2JdPjEEEx2QGrYfog+T7VrmRy+SYOXYD
SiI2VRuUtihzMM3FPAo6enhOzYu7JYw5up3ykSVhy/eM0JPyBGgcnxo51+Ze
L+abi+rHnT778yIG3lh4fVCNGd/s1pEr4Zr4VofY093bPUM+nhUyoWyYc2nu
pTkH5h7oQ3ibd1uWJ3PzakWs12lJ2dWGpy1vrLpzRsiYspaetO2b8944mWN4
TdImqG1Qn7O+Z3UadZsXk7FQ+gz1HW7h+VdgE9hcHj5jfcfmdJjbMSs1zlrG
nJzO9+/x7N38iKkztm5pm7hbR5/n/3yfGXGXkTGar+bFmdqztTHZxmb/x9y9
vEnkGJtrfCF1XFAeOXjm4i3g+6uaxJ1I3o30T9IW2Iu2e2fFnujeaIzw07y7
pCpin26ivb9ob15F2EI8I3lW2krbW/LDR6SvaBlr1NLCiEk0NtE7p7x7Spuh
tkNzzP6Xa+adIcYMum7VjJjhRmUhM8qOY+BY7Ev6nrzjyLuOPIN4FhlEXwaD
k9pH7J93fp1MuX67uEtNn1vtdmHT1bb7JFgBmpeFbnoD/T+8LHJ0zdU1BrKn
41oSuSTaIN41Xobn25pGDIKxCO1TY630t0dca9vHWqCNb4T7OLRNyIgzvGd5
c3rN7fXOFe9e8c4N795wj05zTWwfd5Pp4zue8jkVYQs3hnVQRZxpPdu6Z7t3
79d+3yTuQPMutFLWl5KiuEPJu5S8U8S7RZSBavqOW8fdK455Xf5/mT7dlhI2
6LolceeXd38Zc2ns5YjU8MVrc9b2vB16t+XHnQLeLVCSGXfXqTOoO5jTam6r
NghtEZck44XM0Xk3LWK0jNWaCR9vB7W93yMlbN7avjc6F/Ij59XcV+/o8K4O
z3Ce5YwJNjbYO/i8i28YPB/aMe488e4TY/yM9TOGzli6M6jz9PKIWTR2cSv8
2KJPhmfDMkJmBiXnhHPDHDRz0c6DP0N4/g1j9nXSRqSt6Dv6mpoSMdvGbntH
nnflGWNorKF3rHnXmu90t+32cZYxB21AWtiQtCXtNI6pOHz2+u478axzWpwZ
PDt4xvKs9Vx5xJZpA3y+PO6Y86457yzx7pK2FXG3h3cweReTc9a5qw9XX+6v
SduRZxTPKiuSsu8cda4655x76yivB42z4u4sY7a+4fsnciK2xjv4vIvPO1i8
i8U76C7n3QvaxV0R7rHuta0q4uzinQhplP/k+xuaxp0825I+Pn19+nD05Zjz
Ye6HObLL24WOq65rzNcnrr1lkXviGcqz1Ias0MWNOc2tiBwHcx3MKTe33Dt7
vLvHOxu9u/E/6j8IXodXbxRGDo65ONK0ozJyIsyNUAaHl8edHd7dcas5RrkR
o26sujq1urU2GW0z3rHnXXvmUJpLaYxI/YKIiW2ejBEyVsg90r3SGL3emUkd
XRqgtVObuBPCuyEuBHdBz48FkeuiDz81I3Kkz07KsLLsO7471HilnIiJNjZa
m762ffd09/YamXEX02aQUyvudCgtDxu6tnRjtIzVMgbCWAh9pvpOtbFpaxuQ
1G314enL0wbzfXrkDJg74JnNs5t3Ung3hXdQeBfF/nYR22DO16+U89Mj18U7
u1rlxZ0u3u1izoa5G8bEGBvjnWfeffZXYei23vHpXZ/6+PT1uYa6lmaUxVrt
nVZpZTGHnEvGWBprqU1f274+H30/xqgZq+Yad7A8YiyNtfTOKe+e0uem700b
p7ZOdW51b326NbpEjISxEvp89P14R5B3BXlnl3d3GUNvLL13Tnj3hHdWeHeF
dw5494A5NebWeEeLd7Voc9X26p1oJ6VFTnHH5Jrt2u2dSt6t5JmhgnXyUt4f
m8y5Mffm3GSuoDqSutLN8OCmssj5MvdrDO+MTn7jt97RsjGpc6h7mPNp7ud1
vHt9WcigsuidLt7tUoPfrmgSdx7+Uxw5xeYWmwNkLpA2Im1FvlO9LNZw13LX
YNdi7yDyLiLvUPUu1TPzIhbGnFxzczcndR9zwswNuyI35pp3Bnp3oDln5p55
h94Evu2gPaROyPCXmXGHoHcJmrNn7t7j8GJ5UsdQ17BP1yV5Im/MMTLXyBiJ
mZlx55x3z8kjeeUdpd5V6h1m3mXmnY3e3WjMhLET5gibK+ydpt5tmlsQd9t4
p4132xjzbOyzd5J6N6kxRsYauScfKA0bv7Z+fZazef8TYzCahA1eW/xXxXE3
ib+tKY01eF1yD3Qv/DLpq3APci9yDXMt844i7yryTgfvdjAHvxnz9uPciB2u
A3+m5EQOgbkE+jz0fbjnufeZA2IuiHuce50xyw8XxJ1mP2eGT0LfhHdmeHeG
d3x418cNBXE3hTa1B913c+MuCe/AK2S+310Za5M63LKMuMPOu+y8w+tS+Pt0
ceROaxPRNuIZ3LO4OcuvZEaO05pkzpu5b94p692yxoB1zYg76LyLzhyCtZnh
M9V3qk3vj/K4c9W7V5cj04+3iZhkY5ONuTT20jsOvevQPcG94f72cVeFZ96l
BXFHnHfFmXNg7sFxmXEXhHfcetftnqyIvfYOCe+SuL0qeG2O8rN5EcNuLLs6
hrqGd6J4N4o+RX2L2pS0LSmzyq53RHhXhDH0xtKrA6gLbOPZ9sK448q7rjwD
eBZokxl3E3gn5Jr88FHoq9AmrG1Yn5S+KW1SXWinRtuIJfEM5Vnq/wFOXS8L

          "]], PolygonBox[CompressedData["
1:eJwlkEkoJnAchh9ryFafsi9jH32NaLIUFxS5UVNc5vCNkgsHzByGaLhY7lNS
bhwsB8tXLopEUZRcOZAbpRyMDDOPHJ56+23v+/9/CA109kcC6RIjHTmwbaG+
HLqC0C2N1hqkuhI2U+G+Dl5z4UW27S8lwY+P8Es9lwChEphQT8r0J5iSGYlz
tykbvjg7586J/eE8+C4H3m+OgkF9Q9a/vd0tg0UZ1acoBRasJRVAr/kSnb8q
hWsJ2x+IhjNnt5wJS3sF/NGjqQhurd/Jtb5Xsq7+lwg36iznMiVDHmO9nw9r
ZliVFen3U76ar6/QOwHY+QwR7kfKb9+SFQFPxfAsf2WvBnblUv2QBvvqzVo4
12/WnOvqDRk345iUWVv23fN6nXr7REb0qo6HoSpoMWOBHj32W9Vtcqg+kFT3
L5IhEHyffdv56e6RN47lP9uKT7I=
          "]]}]}, 
      {RGBColor[0.6765997131548024, 0.7087696604999504, 0.9120697516399145], 
       EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFnHd8V9X5xy8QDEMhIZuQhJDByCbkG1ABUakFRKsMt7W/WhCpWkXAXbXW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          "]], PolygonBox[CompressedData["
1:eJwtnXWcVlXXhh9UDJAeymGYBCYZhgkYFLCDMjGxC8F8RcJODFRQRBFFsT4b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          "]], PolygonBox[CompressedData["
1:eJwN0UkrBVAUwPF/IlO88mRjfM88z1Y2voCplJSFYUG8JyxMX8CKDbEiO2Vl
RW8jig0ZNsROnlISRTYo/8WvTt1z7jn33NDwVG80AchWkq6L4TwR5iphUUv6
C0EsGQby4Mf4V/FGOEqFdvN7WqFXC3Uwr7kyeEuHtBrY0WYKrFpz2wx3OiyB
A+22QVcAHs2JVMCKPTrsMWE8qZNSONaycX8GzFbDjPNUON96Pow1wLjqPK9V
jrO8mFdYBUHrshTQaCY0WHthn3vPv70jUgBRXdXDpdZqYd9ZbozjYXhSp7OG
g/BVBIPe+WrfoDWn3nOmeIt52naWRmufjT/s865y8z/dZyQX9nzrgwve8r3d
5e5Lw+YMaUR9zhczZ6MQpt1BpW9JbPI/9A+z+kWI
          "]]}]}, 
      {RGBColor[0.7409383781571689, 0.8121439927347999, 0.913536475036172], 
       EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNnAl0VtXV/t+EhEDIQBJICBnJSIY3hCSEgC1atYMDg2CraLWgOLS2aoe/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          "]], PolygonBox[CompressedData["
1:eJw1nAm4T+X2x3fGMs+SMznHmQfHcRxDXc2jkKGJEs3Dvc0TzRm6t5KkSKWi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          "]], 
         PolygonBox[{{10714, 10713, 10717, 3262, 10022}, {10736, 1548, 7835, 
          10739, 10740}, {12596, 3318, 10138, 7792, 7793}, {10702, 10701, 
          9984, 2001, 10697}, {10479, 10478, 7185, 3236, 10480}, {7553, 7552, 
          10152, 3323, 11427}, {14058, 5379, 9459, 12526, 12527}, {8650, 8649,
           13327, 3326, 10160}, {12216, 2102, 10501, 12219, 12220}}]}]}, 
      {RGBColor[0.8009300411897324, 0.8597697097226844, 0.8968730638680202], 
       EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFmgt0V9WVxm8SEkhCEkISQgh5I0nIg4S8CL66XGMrSztFoQo+0anaRR1R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          "]], PolygonBox[CompressedData["
1:eJwtm3eYV0Wyhg85yEgGZfIwkYnABFgDXlzXeE2gYkQwXV0DGLhmWUHxiqgo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          "]], 
         PolygonBox[{{11264, 11263, 11266, 3496, 10623}, {9477, 2794, 14865, 
          14866, 14867}, {10424, 10423, 12477, 4521, 12475}, {11381, 3856, 
          7422, 10417, 10418}, {10655, 10654, 8632, 2227, 9888}, {14108, 3263,
           10037, 9520, 9521}, {10505, 2675, 9292, 10976, 10977}}]}]}, 
      {RGBColor[0.8587105290957264, 0.8790379628237114, 0.8709874570651155], 
       EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJw1m3l81tWVxn+EEAghJCRvkpeQBbInZIe8IWw6jkWodETrTh1ErFMcVzqt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          "]], PolygonBox[CompressedData["
1:eJwtmXmcz+UWxx9mmAUzY1aZfd9/M78Zs2lzcRXX6yZluUmWieSWUNmvsk8R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          "]], 
         PolygonBox[{{12402, 3313, 10125, 12400, 12401}, {9337, 9336, 10419, 
          3433, 13923}, {12572, 12571, 11170, 1385, 7769}, {9969, 9968, 9532, 
          2831, 9970}, {8818, 2345, 7768, 8372, 8373}, {10730, 3537, 10729, 
          8505, 8506}}]}]}, 
      {RGBColor[0.9164910170017204, 0.8983062159247385, 0.8451018502622105], 
       EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFmGmM1lcVxi/bbMw7+5RhlrK8szDMTpmND7WWUQMuiF+0fiCAJoYPUiml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          "]], PolygonBox[CompressedData["
1:eJwtlVts1FUQxqe2lu32slulBWSXbtmWUrZsF+3ushi1xqpJlXh5QV4M8KQv
JQW0Ia0CJVZKSaoxCF4I1lgMwdaCxK0NsTUaBUHqQxGDUTERYk2MQrzhJfH3
ZXw4yfz/55xvZr75Zk7tho0Pd1xnZr2sIlZkhdn3lWZfl5odSph902h2ptws
wYosNXuFtTfIXqHZPuwrS7DLzNorzP5ZZnbiZrOZG8zOzTE7jv1d1rH2VZnN
Yhe3mA3eaHa6AH/YoVvMCvi+PWTWtdysJ232GfizJWbb42Zt3Elz9xAxzUTN
zhJTKfg/4S/bZPZrs1kze+sCZitrOUtMOWLt4kwA/6uI6We+x8BrBG8dGD8Q
ext3FqbMngH/fvD/KjarrDGr585u7l6CjIpFZsNJs0fCZvfONXsD2xKeqzgQ
F6/Cz/Fy50hc9S82u0o+/WDEwbqU9dz7xB/7f+DzFL6nORPj7J98f1rp/7T3
FTFmie9f7rSuZK/JuVFN1hLP7pzZC/PMDsp/ndkmMCrJ/QH+PcjeFD7P4buA
fxciZvfAZzW+R8m/AezznJk/n5jAjLLfB8Z+sHo5E2h0jsX1MGuceL7IOde6
8yX2djgIg5+Dk96k39HdejAuLjTbmvHYTsNXN/at1OcEZ6f43qA99NKDXvaQ
f77WORf3I8R3scE1I+0oh4+wdyTdl2qu2heyRgs95mLs2/7HnwS/i1wmwHy3
3H0M4auT/O9jb1p6anQNS8uq6SDxHgZ/LfYA8Uyivw5y7ib3HlYn9pP8mxtw
jUqrLeC3YSfZv4rvTSk/m0QvA8R/BLyTJY45gl2Dj81lXqOjMbMt1LOh3DE3
Y69Pu7Y+4c5q6vMQPuLg/wgHVeCN17iWdrFq4WO0nlpXueYOkE8aH8Vh78FE
xDUmrb3I9xV870B/UzR4O3d2YgfZ31nuGstz/iz1HiD2A+QwSi6/17j9Fv7W
4C9Aj14u8p4NYr+Xcm1IA9LCgpT30qPsPwY3pXAyRDwXiL8EezFnfgt5jIr1
GPPlDu5eo+Zj2C9Rs1MFrmlpu6jRZ0sIzPe5X0i+s0HvEfXKeTjpYD8FZ3fC
3X7if0q1IN9B9rbFfXaI4+60a1xaV0zBZtectKcaq9Z3pb030uDdjd0Oxkmw
RvB5jNiSaKi/Gt1y/m3OT8LhtwH/l6c/O4j3dXx9znqNXhxL+VlxOh31GaRZ
pJyPkm8rPprxtYIVjbvmpL0zxPgh9vMNnos0LC2/TD22zPGZmAd7Sdx7RRqU
FvfUuVbUE8uiXjPVTj2h3mtLe26aoZql27KuBc28kXrXlLSlmTeBrz72V1e5
xqQ15aTcNEMuixtyfrPaNRFmHhVzZmie/9OeZo5mzwwxtcVcg9Ki3oRxfOWJ
qaLSNf43+6Ea14I4fQd+1me8l6XZNRF/I/RWaKbOYE80uzaEIaxf4j57pOmn
Y645aU+cBbC31vnsER+aFQVNPgsU896c10C10JuRWeozVLNUGusk90jctaaa
qXaayZrN0uwMuT2b9d4XZ7uwW2Oeu3pevZ+I+9sjjayiXh9zf7jaZ0QGbRVR
88dD3iPqlUytv2XSoLSoGaNZozdOb11P1LWpN01vW1fGZ63etCcy3oPqRc28
jcRbtsjfMvmUb80YzRr11DX09MFy1556SL30XIu/TWFyuAmuFjS5rRiv5+x/
IR8/QQ==
          "]]}]}}, {{}, 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwlkr0vQ2EUxh9bMYihk1ZVaVWpz/ZeFQlpGUxiaYzKqkKF+Ei0Gv+A0WSy
CHp9pJVIGEwkNRAVEwMJGxEmiZ8Yfnne877nnvOck+tOTI8myyRl4bBDqnJJ
OfQALLB1SqEmKQxOj9QfkhzoAFrySd8OaaZeGumRZtHjOt45W6irhnzURhxD
H8g9p94FHMEpFOCdPIdfejakV3iCSa+0HeAeD2O10mWLdAULrXjskubRFPEc
2PG2jJ9VfC2haXQFvXFK+XZpk5nK6WNrQ6ESKsCJnxLe7uEODGoV6ZkJSh48
raFpOKFGAW6pF8NbjNqDEAUfvYZQOz1e2McWO0gyyxtE3FKA9ylq+9FIM76o
YZnst0EaJj9MTpS7He5Mzp/4+oBuzt6/efDxSF419dfpvdvInGgWMmBSM84c
42F2Q80+vl1EJ4gT0EscZ/Yvvv+hxx5zFOm3wZzXaI54H4LsO8/7mfH/H/wC
01BWsg==
          "]], LineBox[CompressedData["
1:eJwlkd8rQ3EYxp/ZrLUkiYvZsLOZH5sfCxt25Vop/AFiN1xtjSSp5eowFC5s
NEKRJG6nXZCU/AG7U9L+AtwgLnzKxafnnO95n/d93u8x4smJhEVSGlxhadaQ
khEpBSsdkqVT2h2S6mKSPSA9DUo1TdJMUKpFHf2SEyrADjYoQcYn+Xulm2bJ
QItoAK3Gkw1JVegjvaKt0mW3dAXncAF3XdID3MNeo7TVJu1AkWwn1B+TK+aW
jngucJYgdwrmYIO6LJ4x8q0OSGtgwjXZD/EdwAt42ulLjzPmncI0+476pW96
OMlmpf6L50/wsss2OzVwFy6oJJcNfPgiEPJIH2R5h1/miv3y9M+BQRYb8257
yA8F+PFK431SPVk3W6QgNVY8dsjwbnLfJurA90rGEe7pjWxpfGX6OzkvMPOZ
s2G+laiJM2sfzzrePJqDpai0DPOwCAswyawyu0yh7vD/P/8DhV5PdA==
          "]]},
        "0.8`"],
       Annotation[#, 0.8, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVkk8ow2EYx7+LgyQ5bcX82dj2w2z+/zmwHdw4LWlFrSaKA7m4+3dWEsUF
hyEiZ1I2MVua/+LADSlRaheKj8Onz+993ud9n+d5+9nCI4Fhk6RFeLRLezWS
s1iKe6TTfwqkI2ITMAnjMA1TcF4kDeML/OGWbFXSWYuU4EyUeBInuSMBLu7c
J/ZEjQzyDNZmztj5jhFvZX1D3i20NUo+GPRKQ7BilSJN0jLOc9GHUxqolPph
kHhHndQJa+Sug7lQ2qmXLNjKfo1D2migfqm0imN4G1dRc75CWgKTIf1wd4Qa
Fnr0MYcVj5XQV600ih9wkLyWcsnPbOZm6ZmcNHub1N2GfGru4kL8xh0O5nvB
Bk4w5wn4qbtAX3f0NYevcYQe7ukrzdzpMukdf8EnLNDXJed7/ueiZorvGd5u
i5nDNmmWb0s1e6z7WR+wPoQjCHFvHPfhXOr04iB0QYhZu+k1AHnUyYFX3jYT
Z0EFcQ/UkZci34udrO0g9n94w3ZmSeErSMIv8W/IppaDfo/JjYKbuQ0Y4l/5
A/1Oa4M=
          "]], LineBox[CompressedData["
1:eJwN0k9oz3Ecx/GX2srSkpYc2G9/zMxssz+2ITlIS1ITDo5s/iVm22EH868o
K3FwcFH+tMNkiaU1SxwQ4kC4ScuBlqQmB8rB4/Ds+f38ef/5fD7fqp7jO/vm
JZlG3/JkYH0yyDcqkz+tySj/44ny5Ij55nXJ2NKkrC4ZX5ucaUvOYRgVVUmL
uRlexZ+4kTeKnZP3a2My0pBcbkmu4Cr+Gs+uTl6Kf4NNzclmdOG8+AZxI3wW
z6yf5G71F+Fih/5qkgs8xq2dSQdq0YR6DKq9pD4p0ntnezKfR1bJjSNyDK1I
7qhxggexW8we7MBp4yHxJU1JKYpxuFptvl1I9vvuFruXd8m1GKXu5761m3jq
7P3WHvNRLl6ZvFX3NTrd62J5lqAM0/ZM4Ym1j8bv8Q6zerillzhfpe/r6hX4
oVw/1agzP7BM78447Gyn8Koi6TX/3fyc+R/cqF6R2NV8qdbd4Z57n7VW2JCU
y9fsLbabb5D3mrUu39vwXNxWHnW+ST1N4bO3/IIZ1NvfYX8dL/CmJdhi/0L/
SClGsV9MwVwPV/JBXsaPna2GH3E19+pjH17rf9Jd3nX/NXKP8wPjWnsmUGv9
mPEB/X9wxkPc5j9tRwteuINf/Bt9ztW/Jvlmz3+Y4nR5
          "]], LineBox[CompressedData["
1:eJwl0k9oz3Ecx/HXrFlLMqaIsT/GjPk3JpNyFBeinEgcOJklSUpyWM2/5WDD
wkQhyUH6aStjoiX/YrUDRdvBTePIDjzk8Oz1/bw/n/fr/ef3q9l3aHtrUZI7
uNaUzKpOumgFvUJLK5Nd65zrkq21SfmqZCZmo2Vh0t+cvF6QFOh7OkB31CS3
liQjzicako90UHwIL7BpfrJlKegI7w18fixKJuT8Qc/ipBvV85Ji+U9WJH0o
4Le+tq3WQ31yVk8N3kziVYIO5/YW0FJ5X+cmm/mP/+tD3ijvMvGCmT6JbXQ3
7M1etS7LOS23h3bj2NrkOA7jKI5gt1qja5I9dM5KO8ABs7aaqQ0neacxucin
Yr2ezDWkxjRz7ld7Oi2VX4YilKAYw+iw21r7flxlbtpH6+hUOV1mm0Jf8mq2
p3vLk/u4jbsYWJY8xzNc0lun3VxAn95ueN+rrxZzXvddEDuo7zac9+Yd3yr+
b+gZ51f6mOFdvxnK6Tl3N91N1k+9+p18msSf+v6lVqP7CTro/NPe6nl8Vu+7
fbfz2snnFB2z42/4YCePxN7SXjt54Lco8B6X/5CG91XfX8TH3Y9V/v9f/gWt
CnCa
          "]], LineBox[CompressedData["
1:eJwlkk9I02EYx7+TYBcPXcroN6e/5Z+pc2pTfw2FYgNtIBTGJLSRKHqKdlIU
QVQGdgoEQZQ8FHSRhF9t1NikDh0EYRAKxUDyDx3yEMwSFPXgJzx8+Ly/Z8/7
vM/7vDMH4t3PHZLWYOWOZJnSvwbpEAKsK29J44a0Uy1dLZMSlvSuUprEMzAF
Vq3U45L6W6XRCqmdvWM46ZVGfNIH7G6R8h7JwNvYxA/Lpaf1xKifq5M2oJX8
ALio18w+J7WugAMWOd95m7NwFWfepLdGckzWPtzFHou8HvbvcpeMW/rJep26
2+wZJvaAnAL3ypZK+8TOie1gmx7S9FMWlDwQZW+W78c4hQ1iNnaTdxc7+Q7j
PPW+0NNXSEIWPkGBPKNG+sV8fsMuDFZJb+nFaJLe4CfUjuE+fptmplE/88U3
2HcNPNSYY6bz8BKWYAFWmO1rbONlvIof/X8fahWDyVwamEkA6uAvsTi1Nsjd
I3cdf4McHNPDEv0c4WXc1SxFYJP5JBulj3DGXfN8dxBP8G693C8G95h1GLao
8x3SvEGW/Azsc84PYj566WRPBO7DdWbt4M1LcBE+4dxT3ugcziBFLAN++v0T
kF7xVi+YyywM0d9n8vd4sxDrSdZx5tRGzgEO4lrOe0a/Xhzk7hP0bZP/nn4i
zKiFnFDp5X/9Ag3ofc0=
          "]]},
        "0.6`"],
       Annotation[#, 0.6, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0k9oz3Ecx/GXrCwtSdpltpmZbbbZH9v8y0FakpqagyPmX4vZfocdzL+y
shIHBxflTztMJJaWf3FAiAPhJsmBlqQmB8qBxw7Pnt/Pn/f78/68P9+q3oGe
Q7OS3MfXRclAc9LfmPxqS37iWWXSwu1owz573i1P9vDB1UnN0mRiGeO28fXy
pLohucGTxi+t76xNelFlz4NV1vkhl/HeFUkl7+Jy3s1jdUkJ5mGjueLWZC5q
K5IOuev5U1PyGR9xR8zkTFxZssn+p2uSzdyFC/Y32L/Fd7N7LVJH+dpkSv03
rZ02fwbLFyezxTXyd2vT7viNe9X/Qg+OVifDKJgfNF9r/oe8d2fy1SQXxVby
P3uuuNuU7zdqeov3eFSvzvbkHhYYl2IhOp330tprFMl1YIne2DPAj/myM26h
RC8Xul8Pdljrdt5uvmptvjz7fRdxCYoxpP/H1LBVLduxDQXjw7gmdoj75Bpx
7ijmqLuzQw+41B0L4uvFNKEGHWjFuHuf6tRrPs3z5ejGkarkycrkBI+iwRkj
3NWSbMB6vLL+HFP6/sdbnPem53AWo8ZfvOW0uHXObnT3D+Lr+BO3cAUPiz+J
47g+00v/yLjzm/WnT+0TYv/6T8f09Tdf4oL5QXn7+T9zonS/
          "]], LineBox[CompressedData["
1:eJwV0l1ojmEYwPFrVsTMONhKm814Z/Y9+2AkqzmTAx9pGpYtJaVRUigRTUop
yZadOVhp2nIuxWbDmpUNoRRhtiYr7MQ0fu/Bv/97P/f1XF/Pm996Yk9bSkSM
4HdNRBtO4RjO4wyqcyPS1kRs2RyxkP9mRxxdHZHlfJyXrIpo5RXOh7jGfQov
SMbz7ZyI0fUR4+hZG/GcM0sjnvBgeUQ/2ss8F3uJR/gq523QAw85n+MB7loX
0YmL+lqml/eVER/wETucp3gCn3FFzGW8EJ9bHZGPzgo5sFzPg+7S+Ys+p/Xz
iX/wJIbN3Oy+BWNyvca02MmNEU215kQj6s1zmHPzInYWR8wURsyXmMcOdpkr
URRRjIN6GK+L2Cpvg/sGbq+KuIazWGq2C5xqV/vFZSQifnn2zLsVctaisiDi
rloP1LzD/dzLpWrfUrsLYadzYrvlybKPbWbK5tNyvZL/JL/jRnF1ctfrM1O9
r2Jm3fXYTS9WmvU+5/CUHAn7n+DC5HfyXYZQr27Hpog3+rrJ49yth7f6mrWn
WTN855+YQYe+Xnq/Sc4+NUf9vm7X93yXlvyIG35n2XOf8xHnh86PMIBmeZ9y
K6erc4AbsRfNZt2n193IUCcN3+w7lRehyPMyVCX/h+LLucA5H//sbw7bzTLK
YxjGvPf+YLFaieR/RexjlJi7EMd8v//9L4vJ
          "]], LineBox[CompressedData["
1:eJwl1Hto1WUcx/HvxpogDHGKM9Tp5jpO51rLlfOCiIVkaMNpzVWgSH+JpCJJ
ZEjoIJqblzrmxBroUhAJL3HaRilzmpl3rXm/Uol52fS/9A/1dfCP9/n8vs/z
fK/PwymYv6j644yImOjnu1cjBgyLSNJc2kSzB0d8UMkuininMKJPeUQ/5KHy
pYj21yKODo9I0ZN0H60uiNg6KqKL/fnIiDO0w/phHMTU/IhpJaBdYk8QpycR
8ZjPE2wqjtiAoUMiMvn/WhbRhhQeqatqjBpGRNSrqdiZDLGy8CW7bhxoNr9r
gyLeEr87XQe/G2JPt/c3Hcj/Ray0nsdnFV2OK3r+jF6l89RQWxrxPi6LfwkX
0aXuGmtz8IMYI51/4GwPWthFr0ckUIiidI30IzUslne3XuvHRuylDXTV0Ihb
ZnkHt7FNP4VytNAys+o28xJ6j5bSyfoqt3fWLE7jDXaOeU+Ut9R6TkXEIfYF
tf1OL9Ox4i5RcwXd7NwNPtdx1loTu0HsGjNopAf4/MmnC6PM7i/aZI4rnM8c
HfFUbd84mzs+oi+y9LGR3YRvMenliBGo1m8xnUnb9NmOFFrxM4aJ04g16O/u
f+Hbj65lz+IzGyXyb5K7Re5d6tyNo+qre8Vdo1m/ufpttr4FB8x6vfUkNmKB
eZeJ95t8R9CJcXIco9fE32n/Jj1nrv/QizTfXd51j0nx7st7Xv4/zOA4DqND
/oQ5TVHvcLpcnk/xCXqbx3v2W7zP/uy5vueocQf7Q9/baS39WsxWdczw3Svt
hxzsY4d+ZvKpkn8ve5kaFthbSpPWd7mDPRiIdeo5pY5T6Xcu9hk6lb6JtxHu
N1eN272TyewpuC/WXWTZq9J/Nn3I7sEd7/Q/1Mpdob6D5p9pP2mGGbSTPcZ6
m7qa1VMp3/fsFHsh/0Vo4HvC2Xw+x+hX7CNq6Otcu1r70NX2tth7wdtPiNko
Trn1/b7/12OJ/ce0g/3AnSbEuCTfPXdTJ9a74nxBb7qnf3HaG/zJ2nHarKcf
/WelxO7mv4c+tb7Z91Xr3ek7H/z8v+4Zu5XYUg==
          "]], LineBox[CompressedData["
1:eJwllGtI02EUh38R7EtFBEY0m23lykupbU2TbiAEklKwZmbZzfRb2L0Pfahk
5IfA2qUkwWrZVRJGyhxNMioQRobNilYjLSqKSCxKu0n0/OnDs9//fd9zznvO
eQ+z1exx10+SNI2fp1bpl01yFUtj6NUl0kSGdAnVXKkd/WiRHhZIAzAjX5oJ
mXOkTwulLDS+VHoEh7FNoEP4H+D7KBwBP+uOXGkL35WwAQ4twAb/Js5Ki6Ry
WJsnBeZLJ11SM/o8W3oC4XnSDvLrQnuglu8oehbfwUXcQZzv2H2Bm/idxt8P
PvhBDbUO6Sdah45QS5BcPqOxZVIBeYyxHoe9+O+DImKU4/u+UHoHI5mSF/sT
3NMI5+lTELsAvkG4yDqyWAqhPegFo4/ktYl+VUEvPjdYX4drEMWmG16Sv9+I
Y+SNzWXOGrgn6ZTa+PYTx8fZKViRI+WR1wsjJ/K5S9x7kML+GGe7yT+SJd1h
L4o+w24QSnir1VBN7VXgpa41vFESv9/0MYJ9JyRYl7JfBq28zzdya0HH0X7i
DEAfvObuOFqfLn3lzhzudhi5gZX8prA3HdzU04FtK7ZhNIS2o81oCzRBEHxg
I1YaNc4Cr13yMAfH0c3MRLUxN8Y8ombyuYLW0PNhzj7AWzDjN0qMbuqLQSfc
h15IMp8lzLiJWlehFuzCqNmYJ7SS2DHUg9rYyzBmi3UYuyFm5g8z8gaN0Z9R
3mMd8erYS7HXRy6veKfb+A6zV8F3Ib0uwyaXN7DSk3x0Nn2x812Bj4mczqHC
bjKYwIlNOj4O/F0QJ26/US85bGNO1pOPlXdLMfNmNIla0Fv4/cUvQewJ9Ayx
ArCdnm4FN3678N9pzBu9S+PeYuIvh5Xg4Xwq9W5E2zg7yJ0P6Pt+NMS6kfgN
vGM28/gYG7vz///FP8qSvuo=
          "]]},
        "0.4`"],
       Annotation[#, 0.4, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVkl1I02EUxp+FVyMCERljZVMz19rmtsp0JEKFjbVsjPLKHCuVQFgEgm3o
tesDdVcRsYIiDbrooo+bjXAgY0gEISpjjEwlYkGQNuZFF/28+PH8z/u+57zP
Oe+/+eadcMwgKQMFi+Q+JZWskgsto160dkQq8t3WLa2jFpu0yNmeLulVq/QS
vndKW1CCb1CGK+Q9If8p1LmlAyC41Cw9OiPNwEGHdAg+Uc9M3Swad0lG1uLH
pZRdmoMhj3QDdp2SoUXaQYUOn5am26Uk/DsqBTqkyxCEC8ekq9zhw982uWG+
45z5Q/2/UIMFvPxGf8FPGGd/iVo52CDnNnEZHUO3UOth6Tw+7xKn0Bjai6bJ
nceTg3ovUDf6g74rsAmPif3UvAiNJ+kVRk9Iz+gzwZw66XHqrPS6jRh9g0bZ
H4J7zMTOLHLM34mu0FcRZonX0Ot42mM9wTze4iXSJA14pSreQug1CIONOu+o
t0L9VfgK/eQ9x0saXORNoHGocH+I990l5wM5VbRAjWXIwxf4DFFy/PwTRrz0
oXbOzVIzwHeC/Gm85fF1H50kDrI+yHys9H0Of9b9mTE7OySYwUPORXm7CLjp
rYP/KMsdHtRLfIv1EZjkbJJ3zeCzi7rvuddE7x9RH/ED9srM1cTszVAPjdAA
FvgPFVZ83Q==
          "]], LineBox[CompressedData["
1:eJwN0ftrD2AUx/HjB/dCopSZfb+buRvbl82ltVqjtTXaUlbUaLOLGkuSP0Ar
Jpc1a7QfiJIkP6ChUMstKWmttSQxX982+U2WFl4/vPs8z3mec87nOU/i0NHa
9mkR8RxtayP+rY4o2xRRih1oXGG9MqJkWURvKqIP4wURGaSxOBHRURRRtTwi
f1XExNKImpKIv7kRx5wVboxIoU1+j9wWOrM4YjamI0v9uXTK/c/W1XLTamSr
Vanmt80Rf5x9pZN0YE3EYFZE+fqICvzm8Re63D2dE3FG/iPnT5MRT2iXfaf4
YH7EF3Vf0Pl8DfE+jBF85GsUKd6SvJTykUPL6Gv9XuKH9U8k1bpeGJFHb9Ca
bJ7NrZqO6NWgfpUZVqASLd5RR3ejk8eDZtWEvTiAeizgc8kWs8AiJPP0p/u8
t13v/fSE9zfQU/SZ+9/FJ7DH3dSGiF3ul2ObszG90rjv386bQ8Z6jL+H9uP2
zXrOMIO33v4OF8WOOz8iPke8lc6iY+Y1IPcxPnl7n5n04yoe6J0r564Z3MMt
3MFtdHhzhp41ozQ9R3v0qN8a0U2z+c1Cwzr+nDX5xw/m1kxbcVi8DW+8JeHe
K9pof1LdhbzMwwWz7JZ7yczfO7+i7hC9bN8rPqzeKIrFd+q7ndbye9M/F1n3
0wJ6jU5hEv8BSbuDcQ==
          "]], LineBox[CompressedData["
1:eJwVkU0og3Ecx7+0w9LSkjCPbeb9/WVmbJIUObjtKAcppRRhL4Q4ODg4uCiR
g5wkOe7m5CSUlIODFFI85hEjcvBx+PTd7+3//T2/+YYnIuMZkjbBG5BSfskC
E7aKpcESqT8kDaD3RVJuvXRNnIe6wlI++L1SDnEXPYkW8j4phhqowZtucMEl
sdWIB5iQTzxNn+mRslolB9hhMSgtwHaZNO6W0vht1Env6Caa/v8Nt7X40p8L
2XCGvxM9ZS7cJLVDEGbwiZdKgXZp35AK2DXAzga7B9FC4h/4hW7eyCbvBAfs
Mr8Dd7zxCE3s8ICeMvfFe+foJ3d5r5FG8LVVSEl6MtEQNzyh3oZ2QgfE6Z1j
7yiaYN4qJ66SZiGjQerDP0XdhCewuM0Lt3uFZ9innuQmSb7/qlI6rCYHR/jZ
uaUDVrntGnzgEWTGQm/Y6Y3vm2LuGd8we3mIPcSt/M8xchP0HfP+GDpJ3Ew+
Qt83uVHm02gP+7qoD1Ffp3aCrw3PA3qX8FyGFeildx6dgSjsURd9F+T/AFsS
aFU=
          "]], LineBox[CompressedData["
1:eJwN0V1oSGEYwPFnq4mZcbGVzGazmX3PPpglq7mTC1qaNpON0kqspFCLaFJK
SbbszsVK0+Reis3Glq1sCKUIszVZYTem4Xfx73/e8z7n+To5RzoaTiZExDja
syLyKyKK8Lg8Yhi5mRHLN0X83haxhLGtEZOYwK4NEYv8F9li81C63l1RRAWX
OBdgme8S8TU/IplTsc/7/TgkrkF8I5qRolYbPy1xx0P8CA9xNCfiXlVE+paI
686tznedr3meKHW3PaJJvy88d2+OmFfnB75hIQ/8JjeiT94pdW7URLzmbq4z
y4i5R5Hv++las/MsZ8h5X69reYD7sZAd8WVjRJqadRkRNYVmKIh4WxnR4e4l
n+Z1YnbKkc59Zl3U1z/06uEmitUdsL9Bfd3mB3yHy/VVLa4Mz+T+KVeqGQ6o
lyjPeflXeneWr6IL9f5ffXHEDp4Sd9C+C32bi71lYvS55H5ezj1qZ6p9WK06
NRu5BU2Ysac5s76y50m0VvsXGJN3xq6/46OZ5vgzp4gddr+ae+2mB9n+SybG
9XDJ3WV8kmsas9htHx/4Pd5hlfMFMT3iezFktnP2P8KdnOW/XOHnzhd5lLt4
0FzDeGL3afoZ5X7zTPEEbtlVktgEfQZX2UELr3Fu4xV6Ps7pzsf4j/skvdQ6
J3Olmc/oqxPtOIUT+IX/MQ+L/A==
          "]], LineBox[CompressedData["
1:eJwV0UlIlWEUgOFTQgVCItXKrOwqmt7MTBukQkikQi1v0CYIsggxUQmRigau
oQ20aBFBhEmQpRS2KGjRpiIXEWEEIiEXiiC1iBZB06YeFy/v/w1n+M5f0NKZ
6pgXEeN4vTqiYW3Ey5URjcmIPahbHnHcXj3Xl0e0FtnjNp4sjZhAekXE5fUR
X/giz/CHqog7c/msz1sXWU8WRBTwBCe4PT/iq9zfMItpXFezx3l3IqJyc8RI
XsTQmoh7+Gj/RkXETQxgRP5ZeR7JM82D9jJiHqh3SN1z+kxvVB87ne1GAxaV
RaR4L5owWBhRWxyxXZ4BOQ9ssccJ9fo26Jkv8Lg7JSURb83njzrvuMe9lPvd
vE/vzci4t9hZntlM+c72lppqe7yNm5wt9X1MXC4n1d9lvoflnHD2WP9H9P+E
p+T7Zy6/3X2hv1HvHOP7+h7GDutazMibJc8P/dWscte8Qu03nMVt+nvqXgc/
41tyjyJbzSVm3IyDzhrVaeG7znLM76jvLM7GQnSrfdq/b9oUsR8pdFmfwPDc
HLhVrl51+7HA+6r1Np+XmUeX+BIxSRSiChUY0nuf/3SbL3GOHI04ZfbPzf4s
96NUjV6u8/ZabMUr52P47L/+Mq9rZncVV9Bv/cn8vourUbvM29+LL+YMr+N8
Pik+jTMYsZdrjkPql5tPq94fiv1bqT+z/ckD3GW/U952/g+wq4dH
          "]], LineBox[CompressedData["
1:eJwl1F1M1mUYx/GLTLcm2aiUg0BDQgMRKA2QnITNldOYNZhONw+wtbkltJZr
04NabrXyQB1OS2UFy621CkHnENjIF1BEwJov1WRjiXMgsIoRuVb0edbB7/n+
r/vlun73df//T0ZVzWvVSRGxws/RZyPmPhlRiyl4GGemRWwuFj8V8crCiDnP
RDxK86goK6LluYjuzIhT2Ivt+GpGRH1OxDXx7uyIq9hhvJPO0Zr5ES8vIbwm
d4k844si7tvzD336dMRBmp8ekWR/Wz4f+BdPy3He4ohUquCneXlEJZ7E/AU8
5EX00Y9PRAzxXy9Pb5ExukJl6vTjC/gZD+k89PKwWtyWG9FKfy6NmKR8eSrU
S7Om23iB9Y/xemSFfmA+f3PxmDgVq5yz0Z4mqlN/ttqfYw0+UBIxix6ks3xO
qDlJv9MqPX7Tmh10ztwwLynGxsUNzplZGJFFGZTpHhbjNrVq9KpR3Y+dpwn3
4gf233E3w3SXvuQxg+8GzNP7Mb3KwXuYi6XOV2DuBz3up9XiZPf3vLq5xpP1
9bz4pn504S9YKO9benLEmmq8ojdT9m3hodTZb6k3QJfMd1OPfT3YbN1JuiPn
ENXLv7eAf+q15nFjv8r3CHaL9xj/kOqsSzFWJ8cX9L0e7DdeS4douz7kqXfB
+S/SWSrWw8s4oE9fmx/E6857G3/CdO/SiP7WyjfK+w33dMnZeqiTOtTP0qMy
d7sQd6nzLr1DD7nDSvMNy7wP4q2eN/L4lXiL5+O4CQ/IeZqP9Z5nJfZRMrWL
p63ZYE+5+k3inTxsN/c21hr/Tp9OUCrt46ePjz75XrLvKq7BF2ktTSf6w+Nx
91cqLqNRuUZohn6WO/9M/E08ThP6t1ndPxLftLn1evI+n+vwE3182PMcmk0t
6ibjGWtfN3fU8zFqFVeJ2zEd35D/b3UbnWUKv8X72MXrSryr3yU4jKtwgueb
vExbt83dZvKTRR85RzYO6MPPdM/6PcYq+HgPB93ZEPV715qN9WCdM3zjeznl
3R/zPZ3AfxPfqedbxscS95/2///bf1d721Q=
          "]], LineBox[CompressedData["
1:eJwl1G9o1XUUx/GjsCcKIhjRcnqnu0s33XRzs1k5GBTSwkyvSjrNfz2JsaS/
4INKJYNgY2pKgz1QadHc8tJCh9dUNBJWhk6Nroy2sqLoyWZ/BNNkvX744L3P
93t+55zvOef7vZu1dfuqlydExHx/rhVH3J4VUbMk4h/aVRVxd2bEYTpOu+nv
MyK+WRhxCVMXRDyAkqKIP+ZEzKEDNRHf4g2+g3RY3KvWb2EH9tr3zotYb70W
q/D6I3zEt/q27NGIZ/B0ZcS+koj3ayMO0u/LIq4iOztik/o+p6ewzbqfHhB7
Zb4z5PmbX6f9eed00DfZtlVHbMaKCmeiGnWoxX49PTc3IoOnnLWcNqJ1ekRp
nTXbrlTEdbZh/KreKWbVJl87XtJDC5qxzgz+M7t7OCP2T7lHxNyko+mIL9hG
rcvVNkZP24+xf10aUW/9lTMr9f6pMyvoMdqjr168y38pWxon1Z1DF/vRhMX8
0OReNuA9vrfMYQ9db3+Dz0nnfMynn35CK5zVhKx+2tTbY06H+XXTneLyiyKO
2O/1rV2uNjxeLk5N18X/Is9Zuc9hiP/bvjXr67h+T7P10+/4XUGDd1KPJvN6
Hrvd65PeR17cv+7wOP8+DNovY29Ep3n+5f466C16UZ5LuIAfnT1AW9R/05ll
zq5KakNKfZPYpmClXnr5dvLN0kO0mx6kHWjFfrSjWK5penwQu91Hxpzfoeu8
x6bkzSa/BVqono/oFnMb8e03/IxCcaNynNBfDn04jzPIexcN3kyBXpfSomTu
tDB5y3St3DmaocVsM5J3bZ/lN+zt3fE2fqK55B25j+Xyvcg2xHZBLT8k9yt2
hG21da1ZN/IpdwcpM6mkD5lL2nq1mAI1fUjH9TiRbwGq+Twspkp8DQbkvZj0
q4aN3tqz6km5tyG/t0Kap0X0M3H3xA3KfZd+INc+vGCmG7BS3Fbxm3HC7KY5
t07+x/AEMr5P1u8aesS315z5pbm/Qg/Z75F/p3uc6z1e5pNedP9/1f//ONH5

          "]]},
        "0.2`"],
       Annotation[#, 0.2, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0ltoznEYwPHnLWIYaYRsxsbG2MyGxhBlThcTmtOElCZEUqiFaRK5oJD3
giglhbJwsVIOc8p24ZTDyJxGarsgF2jDZxffvu/v9Jze/4h1WxdvSUTEb1QN
ixg1IWIMbo6PaEBWRkSPURG/Jkd04OGkiMdowqxM77gTme5mY1y6s7yIQh5r
nYvu3iXQmhORwqlYaH8JVrm3yP0KrEBvudbyvXERaeq55Pfygogr+RF1OGb/
ODaJ1VzC7mwYG3HEu6Pob690aETbaPVxS1HEe7zD3uERy7Ii5k+JWMrXJ0Zc
Q5N+5+ilkcv4jX7eohlfsiMuq6GVy0ZGVHs7m5/J2yrXcx6MG+IN4Vz+6u4s
Z6/lb1dHh7w53nXyaetTqNHDWU6MiJgxJuKnfuaLe9C7q2bSImcdH7Cea7/e
eSkeWQ+UJ6nnQdxkPd3+lNyIF3o5LH+BPgpRhFKxs/XxwX55ccQnTut6o7bJ
zirU8NJstqjtKW/nIe5MU+8APqeG32L/RVJNx5BnRhfFvKXPM1zP57nA/Ivd
y8d9sb+Llar2pfIlxNktfi97O/kQajFTDzP1MpWfuLdSL6O9zUK5/71WnR3O
28VcIHe63Kvlmi5nBVdiedf/5Jv65lt9Vuj7xBqzWIWH4n4x6za06Okbf+Te
7jY478tJ3+EJZJpPOhrVsM/ZfnwQ6zO+Yp55vOM3eIU+1nvcOeF+Erf1tss3
eperOcP8D/Aj6xp+wLV8S18NuGP2aep5wBf084SbcNKsurkb6vyn3yIzqLTu
Z72We6p5Iw+wXs9/nHdTS4l1Ck/Q8w51VaMK27AZP/Afo0Gnig==
          "]], LineBox[CompressedData["
1:eJwV0VtoznEYwPFnK9TKWrhi2Mlmm43ZHN7QylpoG9tqN0oxac2yN62FHHqn
zSEXLqSkWcrLFs0F5cINsgtJpNbSWpGyjeRCOd3gs4tv3//v8Bx+zz+/Pdna
nRERb/CyIKKhIuL5yojGNRG7UZcbcdRePddXRnSsssedPFEWMY7UioiLVRGf
+TzP8PuaiFtz+azPWhdZT+RH5PE4F3DX8ogvcn/FLKZxVc1e5z2FEVWbI0aW
RaRLI+7gg/1r6yKuYxAj8s/K80CeaR6yNyXmnnr71T2jz9RG9bHD2S40YEF5
RAvvQROGiiJqSyK2yTMo596EPS5Qr79az3yOX7tTstqszOe3Om+5170W93u4
Ve/NmHJvobOlZjPpO8tbEhvs8VZucrbY92FxOVyu/k7zbZdz3NlD/R/U/yOe
lO+vufxy95n+Rr1zjO/qexjbrWsxI2+mPN/1l8hz17z+FUe84kw9dOrvsXtH
+AnfkHsUWWouMuNm7HPWqM4Bvu0s2/wO+c7kLMxHj9on/fumTRFtaEHS+hiG
5+bAHXL1qTuAed5Xo7cMXmIeSfElYspRiGqsRVrv/f7TTb7A2XI04oTZPzX7
0zyAUjX6uM7ba7EFL5yP4ZP/+tO8rpjdZVzCgPVH8/smLqF2mbe/E1/MU1zJ
uXxcfAqnMGIvxxzT6leYT4fe74v9s15/ZvuDBzlpv1veLv4PyuCHdw==
          "]], LineBox[CompressedData["
1:eJwV1nt0z3Ucx/EP5XTZUSPamGiZ6zDSaC4VHZWW+6LLaO4hqVONTXVOTkkT
MndGROkit1mdWrHj0lCtTrmEndRGEg5nJKeYHt8/nuf1fX8u79vn8/19f4kj
Jg18tkYIYVjNEBp2DKEu6iEW8bgV5beF8FbTENLuDqEowVjLEAppZ/aXzUJ4
09zU1iGMSglhBDokhdC+UwjFjUNoR1PYw4xnIa9RCDnWtmoXQjKatA2haxPa
JoQnPaffzhe/M6zbdUcI06P17N7GZze3T9xenm9IC+FBmiXGt3eG8D12YQ9K
ccG6La1CqKL97D8pzynJIWSjrT0FdAX68Plj5xD24SdstqeFPQP4GIR+kS/5
PUqH2bde7Tny+se+DLntV9tsufxCf0Ib4yXsVnQyP0P5y8LH4ufwv5a+TFP1
IEdfl6t7tPl4udTD/S3UhYWJIfyu9ydxHCnsVfqTTN+nBXp3j1wmyu0d+hzt
QZvIqaJDCOPZ5XQsPUpL+NyBF9gn7P0LZ/ABfxfpeZzDFPMDUkPo5kwzaDa7
F7+rza1CmvG+xnvZd9l5ViNdHWfl2JtOcN4TMQ7PYxLm6ssCzNCXefS8PJry
u4yfIv6W0AQ9aYDW+vM3P/U9x+EWtDR2hA7W00M0g47jYywOskv5HWjsJs91
0Nz6bnrZlKbROnrdWJ4JiEeVeGdx1J5N8tuCke1DGIM5YhfysQWP8T8EW/lY
wle2scl4CUvZQ51vCg6aT8BIDEexGhvR0e7Lv/qyPuoxXUcv0V32dKV/uL9p
9E/anVaJfUAO1daNuCuEO8ROwnT3rSUtd09+wV/WTzM2SN2v0qPOpxJlctpk
bC8tUPMn7kKhPp92/zfQK8aXeD5i/LT5o3Spe12Pv3waSxfSa40/bl2sOh7h
v7b7Uwf10YmPz/Vut3MrpN/RYtpfziv5/JmdK8fJqFbP33p1CVWoxn9Yzsdq
fCrXlTQr+i1BrJiz2TMx3tl8a34sXcbPVbnks2ua6y/GZfYie8aIW6R3n+Mz
ZEbnR7dgIzZjE+bq5z18befjXnozP3WjfrBjaTv76tFl7FvpcDHWu+8bUSDO
jfq7gj5La3QJoRauQYm+Vsn7As6hu95NsKYHPadf53EGedaVOsMY+qV8Jsi7
sbNOxEix4+Q3hn7lLu5U2xe0lDaU61Y5xdEPzT/FR5b8esqrC7857tig6HeN
PqrnuXSR34fFWIiJYj2DBZ7zMQ9zUVP8+bTM+9DDvhh2F76TxYiRy3b2AfO7
6CGaKtYkvpdYM5FetOcShspljfwy6Z32nvZ8Bqfwmt+2SrkdQ5zexGOUHvZE
nvwfpOnq7IPeyFBvPzqQDqKP0QF0MD2j/lMYy57DPizvcvyKy/LoJPbr4k3D
FfYsa+7nv4GYZ93hP+Q8XQ3H6YnobqupUA6bsdK6NsZGO/My9b7tTGZhNvaq
912+K/VkJc0zNgPfWXeLsd/5u4nuZk8z/gYKrIs1VhDtxTa5zDGejwV42nvS
Vk92eBe+QQk6q20PLZfDR9G7Sfd5ryroQdrIu3nSvcrn75T69su5VA17sRNb
xU9S5336nkhzxMnGC7jePc2Ivh/R95091PNgOa5lP+F5DR1C3+GzSB7pnmtF
+xCDYna1Nf3s6SP+RvaLcng6qif6zacb5PCw8YLoO0CvE7NJ9M2QS6ac3qMP
GV+nz33teYX9g95VsI+hEqnsUuOdaDotk8sVOV3gu9K5HkMFSs0fj87Zmo56
U02TvFfNMN97l2vfVLEznfen0bvBzo2+bdE3mU6mU2gx3/F6+jWtzV8MZvE3
Ew/I9aq7VUNt12CpuhbjEbmXu4O/4jAq8Bvec05r0E0d2/hryO8BZ5YU/Teg
F+3rEP2X8tyWHqYptNTa/wGY8Z68
          "]], LineBox[CompressedData["
1:eJwVkU0ow3EYx7/LQVrSWmZmXub93bA/myRFDm7c5KCklDJvGxpxcHBwcFEi
BzlpyXE3JyeNknJwkEKKmb/mJXLg4/Dpu+ft933+zzzDE/1Bi6RtOC+Wfpuk
/SJppkGagwXoJr+KrsAyHFBPa5ZOyqWNQmnILzndUleZ9E7vaED6Qvuoeemd
pD5G/ZhcEA0R+8jn10KdFKDvidwU8SvxNfMmfYZPekPX8VwDK57pcIRvtEo6
hMsKKcZcLJ8c7z8x8wLPYBZIjzVSApLQQ1310nylFAGTfWfxncEjQj2MtvH9
7dACJ+zlRy34xdgpDR0plVLV0ge9Z9Q/mY+j9x6pgZ4H9BZ2vdIeWNukLMiE
Tvx/+L5vyAWDORf5ZjSHOJrHb94Ll3B73jCYb4UAxPHNMqRT3shE7WCDG/ZO
8f3vsAUpdtj8j9FxbrLD3GKLtATp9FshAxLcZppbOvBJcNskmHBB7OR2bnD9
Qxyiz4nOoh3429i1kZ0d7O6EbOIr/OzoHXcZoKeXeBDd5n9OcEMTklDAm3+A
0Gi6
          "]], LineBox[CompressedData["
1:eJwN0e9rD1AUx/Gj/C4kyoP52r6b+W1sXzajtVqjtTWyVlbUVzb7odiS5A/Q
ismPNWu0B0RJkgdoKNLyKylprbUkMV9rk2eytMjrwbvPvefec87nnps81F53
bEZEPEfb+oh/ayPKCyPKsAON+darI0oSEb1bIvowsSliHBksTUZ0pCKqsyPy
10RMZkXUbov4mxfR7qxwc0QKbfJ75LbQ2SURczETWerPp9Puf7aukZtRI6FW
lZrftkb8cfaVTtGBdRGDyyMqNkZU4jePv9Dl7umciDPyHzl/mhvxhHbZd4oP
ror4ou4LupCvId6HMYKPfI0ixVuSlzI+smk5fa3fS/yw/omkWteLIvLoDVq7
gmdzq6EjeqXVrzbDSlShxTvq6G508njQrJpQjwNowCI+lxWbBZYguVJ/us97
j+q9n57w/jQ9RZ+5/118EnvcTRVE7HK/AqXOxvTK4L5/O28O49Zj/D20n7Bv
1nOWGbz19ne4KHbc+RHxeeKtdA4dM68BuY/xydv7zKQfV/FA71w5d83gHm7h
Dm6jw5vH6VkzytBztEePhtKIbprgNwvpDfw5a/KPH8ytmbbisHgb3nhLjnuv
aKP9SXUX87IAF8yyW+4lM3/v/Iq6Q/Syfa/4sHqjKBbfqe92upffm/65yLqf
FtBrdBpT+A8oLIKx
          "]], LineBox[CompressedData["
1:eJwl1FtM12Ucx/GvWzfZwDU7uFkmICKKB0REwvLGWrWytJlC6yA3NiOFoUHK
Icu5CBKQyq2aXoSZFSoahSZqdlozPAaiw8o5nRe1Rrq5DrNev3Xx/n+ew/f5
np7n908rXbFg+bCIeMpP4biIVydGrMXySREHMyNemxDxJS0333xXxDrz+qyI
rLyIo2MjMuhJei0tIq8w4gp9PzfirzERW+h1uo1eujPi+2kRvRgxNWIk0u+I
uMzXePrdjIgjWMn2GB10rsK4BtVoNv9IDsXGCzEflePZON9o7/6CiIfwwJSI
lgx550e8SfuyI06gIz3iafl10r0oNe6ibc4ezxGDnz/YvWN+SJxNdJW10ukR
z2DeZDGRiwLMQKuaHtWPBZgr1sP0QTSOjhg3y9jay3p22togLsg3Ra+a+NuA
59RQhmVYrAd/610JXersCHYH2bewa8Uj+jUPT9qvTe5J/nX0nBpS3dc/tEbt
fXLvR4txM340HlLHrXdHjJXLLvM0ekmMtfzfx+dcVIhRjh1y3qh3O2kb/ZPt
L/rzjX78TL+lH86M+FzsdtpFP6A5ai5BB59N6tgu5hb222i9PvV7J83W9+jb
dbkf4mepug/TQXs/4Sza2MzSqyXifkwv0iJazNd8tS+ieWLWyr8p6YXa93uf
O/jsoe+yH66O9+hNtF/sTDX30W5npsrvivlVZDn7O51ApyEHY9R9o7UUPCb3
zWqrcvZm81rz2d7mPSjCkFxPyvkETuEYXrd2nB7wFrPE+kzMA863Jt8T7U2+
G/yABrb96unUgz46gNPYz66FfQ9dpV+VWIlO/d3rTr/APnSjS83NYtXJ+6i+
NOpDL62R67OJmi+h1fZfwkz5dPBzi55+QvPNq6w3yOE3+eSy/5Wucb7dGxxl
vpV2y6Xdt7sVreJuRJnz0/XhebpbrbPZFXtLVe6lmt8i8zZ2m9zzEP//8lWS
vGGsZlOp3xvkvkcNb9BPab286pCiP6mY4w4H3OW99Ayd6D4mITtBXel83Cb/
yc7cTjPMH2d3A/tsa28bv0Jzk7Fc3sIc73o026/4+BqHMcjXETW+YL8cy/Ai
KlGhthX6UYYn1DoK+4zX21uHU8k35/vL56cAecjn76K9CziPs3owgPViF9hb
Xfj//+1/WSfyKQ==
          "]]},
        "0"],
       Annotation[#, 0, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0ltoznEYwPFn40ouSBTb2GyzzexsWLlAiJEYaw45rbY0MzmVoly4YGFR
lFKWlM2VO2E2FyJlljmEhMi5FRarbU6f9+Lb931+h+f3PM/7z6jdWdWUFBGf
MJgd0TY7YojbeV1WRPWsiA28htfzgtSITYURv53ZyFuwGcPilJyISfiSEpGZ
G5GFj9bPy/WBW7ljekS3HNtnRDTidX5Ei/vL3HngbiWfEB9HZUnEUhyaHLE3
IyK3ImIPX3BmF+eId/NR+z+mRqTNcd5etzxLOFX83Xq9t+tQXBxRhEI0uXer
zF6mmu1Nk+Oq2n6JB9Brf6v1A9bXqvEg14oPq7k8Tb95Ea+KIl7iBVrMpt6M
vk6L6EO1eKW4hqt4Fa/g1byEl6MSi9XZrNdj6BJ34p4zQ/IP4rK3dsjXrdcm
bldLG46o56X+Gq3dQLLZjkCSeSUjy36Zc9ncIc+b8oh+fb3mn/yWx+qx2pma
BM706G2f81Xi/Vwhz/zE/6vvTWbappYJ3upUy0S+q85r6r3NHVyX2J9pTpxu
xmlo8MZ1cx41xXk5mrlP3n58wzzfQoPvZC6XmuNMDCa+J4y3dqk0Yhw/9uZT
9KJQnVEQccX9v36PxE1vdCHPm/kowMPEN8LZyMQOcei93swXIcX8nunzjvz/
5Ery1iD/wTA+O5Outql4bwbbvPOO16vthm/lvnt77NUm5sZjzHA0WvR4Kj3i
pPw9zpz1DT7i0+Iz1p+Y3XOUW1+onwpeqY6LZlfi9zku4FYewgD+Az9ym8I=

          "]], LineBox[CompressedData["
1:eJwV0ntozXEYx/HHJeSPJf5YbC5zv24cxzZKLit/kJKS+IOScMyxoSlkYzNK
Uiwk8cdWZm4l/OGSy9QIC4skkkRoIRSmjNf5493nPN/n+32ez/P8Tt6KsoXr
u0TERzwaGtGZiGgcErGxIGIztqLE+W5ajUqcke86OeLeyIi6wRHLiiOycyNm
j4j44e6qqRG/6AK5AnfL5FPyzc7SdJN4svPc8ZgQUezeJ2fl4q/iV95/cS+Z
jPhO9+u5F7317IHr+jaNiTiHp6MiLnvXltGBhpjCGzq97UG7oz1PD/EnOo1+
zonYPlpendNFEedxFquHR5SiUv8U3ZLxSqvFFTSNDdghLqNNajznface+4dF
VNF99AJfrbycmxjx2r3bhREv6X1n6/K9RQoV2IhyPtbzX4pFvGXjit+1cjVo
GxfxzO6S6hQigaR67+Te4g1eTOIFtTwUZrzzWJzxPpZfpNW44fvs4fkWLRMf
571GXKnXSHtt9U2G0if0p10l1PhO69XtGBRxgv6lJ+l7s9wz30Nk+TZ9kWdf
H9QaQVvs+T628T3T95mBdrkcPQ/qOYDOy3i1r7l0Cr2qbn/nLea5izv2MF+N
Xd41mPmieerpJVpiptmYg4S3aTtP0rV0DbZ7e8Qs0/k/RGfQY8g301H6h9/f
+Ik6+QNI8LHYbhrcWUJL3Kvyf5xFT9GbPDWre43/vubpgxa/G/V9TB/gsNm7
2d8//+dOs0xyf6k4S83ltKe9pWg/8UraId/NjorEvehE+60w81asQjlK8Q3/
AUj1new=
          "]], LineBox[CompressedData["
1:eJwl1WtMFlQYwPEHdGWbFrNMQ6FAQblqZfICQclU1FmpzC5LV1GSlIkzFTZn
1oq5isgcLpY1WROahK2wm1uF1qoPraTsApGU0+yyptPKtRmuH+vDn/97bs95
znPO+5JRXbd0TVJEPO5PQ25E75SIpuKIQ5yuPQlpmKhdrz+VR02K+KEwYgBf
XB3xOWZcF1GZFbHLnPk8F8VFESUowjztBD+ZE9E9MWLhNRGnroxYwH/yzdwo
7pY8ueAf89vN/4tfmRYxQg4XolV7rf4WXs8rcTgzYpz9v+LBqRHn5TWEfzFC
3GRsNr7B+o0odIb8WREFXMC91vTIa539P5gZkaT9mfb57IgDnLgq4rQcksw/
IU65ObPRMSNiDz5Ki+jSPsBnnX+oIKI/P+Kt9Ihqtenmw854T0KN7JErziWT
I2rNHcuLjJWKO9rnBF/E/XK4Qq4TMNp4n3aL85QbH2d8+fSIFdgk3npznlOH
t9VkG7/Dj8n3Ubwn98n2eZ+PiZOwphiLretx9grxDsmxF0fEH8SPyJB/DrKG
PXweZ8jlPm6XS7VYedr3cj6XiLlUzGJ73m5NCR831sl3cxFvzxDnWvtgAAfF
qrFvDw/JsVucZnO+MfaIWnbYZzMXyednNZvFJ7jcectwA6arRbb38ov+2dpH
zV/mLm7DLajCEuz35mq9gwdxP+rwELbJud+6geGYYhSrSRlKscWaMXLILHFf
vNU+jdhpTYq1Xc51MXfy8+q4Ty47+A1+WP85/ZXqsgAVYj/h/ndZe8ReL/Fe
Zx9pzquczHfI80587E19imPOclDdnja/TcxWb7HZ591qlCOP38W8VV7Xq0sx
stGphl14yh00oVKM17Tn8iJzG73pC+QxCoGRSEaT8W5vp5lX2rsa+9TgdQxa
c9K5TmO8s6QiDSlyScgj03sr5SxOEWMMlljziTv91uca+65Clb4+7WX8PU81
fyxfjsuGv+v2ztE3wedUtNrvTed+gTPV54wY2515q7gtvA1r5LcWq7AaD2C+
OCe9oYU8JM9zmKNmN4mTEK9NnV7GHLXdIG6V/lL9i7le+5SxM/gb7db9wb8N
vz2sM/7h8O8FBt1bjfYA1/JRTnevN4pbp/0sr+Yy3mntbveQK14bF/JxOf6K
n7BDe56YFbhULcfjPvf9ojtscI6Zar1JTTrUp4H38F3Gl2OjdzpNTXvUJY+/
VJfv8Iz211wlp7P6G/w+7pVLF1b4zvW793p9U+y9X7x3UZ/7//+B/wCE3/z9

          "]], LineBox[CompressedData["
1:eJwl1Hto1WUcx/HvQMihNZsxMufOzqbO1ZZ61tZxs2Tepsm81NaVlDWZDHWJ
ihYOBgNxHErNQPGCiiGpiM5ZsP6I/SWhgi0o/7FCBoFLBUeB2pj0OvjHe5/f
93m+z/f2PGfJTz59uyMnItL+FNZGPCiL2DCHVkWMIDk3ohjriyK+nhUx3Xcp
StBZEnHjtYhb9rawd2En9rLPvhLxvu8mrMbWmXzEzthb8nrEcjS8GrGvNGJP
tdj01/KIQZwX9+N5Eb20Hy2+v6MHnP25Qg5xRvgdZg/Ic5But9aSiliLxko5
MQc1qML+aREr1b8Gi+RaQZchM1U/ad/WuhIRN63dwpB6JxZGFIg3BZORQCE6
+dWJWY830YxNeOTcKHpmsPX3WTGdHdGBM2L97ew5WmW/yH41Xar+xVn00GcO
P6mjl16hx81/VTIiz308j2Y9nLT2Ds2Y+xfowSSz+dw8fjCbMXv/iv0QIxjD
fzgm1ymcN8sTdJ2+a5Cn9y/ZGbTr+Zr9NnpEnCfTI75i59hbpZ5R9mMcdK7c
ufHm8L1+Lr0ccRm/82uw/of9O9k50kXsJRh2/j7u4iLfqfq9jVY+p+X7BjPN
q51vi5jj9N1KN7JnWR+0/5YZD8i5Qp8d2fs11xo+W3z3uf8hM0iz62vkRMr7
WqneYfn+wo/2dprtWjVsox/STdbfpUX8i/nm05dQgOf4v2feH2Vnjlasw241
NMq1Bm36bKDr6VG95KplAp5BHp5FUp8pd5ygY+5xFFPMKse9fKuvYr+7s1nV
Z5m6yjEDd9zrBX2VuYsuPZ+QI8zlDfn+4b9MvXvMp0+df+qjl+5mL7Xeb78W
V9kvyHtI/gJ6nT3felrc37ydjByVfp+zMRe1YpfIfdt6o16HaH72jN6q7TWp
4aZ3vFmtv9Ct9EU+dd7JZHpKDY/EHsMhNR1AuXmdE3Mg+6ZpPz1NK80gxa8C
V8R+INZEtTfLF+J0ip9rbQftQTcW6GGBXubRQX4f6KXM2SQa3Xe3Okft3xNz
oTzL5U8knv5v+x+iOMHA
          "]]},
        RowBox[{"-", "0.2`"}]],
       Annotation[#, -0.2, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVkckrRXEUx78yJQsylEzPM3seHh49IYqyFEksEJFeiZLyLzwLU2TOgrCz
NWcICyUzC8lYFkpJCuH53MWnzz3n3HvO+f2uuamjst1D0ixMRUsNmVJBrDRv
lzx59oIaYl/sA95QSLxA/TpRGo+RxhzSZaQ0Sf4CjxKPkR80SS7cS7xFfov6
Nu4j7iG/z/cd2VKwWXrIkB7hCUZ47x7fwS0EUW/nvTL6DTHXQv3PJrlB7LNJ
3JIkNYM9VUolXk+R3uKkmxzpHd/hQPpUUa82oH5olbo4cwVxN3bQqzhdqk+Q
6ug1HyWFsuN6nhSG9+KlpVxpB6/iZqPOPo3YxC6R4GTGMrv6sesePVz4hb5v
8ApFnN+ZLOXjTM6WDZ/M/IYQcnNZnBefMvMcjiGNPd2wyPe/2BPWmLEBycy0
gBWOmJ2I4yEW2ojdxt1ESKUQbvwnzrlL/z96iVmf+Ae+4Zl3TOxmhkfuoJU5
97iW3VYs0gHfdVJrNO4NB3CH/tDLGQf4n/30PzT+PzNP8BDxMPkz7u4K7ORL
OI8Dl7PHDHdn43kCW/E0/oIP+Ad6iXEr
          "]], LineBox[CompressedData["
1:eJwV0ltoznEYwPFn02gXkl3sZgfmzOzwbmxWEotrJQ0XXNDmNbPXNGW1dzPl
QhpaSC5dzDDlsFJssiKRSOSC5noxcyiH0fB5L7593+f3/A7P8/zfkt2pLa1Z
EfE8w4KI6aqI/vkRbRURh9GBeuvHuQdpXJXPqo54vCSib17EzjUR+YURGxZH
fLO3sS7iB2+WK7e3VT4pP2qthQ+Jq6wXrERZRK1949ZS4knxO+c/2Ve9KuIr
93rzBHK9mYN73h1YHjGIV0sjhpx7mXFRxD9nslbrg3N4Bj6UeEM8znU8URDR
uUzePVdqI67jGpoWRTQj7f0kH8nUyj3idm7BQXSLW3nAHW/UftQbvQsjuvgk
31DXM7UMVkaM2fegJuItP7G2v9xZJNGONqTUcUD9zdiqtnw8LNWn+LWZjfAw
ctVTlKnL+8VciN/OTqHUmc96SPs9yd2cYy5p9+eabZf4pjtv4xb+iO84MyI/
jDx9DCXkrQ8hYVanzLqKT3O62PeVf29+YxgRf7Q+gQZ9bsOxTH9637giYhMS
ZtEiruZ9vBed3jzvzFr3nuV1fBFlerrAU77zT3xHn/wZJMy1wX/rkj3bud6+
Lv+T9XyZ76t/1L13fY+5ep6DR373e/cFP8U5s8v2n/trFtN6rbR/h3i2O3fx
TLUnOU+8h3/JZ5t9jXgWV+i3Xd8daEQKzfiC/9EYjMY=
          "]], LineBox[CompressedData["
1:eJwlk1tIk2EYx//LDppfjbwQKyuHm81TrbJcaxet0gZRmWnkgUqTkggFK7oo
BuUQcq0DSeKBDZoFS+3gRemdZIW35QGJyqigzIqoi2AE9RsJP//f++55nvf/
PO/3WWobSxtM4o9/NQ5pYJN0H95kSd82Sj8gda20FNLBnCMV5koWm+RCrai5
UDKghJxnm6W96ChqrJMKVkp/eD6+RvLmS/dWSTvRfvQLtZOs0gyaiOZskCYy
pC7O6YaUFdLLAmkJGnVKy6hxNk8KkH8JrnHOdaheLqVR7zHnDcEgfCRnlppf
wZEpZZIbhnPEbrdLV8ANIfY6IUK9bAsxaD76AS+fYBraWBetljyQQs+pcDQb
n3ipRcuZWxnshwCx4+TY0GRmZUAVMQvRStSDry7OCEGQuFawE9uBhzN4y6BP
K35HibtMfDPPp5lfC/qdHr3rpZ/obtSfLvnwchF+cw893MEv9A59zeG8+dDO
upH9G+gptA7qIY2Z16CH4Aj5MWqFOTspPk/6SqbXC+w94jcfmsi6CX+TzLaa
88fQw2gRPmbRbehnNI9cO1ihgnUf9SrIy4IX1DrPfdziHBP97cPTXPQ262Hu
vYMeA3h/y94QezHmYvAeGNSOUEsu6QkzHoFpYrbS3zu0jHfkAOyBUiiBQc6r
J+8EHIMGOAlX6WWKvFfgxouTd90NLvCRY9CnhXMWoy349UMnOWZye/GwCI2i
N5nfAH7b0AdoE/sx9ovx6wUPtZvpIUTua87qRvuYWQIxd1ETehCflfCUfp7D
e3oZpv9W4sPUbOf+gzxHmIMdHzPULMfXFt4VJ9ggynvUG/8e4t8FFFOjn/UO
dBexfuY/Dx8L4C93nRCfPQT4/SHrIFrn+P/t/wNKLaDg
          "]], LineBox[CompressedData["
1:eJwl1G1o1WUYx/ErhBKtmYHotD35cPbgdE03nWKipmdLTGTMp0kSi4E03UAw
jZFMEQ7DiN70osSZclDX1DSCFGVvHIKI+KZwlDCmhRZBC9tcY7Y+f3rx3e9/
39d13dfDfZ8VNbXVt74QEWX+LC6N6ExFfFweMSMv4iPajocLIzoqIz5dFFG1
NGKwMOKriogzyKK7KOKp/R46TH9lX0Yf0RqamRNRW+JsOrfG97yIwwURP9r7
CYNyTn1dziURs/Aa8jEH7fxWyrsGb6IBLXgmbgyZBdbLIw7K1aKWfTjnrN/E
dtMl7HnsVXSDPt5KyI+4Uh1xSx3f0D56Up2b1Z/zRsSraND/KXv1tLMq4jgy
mDY34pA5XTWXcbanzh7BEMbxD07IdRo9KyK66G59VyNH759Yd2KPnm+zN9Mv
nPN8fsRn1sG2WT1j1qP4XFyJuJfM4Tv9XC6L+BY/80vbf8D+OJkjXWe9Hk/E
/4HfcYnvbP0OoIlPVr4zWGBee/i+58xJ+m6iH1gX27/H/rYZ98q5UZ/7fFeY
azWfNt9Xit2ZGSy3XrNMTlQujnhHvU/k+wU32D4023fVsJ/upC32t9I8/gV8
p9NczMAr/LeZd2MyczRhN46pYZNcW9CszzR9n36pl8lqmYIXkYOXUajPSnec
T8fd4xhmmVW4l7P6KlgZcT5RfabUVYL5eOxeL+or5S4O67lLjgk+w3z/pavk
vcD+0LvqsB6kR+gjel2NKVqCYvSrbTbbqeQNJ78Vulc9S/2G+r2h+9hhntuR
y96VxKh5SN42Pn/RWqRRZi671FJK11nfMcNcs/tbzTPpCG1kvyvnsPqeoTd5
z/a/p1larv9K+wvRp48/5ZwqtsF9T4hrl3+yvQM0k/SF1epdraYaeo/fDnNI
iS3EJnd9RNwY+yjqrdfKVae2H9SYFTPqu0OOZnd7lLaq4az3vZcWqaMAN8UO
yJvvzK/FXLO+joxc680hjTo02htxXnnp//+j/gM1f8Ba
          "]]},
        RowBox[{"-", "0.4`"}]],
       Annotation[#, -0.4, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwl011Mz3EUx/Fj5qHuSqMhCpEeKKm0aVh6oA3VlpkwTzO1uHFB0ypbrRs3
5sbYzGLhJsNipjzesOaGG2wWc81G+teFh1dz8d7n/z/f7znnc87v98s6dLLh
xIyI+IK+lREFqyPy8Cs3Yk9eRE1RRBUq0ev8kdhD3FoSkeHep8yI5/4vWRWR
idbsiBvlEW20e0XEkdKITppQr1/O23w1/d68PKJ+jbjcKXQtiqjzf6ma2dit
15sNEWVyKpxX0K51POAU5ujbTv/Ia3QvWY9vYi/k5vJRiDwe+ksihvS6Qofp
hPg4RuXtyTGn+Hy5P2k6fc3bFh5f0Sq6FZWYdJ7AKI/DdjGCndiBHt4u6XsZ
A8sivtNmPYbMPqJmR6EdoBtH1T2qzjEcRiuOow2z+JmJi7zNpfnmW4NcDC+N
mC1Wy8s2JPm9fnFEqnrzsF2fx/Z0zt4GcVCN69PPAnXOHjhL4SkVzWbYi0H5
+9U5gLNy9tFmDPE/WRCRY5YEXU0vrOeFhyfmfYanaBCv9awb6Rm7f8bHS/xV
4zeK1SnEB72KaNq0R+cJd+vl1MjdRct4KkXCvhLu/LKnCSTZ64D7TfJ3o4mX
dLn7zL8fg2URd3B3bcQ93Mcxc7aI9Zj74/T7Qqd4mUCL/EZsxCaUo91MC93L
QAoWIA3JdjNmJ+/lvUOHe9XenyzvWp/dVov10rJi3w5PJfQrHae3syJ+0Ju0
n6druIox58Xi5/XttL/PvLab4zTSMjyD/P/f4D8wQZUy
          "]], LineBox[CompressedData["
1:eJwl0ltoznEcx/HPkmbKlQtnM8ODZ7Yh59KUKC2tpUxrI4fcTQ7tRstMYjPK
obXEalhbbRMX7iwXaLdLuXPlECkXFJKUl1x8ej/f3+97+Py+/6fi8InGtpIk
j6lzYTKzkDRXJTNWJAObk1/ODhaTlk3JIZqzITmOR+gU3VietGEfTl+dlNDQ
yuSb+L7zH3hefQdd0Kt+XfK1PNmNX/BiZXJ6S9KFV1Ylk4uSSr/LzT6zIOmv
TgoVSff6pJfurkluU528A/LLzPu9NNlrzpHFaE4D1YsH9d2D3/n5qVejnqXL
+KTmjd6F+7EFD+Bbb5/i6x02LUk+4Hu6znen2u3yavmpNv8o72vwGNbgrBr3
9jYi3iV+zksvvsAebHc3T+2IPsM0m/8BNXepyruK9MbOx/l4+M9brX1Tj7z5
3tONreIWGnM/SrfkP9V7gsb0H6dL8uaacxm34j7+P/Fd0OOePfba16D99tld
qfwymrCfZzTgvN3O7mC3vJve3cVrnfo/Zm3Dc+Jrzi+6f2m3j+RP4pB3X3I2
jFf16qF+fZ7Z4wM10/hpkBccFJ/Va4qn5b5LE43q36S2kp8CFemjeIfv8Rl3
Yiu+Wuvb4Ws8qa7U+zr4eVL8///9C+JDcxo=
          "]]},
        RowBox[{"-", "0.6`"}]],
       Annotation[#, -0.6, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwl0D0vg1EYh/GLSOoLmMTTVLxVQ6veRwwmi5EgaUREhMlEREJsdLDZSIiR
0M1DvST4BFT4AooBY4lLDL/8T8557nPf54ll5ofnyoAJfbfDSQxK5rFZUwvX
PRAJYM/1UBusud7sgKw2FLj/WA+5XiiYCwl4MN+6YbEBXsxXFVVp7aE1R/pK
wac+FPWOYqff6b7VehWUjENapSb40VUz5HUp3K+qg3PXoc40br8n+4yZz+ag
sxy4f5eEW91o1Zp+zwbUpxFn3fGuXV1Yl1doXSpq/zScmnGzRQlFnGOrGsrN
Cs0687RmlNGUJv/Yd8W3LWtJoX1zXTDaCO/22vfN2+Z68P/ffwGAZkhs
          "]], LineBox[CompressedData["
1:eJwlkskrxGEYx780xlKuLtYZY+yE7MtMKaVpknU0WWoOuNhz0WRP1kRknRpM
Di4uLiQnTW5S/gEXpRyoIUnxkcO3z+953/f5Pks/k2ewaSBM0g6KTpcmE6Tz
bMkLjcRD8dJDgeROlu5hJ6wtlJ6hHT7BrBzJiszIRXxqheRZ0B1e4xbJXyb9
4NmQJoUnSsfE1ynSdqq0mCGtoBNy57OkAAzy7qxcuoFznK2SO0FOBV7f+Nvg
NPEG5wvc7+MzxnsfvMbrCkXRjxFtZUprvDk0SZt8N+NZWSq1wCrYBO2wFVZD
G6pBseSEUAT9nlArhrqLzLOA9qhz++fD+SVzXlBvhn3NIidz9eRLvagPuYjv
2NUjd+0lUge9t8Eu6IYGaESNeH3gFcKrHm8/8zhgA/WcyJMEib/MzEZf7cxi
o7fdXOkALRfRG7Iy53aeNIpXEp5meg3ybon303yP4DsHX9hzHX29QgecYZde
6kyhd+ocsYM3GKAfUc+Atoj7OV+Hw9CDelBcsdQNO1AX+Z94+agdyc7cOf//
1i9sy2Dw
          "]]},
        RowBox[{"-", "0.8`"}]],
       Annotation[#, -0.8, "Tooltip"]& ], {}, {}, {}}}], 
   {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJwVk2tQk1cChj9yIyEhAbmUAYvBy4jAImUpwkA5RwGNVgrFFK2KUIqCGZTL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     "]]}},
  AspectRatio->1,
  Frame->True,
  ImageSize->{400, 400},
  PlotRange->{{-6, 6}, {-6, 6}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 ImageSize->{404, 400},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[6]=",
 CellID->217697153]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell[TextData[{
   "Options",
   "\[NonBreakingSpace]\[NonBreakingSpace]",
   Cell["(1)", "ExampleCount"]
  }], "ExampleSection"],
  $Line = 0; Null]], "ExampleSection",
 CellID->2061341341],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell[TextData[{
   StyleBox["DistanceFunction",
    Editable->True],
   Cell["", "ExampleCount"],
   "\[NonBreakingSpace]\[NonBreakingSpace]",
   Cell["(1)", "ExampleCount"]
  }], "ExampleSubsection"],
  $Line = 0; Null]], "ExampleSubsection",
 CellID->20803],

Cell[TextData[{
 "The DistanceFunction determines how to calculate the squared distance \
between the control points and between the interpolation point and the \
control points. With the default setting ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["DistanceFunction",
    BaseStyle->"Link",
    ButtonData->"paclet:ref/DistanceFunction"], "->", 
   ButtonBox["Automatic",
    BaseStyle->"Link",
    ButtonData->"paclet:ref/Automatic"]}]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  ButtonBox["DirectedDistanceMatrix",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/DirectedDistanceMatrix"]], "InlineFormula"],
 " uses the square of ",
 Cell[BoxData[
  ButtonBox["EuclideanDistance",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/EuclideanDistance"]], "InlineFormula"],
 " for numeric data, ",
 Cell[BoxData[
  ButtonBox["JaccardDissimilarity",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/JaccardDissimilarity"]], "InlineFormula"],
 " for Boolean data, and ",
 Cell[BoxData[
  ButtonBox["EditDistance",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/EditDistance"]], "InlineFormula"],
 " for string data. We might interpolate between words: "
}], "ExampleText",
 Editable->True,
 CellID->465813429],

Cell[BoxData[
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Obtuse`\>\"", "]"}], ";"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->586163291],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Interpolation", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\"\<All\>\"", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<that\>\"", ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<is\>\"", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<gold\>\"", ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<does\>\"", ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<not\>\"", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<glitter\>\"", ",", "7"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Not\>\"", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<all\>\"", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<those\>\"", ",", "5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<who\>\"", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<wander\>\"", ",", "6"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<are\>\"", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<lost\>\"", ",", "4"}], "}"}]}], "}"}], ",", 
    RowBox[{"Method", "\[Rule]", "\"\<Voronoi\>\""}]}], "]"}], "[", 
  "\"\<Strider\>\"", "]"}]], "Input",
 CellLabel->"In[2]:=",
 CellID->550600968],

Cell[BoxData["6"], "Output",
 ImageSize->{11, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->292159038]
}, Open  ]],

Cell["\<\
We might try to use the square of EditDistance as DistanceFunction instead.  \
\>", "ExampleText",
 Editable->True,
 CellID->506298877],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Interpolation", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\"\<All\>\"", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<that\>\"", ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<is\>\"", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<gold\>\"", ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<does\>\"", ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<not\>\"", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<glitter\>\"", ",", "7"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Not\>\"", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<all\>\"", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<those\>\"", ",", "5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<who\>\"", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<wander\>\"", ",", "6"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<are\>\"", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<lost\>\"", ",", "4"}], "}"}]}], "}"}], ",", 
    RowBox[{"Method", "\[Rule]", "\"\<Voronoi\>\""}], ",", 
    RowBox[{"DistanceFunction", "\[Rule]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"EditDistance", "[", 
          RowBox[{"#1", ",", "#2"}], "]"}], "^", "2"}], ")"}], "&"}], 
      ")"}]}]}], "]"}], "[", "\"\<Strider\>\"", "]"}]], "Input",
 CellLabel->"In[3]:=",
 CellID->36605670],

Cell[BoxData["6"], "Output",
 ImageSize->{11, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]=",
 CellID->546481481]
}, Open  ]],

Cell["\<\
7. should be the correct result here. Maybe we should have more control \
points, and maybe there are better ways to determine the length of words...\
\>", "ExampleText",
 Editable->True,
 CellID->630229669]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell[TextData[{
   "Applications",
   "\[NonBreakingSpace]\[NonBreakingSpace]",
   Cell["(1)", "ExampleCount"]
  }], "ExampleSection"],
  $Line = 0; Null]], "ExampleSection",
 CellID->258228157],

Cell["\<\
Suppose that we want to make a seven-color cross stitch embroidery out of a \
rose picture. Could we represent the picture with a low number of threads? \
Start by importing the picture.\
\>", "Text",
 CellID->287509959],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"rose", "=", 
   RowBox[{"Import", "[", "\"\<ExampleData/rose.gif\>\"", "]"}]}], 
  "\n"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->536059591],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztfS+U4lrzLWs90xKJRUYiscjISOQPiXgiMjYSGYl8kZHIWCQSyU8iWyLn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    "], {{0, 164}, {223, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{223, 164},
  PlotRange->{{0, 223}, {0, 164}}]], "Output",
 ImageSize->{227, 164},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[1]=",
 CellID->505793958]
}, Open  ]],

Cell["Which unique colors are there in the picture?", "Text",
 CellID->225545386],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"uniquecolors", "=", 
   RowBox[{"Union", "[", 
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"rose", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", "1"}], "]"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{"Length", "[", "uniquecolors", "]"}]}], "Input",
 CellLabel->"In[2]:=",
 CellID->38762],

Cell[BoxData["251"], "Output",
 ImageSize->{25, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->20259369]
}, Open  ]],

Cell["\<\
Let us try with seven specific threads! They were found by cluster analysis, \
followed by a choice of the closest real thread colors. The color0 is the \
background color white.\
\>", "Text",
 CellID->7671447],

Cell[BoxData[{
 RowBox[{
  RowBox[{"color0", "=", 
   RowBox[{"{", 
    RowBox[{"255.", ",", "255.", ",", "255."}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"color1", "=", 
   RowBox[{"{", 
    RowBox[{"151.", ",", "31.", ",", "1."}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"color2", "=", 
   RowBox[{"{", 
    RowBox[{"65.", ",", "85.", ",", "69."}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"color3", "=", 
   RowBox[{"{", 
    RowBox[{"13.", ",", "41.", ",", "4."}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"color4", "=", 
   RowBox[{"{", 
    RowBox[{"165.", ",", "137.", ",", "115."}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"color5", "=", 
   RowBox[{"{", 
    RowBox[{"252.", ",", "143.", ",", "12."}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"color6", "=", 
   RowBox[{"{", 
    RowBox[{"215.", ",", "128.", ",", "0."}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"color7", "=", 
   RowBox[{"{", 
    RowBox[{"233.", ",", "189.", ",", "150."}], "}"}]}], ";"}]}], "Input",
 CellLabel->"In[3]:=",
 CellID->104056813],

Cell["The colors look like this", "Text",
 CellID->43858913],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Graphics", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"RGBColor", "[", 
        RowBox[{"Sequence", "@@", "#"}], "]"}], ",", 
       RowBox[{"Disk", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], "}"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"60", ",", "60"}], "}"}]}]}], "]"}], "&"}], " ", "/@", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "color0", ",", "color1", ",", "color2", ",", "color3", ",", "color4", 
      ",", "color5", ",", "color6", ",", "color7"}], "}"}], "/", "255."}], 
   ")"}]}]], "Input",
 CellLabel->"In[4]:=",
 CellID->119666659],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[
    {RGBColor[1., 1., 1.], DiskBox[{0, 0}]},
    ImageSize->{60, 60}], ",", 
   GraphicsBox[
    {RGBColor[0.592156862745098, 0.12156862745098039`, 0.00392156862745098], 
     DiskBox[{0, 0}]},
    ImageSize->{60, 60}], ",", 
   GraphicsBox[
    {RGBColor[0.2549019607843137, 0.3333333333333333, 0.27058823529411763`], 
     DiskBox[{0, 0}]},
    ImageSize->{60, 60}], ",", 
   GraphicsBox[
    {RGBColor[
     0.050980392156862744`, 0.16078431372549018`, 0.01568627450980392], 
     DiskBox[{0, 0}]},
    ImageSize->{60, 60}], ",", 
   GraphicsBox[
    {RGBColor[0.6470588235294118, 0.5372549019607843, 0.45098039215686275`], 
     DiskBox[{0, 0}]},
    ImageSize->{60, 60}], ",", 
   GraphicsBox[
    {RGBColor[0.9882352941176471, 0.5607843137254902, 0.047058823529411764`], 
     DiskBox[{0, 0}]},
    ImageSize->{60, 60}], ",", 
   GraphicsBox[
    {RGBColor[0.8431372549019608, 0.5019607843137255, 0.], DiskBox[{0, 0}]},
    ImageSize->{60, 60}], ",", 
   GraphicsBox[
    {RGBColor[0.9137254901960784, 0.7411764705882353, 0.5882352941176471], 
     DiskBox[{0, 0}]},
    ImageSize->{60, 60}]}], "}"}]], "Output",
 ImageSize->{575, 62},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[4]=",
 CellID->409666894]
}, Open  ]],

Cell["\<\
We can make an interpolation between these colors, with the colors them self \
as function values. If we use the method \"Voronois\" with InterpolationOrder \
1, we know that the interpolation coefficients are zero or one. Let us first \
check what will happen in the interpolation point defined by color2\
\>", "Text",
 CellID->180721139],

Cell[BoxData[
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Obtuse`\>\"", "]"}], ";"}]], "Input",
 CellLabel->"In[5]:=",
 CellID->884755071],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"interpol", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"color0", ",", "color0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"color1", ",", "color1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"color2", ",", "color2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"color3", ",", "color3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"color4", ",", "color4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"color5", ",", "color5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"color6", ",", "color6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"color7", ",", "color7"}], "}"}]}], "}"}], ",", 
     RowBox[{"Method", "\[Rule]", "\"\<Voronoi\>\""}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"interpol", "[", "color2", "]"}]}], "Input",
 CellLabel->"In[6]:=",
 CellID->362765852],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"65.`", ",", "85.`", ",", "69.`"}], "}"}]], "Output",
 ImageSize->{103, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[6]=",
 CellID->29366755]
}, Open  ]],

Cell["\<\
We got back exactly color2. If we choose another random color, we might get a \
quite different result, more in the tune of the figure.\
\>", "Text",
 CellID->260533583],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"interpol", "[", 
  RowBox[{"{", 
   RowBox[{"150.", ",", "5.`", ",", "150.`"}], "}"}], "]"}]], "Input",
 CellLabel->"In[7]:=",
 CellID->204999252],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"165.`", ",", "137.`", ",", "115.`"}], "}"}]], "Output",
 ImageSize->{124, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[7]=",
 CellID->212991824]
}, Open  ]],

Cell["Compare the two colors, in and out.", "Text",
 CellID->66761881],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Graphics", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"RGBColor", "[", 
        RowBox[{"Sequence", "@@", "#"}], "]"}], ",", 
       RowBox[{"Disk", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], "}"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"60", ",", "60"}], "}"}]}]}], "]"}], "&"}], " ", "/@", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"150.", ",", "5.`", ",", "150.`"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"165.`", ",", "137.`", ",", "115.`"}], "}"}]}], "}"}], "/", 
    "255."}], ")"}]}]], "Input",
 CellLabel->"In[8]:=",
 CellID->89390494],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[
    {RGBColor[0.5882352941176471, 0.0196078431372549, 0.5882352941176471], 
     DiskBox[{0, 0}]},
    ImageSize->{60, 60}], ",", 
   GraphicsBox[
    {RGBColor[0.6470588235294118, 0.5372549019607843, 0.45098039215686275`], 
     DiskBox[{0, 0}]},
    ImageSize->{60, 60}]}], "}"}]], "Output",
 ImageSize->{149, 62},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[8]=",
 CellID->228164427]
}, Open  ]],

Cell["\<\
Well, maybe not the very best representation, but there are very few purple \
pixels in the rose anyway. Let us now create a replacement list, replacing \
all colors with linear combinations of the threads.\
\>", "Text",
 CellID->2871894],

Cell[BoxData[
 RowBox[{
  RowBox[{"replacementlist", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"#", "\[Rule]", 
       RowBox[{"Round", "[", 
        RowBox[{"interpol", "[", "#", "]"}], "]"}]}], ")"}], "&"}], "/@", " ",
     "uniquecolors"}]}], ";"}]], "Input",
 CellLabel->"In[9]:=",
 CellID->300249759],

Cell["Number of colors after replacement", "Text",
 CellID->94961639],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", 
  RowBox[{"Union", "[", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"rose", "/.", "replacementlist"}], ")"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", "1"}], "]"}], "]"}], 
  "]"}]], "Input",
 CellLabel->"In[10]:=",
 CellID->128794562],

Cell[BoxData["8"], "Output",
 ImageSize->{11, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[10]=",
 CellID->195355857]
}, Open  ]],

Cell["\<\
Here is the original image, followed by a image with replaced colors.  \
\>", "Text",
 CellID->138717722],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"Show", "[", 
      RowBox[{"rose", ",", 
       RowBox[{"ImageSize", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"223", ",", "164"}], "}"}]}]}], "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"Show", "[", 
      RowBox[{
       RowBox[{"rose", "/.", "replacementlist"}], ",", 
       RowBox[{"ImageSize", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"223", ",", "164"}], "}"}]}]}], "]"}], "}"}]}], "}"}], 
  "]"}]], "Input",
 CellLabel->"In[11]:=",
 CellID->13096728],

Cell[BoxData[
 TagBox[GridBox[{
    {
     GraphicsBox[
      TagBox[RasterBox[CompressedData["
1:eJztfS+U4lrzLWs90xKJRUYiscjISOQPiXgiMjYSGYl8kZHIWCQSyU8iWyLn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        "], {{0, 164}, {223, 0}}, {0, 255},
        ColorFunction->RGBColor],
       BoxForm`ImageTag[
       "Byte", ColorSpace -> "RGB", ImageSize -> {223, 164}, Interleaving -> 
        True],
       Selectable->False],
      BaseStyle->"ImageGraphics",
      ImageSize->{223, 164},
      ImageSizeRaw->{223, 164},
      PlotRange->{{0, 223}, {0, 164}}]},
    {
     GraphicsBox[
      TagBox[RasterBox[CompressedData["
1:eJztnU2y6zwRhi8FQ7IGiiHLyIANUMUGvg0wYANMGTGDDeBlsI4MGWsPqTL5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        "], {{0, 164}, {223, 0}}, {0, 255},
        ColorFunction->RGBColor],
       BoxForm`ImageTag[
       "Byte", ColorSpace -> "RGB", ImageSize -> {223, 164}, Interleaving -> 
        True],
       Selectable->False],
      BaseStyle->"ImageGraphics",
      ImageSize->{223, 164},
      ImageSizeRaw->{223, 164},
      PlotRange->{{0, 223}, {0, 164}}]}
   },
   AutoDelete->False,
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 ImageSize->{227, 335},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[11]=",
 CellID->12470274]
}, Open  ]],

Cell["\<\
Not a bat cross-stich patern!. But let us see where there is dark green \
(color3) in the picture, by replacing all the other colors by white:  \
\>", "Text",
 CellID->161860483],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"interpol2", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"color0", ",", "color0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"color1", ",", "color0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"color2", ",", "color0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"color3", ",", "color3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"color4", ",", "color0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"color5", ",", "color0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"color6", ",", "color0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"color7", ",", "color0"}], "}"}]}], "}"}], ",", 
     RowBox[{"Method", "\[Rule]", "\"\<Voronoi\>\""}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"replacementlist2", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"#", "\[Rule]", 
       RowBox[{"Round", "[", 
        RowBox[{"interpol2", "[", "#", "]"}], "]"}]}], ")"}], "&"}], "/@", 
    " ", "uniquecolors"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"rose", "/.", "replacementlist2"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"223", ",", "164"}], "}"}]}]}], "]"}]}], "Input",
 CellLabel->"In[12]:=",
 CellID->96069006],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3WFu2zYYgOEA218foj93nR2hF9ildq8eRctQwFBIimJEUqTN50ELJI4t
OfKbj3KS1j9+/vP3zz8+Pj7+/fz76/Pv/29vAABrePz15+i7AADAm/s853Ta
yZzEyczEyWyeM9PwZDb7OEffFzhkeDKn32WKk0kENYqTeQTT0skn8whqFCfz
CMamOJnKc2UXJ5MIvvee/DP6PrKiZIFHb8Ntkj+v9A0lZhC3F59z6pP7lfya
h98D4X7JkZhMUZncL/5mUWZ+6pM7Bd/MjKelJrmf6phWXKafBzEJ/xyDmWkS
AAAAAAAAAAAAAAAAAAAAAADgRfmPpJiTMgGAZXklSmYQv7R0/KqpQ+8gK8q8
aK/XmB5izaMdzMDTLM1M7lQepLHJzZLtmZkTWurgf3dmGpv0VjIeDc85vffB
L1++lcmdaqalOOmkSZbipLl9VOXPeo6W/pGfCe+lyZxUJg01XMeDWcormuex
a1umNZ16/ZoUJ5VKThqVySjG5pomf3TaRqhM6j2+/jJGpq7CCM1MmgiysaYz
j641KpPLTtfl/EfF+cbGPmT59jIfEie9JTvc+iz0oz9XXkZlZsqkq64ruD65
pneHynxdYx+s/MCMLxEnt0mWY34y1uPrTyeH/Bl7BJjTnRNSli/n/gdov8fh
Wap0ckMemkwznVKMI8x8iMUNHJtHXwijDwmzOBpr/Sbqc/vJrQ06DEzqNJiu
c9LwJOmok63bM6aSrW2DzsCZTbCOb6mF/p4mg2uOOyTMIlhJrxXVJMvkbVlW
j6K+u5383WBZyRia9Jm/efnGBx4cBnocP+WJL7lW5tF2tq8nlvpkr2aa3Tk5
xbmmOJLn5U2iaps66+haWnLL13a3fT39YB09Iux029GHilt9q5ktOgE4un7y
kqPNipMjlfEkb7W/8Npm9cnpZEtemA9161amPlcTPOLl4/F0lmY2qE/yrk22
o5tsB02eXl+fxCpTSd5kK/tXnBd2J86lVOZREk+TDvW5oMoheRrkhR3pk631
E+otOuEM9nKtdokuq0eN+3fjCLcOXxS8n5pItl2ZQSSP4+dE8SXKJKlhJHGu
+71sBau8ONl7VC+y20GQz+3HFSmTU/UTsrCQR3QuqkwyxuahTDIeqafS8SX5
4Vmz95ogxfn2aqZWeR7xNQv7NyfXdK3GVqmIk7yBfWqSI5VL+YVsLqzsjT5X
XsyFLLfUL3J02u9+d4tb7as1mIH5a+5TSR6lzHbiqo+mZXB9nlZbWS5/XkGH
wSHKZ1zyNjFn5t+SnJxH71Lp8rMD6O1anPtKRUtvhfllzuf1SVcNE/VUlB7y
Y/B0HU/GqU8aOi1KcoyiPSanTwAAAAAAAAAAAAAAAAAA4Db/AZt8hEw=
    "], {{0, 164}, {223, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{223, 164},
  PlotRange->{{0, 223}, {0, 164}}]], "Output",
 ImageSize->{227, 164},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[12]=",
 CellID->763173756]
}, Open  ]],

Cell["\<\
What does the color space look like? Plot a sphere for each color in the \
original, with a volume proportional to the number of pixels of that color:  \
\>", "Text",
 CellID->155939414],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tallyfig", "=", 
   RowBox[{"Tally", "[", 
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"rose", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", "1"}], "]"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{"colorplot3D", "=", 
  RowBox[{"Graphics3D", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"RGBColor", "[", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "/", "255."}], "]"}], ",", 
          RowBox[{"Sphere", "[", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "^", 
             RowBox[{"(", 
              RowBox[{"1", "/", "3"}], ")"}]}]}], "]"}]}], "}"}], "&"}], " ", 
       "@", 
       RowBox[{"(", 
        RowBox[{"1.", "*", 
         RowBox[{"tallyfig", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], ")"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{"Length", "[", "tallyfig", "]"}]}], "}"}]}], "]"}], ",", 
    RowBox[{"Lighting", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"\"\<Ambient\>\"", ",", "White"}], "}"}], "}"}]}], ",", 
    RowBox[{"Background", "\[Rule]", "LightGray"}], ",", 
    RowBox[{"SphericalRegion", "\[Rule]", "True"}]}], "]"}]}]}], "Input",
 CellLabel->"In[13]:=",
 CellID->360042820],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztnC+wq7oWhzvzzJaV21YiK2srK5GVtzPHVDxRia2sRG5biXtbYisrmcHU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    "], {{0, 180}, {180, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{180, 180},
  PlotRange->{{0, 180}, {0, 180}}]], "Output",
 ImageSize->{184, 180},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[13]=",
 CellID->499018242]
}, Open  ]],

Cell["\<\
Make a 3D plot of the thread colors and the connections between them, \
according to the obtuse-angle shadowing rule:  \
\>", "Text",
 CellID->15451953],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"colorlist", "=", 
   RowBox[{"{", 
    RowBox[{
    "color0", ",", "color1", ",", "color2", ",", "color3", ",", "color4", ",",
      "color5", ",", "color6", ",", "color7"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"conlist", "=", 
   RowBox[{"ConnectionList", "[", 
    RowBox[{"DirectedDistanceMatrix", "[", "colorlist", "]"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{"threadplot3D", "=", 
  RowBox[{"Graphics3D", "[", 
   RowBox[{
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Opacity", "[", "0.5", "]"}], ",", 
          RowBox[{"RGBColor", "[", 
           RowBox[{"#", "/", "255."}], "]"}], ",", 
          RowBox[{"Sphere", "[", 
           RowBox[{"#", ",", "10"}], "]"}]}], "}"}], "&"}], "/@", 
       RowBox[{"(", 
        RowBox[{"1.", "*", "colorlist"}], ")"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"Black", ",", 
        RowBox[{"Opacity", "[", "1", "]"}]}], "}"}], ",", 
      RowBox[{"conlist", " ", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"i_Integer", "->", "j_Integer"}], ")"}], "\[RuleDelayed]", 
         RowBox[{"Arrow", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"colorlist", "[", 
             RowBox[{"[", "i", "]"}], "]"}], ",", 
            RowBox[{"colorlist", "[", 
             RowBox[{"[", "j", "]"}], "]"}]}], "}"}], "]"}]}], "}"}]}]}], 
     "]"}], ",", 
    RowBox[{"Lighting", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"\"\<Ambient\>\"", ",", "White"}], "}"}], "}"}]}], ",", 
    RowBox[{"Background", "\[Rule]", "LightGray"}], ",", 
    RowBox[{"SphericalRegion", "\[Rule]", "True"}]}], "]"}]}]}], "Input",
 CellLabel->"In[14]:=",
 CellID->8661810],

Cell[BoxData[
 Graphics3DBox[{
   {RGBColor[1., 1., 1.], Opacity[0.5], SphereBox[{255., 255., 255.}, 10]}, 
   {RGBColor[0.592156862745098, 0.12156862745098039`, 0.00392156862745098], 
    Opacity[0.5], SphereBox[{151., 31., 1.}, 10]}, 
   {RGBColor[0.2549019607843137, 0.3333333333333333, 0.27058823529411763`], 
    Opacity[0.5], SphereBox[{65., 85., 69.}, 10]}, 
   {RGBColor[
    0.050980392156862744`, 0.16078431372549018`, 0.01568627450980392], 
    Opacity[0.5], SphereBox[{13., 41., 4.}, 10]}, 
   {RGBColor[0.6470588235294118, 0.5372549019607843, 0.45098039215686275`], 
    Opacity[0.5], SphereBox[{165., 137., 115.}, 10]}, 
   {RGBColor[0.9882352941176471, 0.5607843137254902, 0.047058823529411764`], 
    Opacity[0.5], SphereBox[{252., 143., 12.}, 10]}, 
   {RGBColor[0.8431372549019608, 0.5019607843137255, 0.], Opacity[0.5], 
    SphereBox[{215., 128., 0.}, 10]}, 
   {RGBColor[0.9137254901960784, 0.7411764705882353, 0.5882352941176471], 
    Opacity[0.5], SphereBox[{233., 189., 150.}, 10]}, 
   {GrayLevel[0], Opacity[1], 
    Arrow3DBox[{{215., 128., 0.}, {252., 143., 12.}}], 
    Arrow3DBox[{{252., 143., 12.}, {215., 128., 0.}}], 
    Arrow3DBox[{{233., 189., 150.}, {165., 137., 115.}}], 
    Arrow3DBox[{{165., 137., 115.}, {233., 189., 150.}}], 
    Arrow3DBox[{{13., 41., 4.}, {65., 85., 69.}}], 
    Arrow3DBox[{{65., 85., 69.}, {13., 41., 4.}}], 
    Arrow3DBox[{{215., 128., 0.}, {151., 31., 1.}}], 
    Arrow3DBox[{{151., 31., 1.}, {215., 128., 0.}}], 
    Arrow3DBox[{{165., 137., 115.}, {65., 85., 69.}}], 
    Arrow3DBox[{{65., 85., 69.}, {165., 137., 115.}}], 
    Arrow3DBox[{{65., 85., 69.}, {151., 31., 1.}}], 
    Arrow3DBox[{{151., 31., 1.}, {65., 85., 69.}}], 
    Arrow3DBox[{{215., 128., 0.}, {165., 137., 115.}}], 
    Arrow3DBox[{{165., 137., 115.}, {215., 128., 0.}}], 
    Arrow3DBox[{{233., 189., 150.}, {255., 255., 255.}}], 
    Arrow3DBox[{{255., 255., 255.}, {233., 189., 150.}}], 
    Arrow3DBox[{{13., 41., 4.}, {151., 31., 1.}}], 
    Arrow3DBox[{{151., 31., 1.}, {13., 41., 4.}}], 
    Arrow3DBox[{{233., 189., 150.}, {252., 143., 12.}}], 
    Arrow3DBox[{{252., 143., 12.}, {233., 189., 150.}}], 
    Arrow3DBox[{{165., 137., 115.}, {151., 31., 1.}}], 
    Arrow3DBox[{{151., 31., 1.}, {165., 137., 115.}}]}},
  Background->GrayLevel[0.85],
  Lighting->{{"Ambient", 
     GrayLevel[1]}},
  SphericalRegion->True]], "Output",
 ImageSize->{184, 180},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[14]=",
 CellID->121469648]
}, Open  ]],

Cell["Show the pictures together:  ", "Text",
 CellID->176476148],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"colorplot3D", ",", "threadplot3D"}], "]"}]], "Input",
 CellLabel->"In[15]:=",
 CellID->74866521],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztnTGoK0sZx8N78LjaGFDwNIJ5vCaKRapHbN4lCEoeWET0PVJYvMAVTPGQ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    "], {{0, 180}, {180, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{180, 180},
  PlotRange->{{0, 180}, {0, 180}}]], "Output",
 ImageSize->{184, 180},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[15]=",
 CellID->752506209]
}, Open  ]],

Cell["The color space for the image with replaced colors:  ", "Text",
 CellID->47837066],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tallyfig1", "=", 
   RowBox[{"Tally", "[", 
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"rose", "/.", "replacementlist"}], ")"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", "1"}], "]"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{"colorplot3D", "=", 
  RowBox[{"Graphics3D", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"RGBColor", "[", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "/", "255."}], "]"}], ",", 
          RowBox[{"Sphere", "[", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "^", 
             RowBox[{"(", 
              RowBox[{"1", "/", "3"}], ")"}]}]}], "]"}]}], "}"}], "&"}], " ", 
       "@", 
       RowBox[{"(", 
        RowBox[{"1.", "*", 
         RowBox[{"tallyfig1", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], ")"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{"Length", "[", "tallyfig1", "]"}]}], "}"}]}], "]"}], ",", 
    RowBox[{"Lighting", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"\"\<Ambient\>\"", ",", "White"}], "}"}], "}"}]}], ",", 
    RowBox[{"Background", "\[Rule]", "LightGray"}], ",", 
    RowBox[{"SphericalRegion", "\[Rule]", "True"}]}], "]"}]}]}], "Input",
 CellLabel->"In[16]:=",
 CellID->105252577],

Cell[BoxData[
 Graphics3DBox[{
   {RGBColor[1., 1., 1.], SphereBox[{255., 255., 255.}, 27.11428466736573]}, 
   {RGBColor[0.9137254901960784, 0.7411764705882353, 0.5882352941176471], 
    SphereBox[{233., 189., 150.}, 17.92665628841176]}, 
   {RGBColor[0.2549019607843137, 0.3333333333333333, 0.27058823529411763`], 
    SphereBox[{65., 85., 69.}, 10.777915547968671`]}, 
   {RGBColor[0.6470588235294118, 0.5372549019607843, 0.45098039215686275`], 
    SphereBox[{165., 137., 115.}, 16.408740136012103`]}, 
   {RGBColor[
    0.050980392156862744`, 0.16078431372549018`, 0.01568627450980392], 
    SphereBox[{13., 41., 4.}, 14.291507174462806`]}, 
   {RGBColor[0.9882352941176471, 0.5607843137254902, 0.047058823529411764`], 
    SphereBox[{252., 143., 12.}, 9.333191607825249]}, 
   {RGBColor[0.8431372549019608, 0.5019607843137255, 0], 
    SphereBox[{215., 128., 0}, 10.467777254236418`]}, 
   {RGBColor[0.592156862745098, 0.12156862745098039`, 0.00392156862745098], 
    SphereBox[{151., 31., 1.}, 6.8964344807654605`]}},
  Background->GrayLevel[0.85],
  Lighting->{{"Ambient", 
     GrayLevel[1]}},
  SphericalRegion->True]], "Output",
 ImageSize->{184, 180},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[16]=",
 CellID->103116570]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["SEE ALSO",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "SeeAlsoSection",
 CellID->1255426704],

Cell[TextData[{
 Cell[BoxData[
  StyleBox[
   ButtonBox["Interpolation",
    BaseStyle->"Link",
    ButtonData->"paclet:ref/Interpolation"],
   FontFamily->"Verdana"]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  StyleBox[
   ButtonBox[
    RowBox[{"Interpolation", ",", " ", 
     RowBox[{"Method", " ", "->", " ", "\"\<ObtuseAngle\>\""}]}],
    BaseStyle->"Link",
    ButtonData->"paclet:Obtuse/ref/InterpolationMethodObtuseAngle"],
   FontFamily->"Verdana"]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  StyleBox[
   ButtonBox[
    RowBox[{"Interpolation", ",", " ", 
     RowBox[{"Method", " ", "->", " ", "\"\<Delaunay\>\""}]}],
    BaseStyle->"Link",
    ButtonData->"paclet:Obtuse/ref/InterpolationMethodDelaunay"],
   FontFamily->"Verdana"]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  StyleBox[
   ButtonBox[
    RowBox[{"Interpolation", ",", " ", 
     RowBox[{"Method", " ", "->", " ", "\"\<RBF\>\""}]}],
    BaseStyle->"Link",
    ButtonData->"paclet:Obtuse/ref/InterpolationMethodRBF"],
   FontFamily->"Verdana"]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  StyleBox[
   ButtonBox[
    RowBox[{"Interpolation", ",", " ", 
     RowBox[{"Method", " ", "->", " ", "\"\<Shepard\>\""}]}],
    BaseStyle->"Link",
    ButtonData->"paclet:Obtuse/ref/InterpolationMethodShepard"],
   FontFamily->"Verdana"]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  StyleBox[
   ButtonBox["DirectedDistanceMatrix",
    BaseStyle->"Link",
    ButtonData->"paclet:Obtuse/ref/DirectedDistanceMatrix"],
   FontFamily->"Verdana"]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  StyleBox[
   ButtonBox["DistanceMatrix",
    BaseStyle->"Link",
    ButtonData->"paclet:HierarchicalClustering/ref/DistanceMatrix"],
   FontFamily->"Verdana"]], "InlineFormula"]
}], "SeeAlso",
 CellID->929782353]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["TUTORIALS",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "TutorialsSection",
 CellID->250839057],

Cell[TextData[ButtonBox["Scattered Point Interpolation",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Obtuse/tutorial/Scattered Point Interpolation"]], "Tutorials",
 CellID->341631938],

Cell[TextData[ButtonBox["Interpolation interactive demo",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Obtuse/tutorial/Interpolation interactive demo"]], "Tutorials",
 CellID->294894982]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["MORE ABOUT",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "MoreAboutSection",
 CellID->38303248],

Cell[TextData[ButtonBox["Obtuse Package",
 BaseStyle->"Link",
 ButtonData->"paclet:Obtuse/guide/ObtusePackage"]], "MoreAbout",
 CellID->606611808]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"Interpolation, Method -> Voronoi - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, 
  "Metadata" -> {
   "built" -> "{2010, 5, 24, 20, 41, 49.4383378}", "context" -> "Obtuse`", 
    "keywords" -> {
     "Distance matrix", "Scattered Points", "n-dimensional", 
      "Multidimensional", "Interpolation", "Voronoi", "machine learning", 
      "connection", "neighborhood", "correlated points", "associated", 
      "point set", "distance-based"}, "index" -> True, "label" -> 
    "Obtuse Paclet Symbol", "language" -> "en", "paclet" -> "Obtuse", 
    "status" -> "None", "summary" -> 
    "Interpolation[funcvaluelist, Method -> \" StyleBox[StyleBox[\\\"Vo\\\", \
\\\"TI\\\",\\nFontSlant->\\\"Italic\\\"]ro StyleBox[StyleBox[\\\"n\\\", \
\\\"TI\\\",\\nFontSlant->\\\"Italic\\\"], \\\"TI\\\",\\nFontSlant\\ \
->\\\"Italic\\\"]oi]\", (options)][x], where funcvaluelist is a list of \
scattered control points together with the function values in these points, \
returns the function value of the nearest control point to x. The function is \
thus constant in regions. If two control points are at the same minimum \
distance, the function value of the first is returned. ", "synonyms" -> {}, 
    "title" -> "Interpolation, Method -> Voronoi", "type" -> "Symbol", "uri" -> 
    "Obtuse/ref/InterpolationMethodVoronoi"}, "SearchTextTranslated" -> ""},
CellContext->"Global`",
FrontEndVersion->"7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> FrontEnd`FileName[{"Wolfram"}, "Reference.nb"]]], 
   Cell[
    StyleData["Input"], CellContext -> "Global`"], 
   Cell[
    StyleData["Output"], CellContext -> "Global`"]}, Visible -> False, 
  FrontEndVersion -> "7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
   StyleDefinitions -> "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "PrimaryExamplesSection"->{
  Cell[8242, 233, 461, 13, 45, "PrimaryExamplesSection",
   CellTags->"PrimaryExamplesSection",
   CellID->462255656]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"PrimaryExamplesSection", 505113, 9136}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[613, 21, 76, 1, 3, "SymbolColorBar"],
Cell[692, 24, 178, 5, 19, "LinkTrail"],
Cell[873, 31, 3981, 87, 46, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[4879, 122, 79, 1, 51, "ObjectName",
 CellID->1224892054],
Cell[4961, 125, 1163, 34, 121, "Usage",
 CellID->982511436]
}, Open  ]],
Cell[CellGroupData[{
Cell[6161, 164, 580, 17, 39, "NotesSection",
 CellGroupingRules->{"SectionGrouping", 50},
 CellID->230136585],
Cell[6744, 183, 497, 18, 70, "Notes",
 CellID->1067943069],
Cell[7244, 203, 72, 1, 70, "Notes",
 CellID->283978029],
Cell[7319, 206, 886, 22, 70, "3ColumnTableMod"]
}, Closed]],
Cell[CellGroupData[{
Cell[8242, 233, 461, 13, 45, "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->462255656],
Cell[CellGroupData[{
Cell[8728, 250, 148, 5, 31, "ExampleSection",
 CellID->527923314],
Cell[8879, 257, 133, 4, 28, "Input",
 CellID->139566013],
Cell[9015, 263, 75, 2, 32, "ExampleText",
 CellID->65039657],
Cell[9093, 267, 307, 11, 28, "Input",
 CellID->614368519],
Cell[9403, 280, 103, 2, 32, "ExampleText",
 CellID->472343579],
Cell[9509, 284, 693, 23, 28, "Input",
 CellID->27569007],
Cell[10205, 309, 93, 2, 32, "ExampleText",
 CellID->111279482],
Cell[CellGroupData[{
Cell[10323, 315, 266, 8, 28, "Input",
 CellID->213125124],
Cell[10592, 325, 176, 5, 36, "Output",
 CellID->321014514]
}, Open  ]],
Cell[10783, 333, 111, 2, 32, "ExampleText",
 CellID->96612022],
Cell[CellGroupData[{
Cell[10919, 339, 156, 5, 28, "Input",
 CellID->133901027],
Cell[11078, 346, 177, 5, 36, "Output",
 CellID->378076224]
}, Open  ]],
Cell[11270, 354, 273, 6, 45, "ExampleText",
 CellID->163562336],
Cell[CellGroupData[{
Cell[11568, 364, 920, 28, 70, "Input",
 CellID->187990255],
Cell[12491, 394, 388160, 6444, 70, "Output",
 CellID->217697153]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[400700, 6844, 223, 7, 70, "ExampleSection",
 CellID->2061341341],
Cell[CellGroupData[{
Cell[400948, 6855, 292, 9, 70, "ExampleSubsection",
 CellID->20803],
Cell[401243, 6866, 1213, 35, 70, "ExampleText",
 CellID->465813429],
Cell[402459, 6903, 133, 4, 70, "Input",
 CellID->586163291],
Cell[CellGroupData[{
Cell[402617, 6911, 1321, 37, 70, "Input",
 CellID->550600968],
Cell[403941, 6950, 158, 5, 70, "Output",
 CellID->292159038]
}, Open  ]],
Cell[404114, 6958, 145, 4, 70, "ExampleText",
 CellID->506298877],
Cell[CellGroupData[{
Cell[404284, 6966, 1564, 44, 70, "Input",
 CellID->36605670],
Cell[405851, 7012, 158, 5, 70, "Output",
 CellID->546481481]
}, Open  ]],
Cell[406024, 7020, 217, 5, 70, "ExampleText",
 CellID->630229669]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[406290, 7031, 227, 7, 70, "ExampleSection",
 CellID->258228157],
Cell[406520, 7040, 230, 5, 70, "Text",
 CellID->287509959],
Cell[CellGroupData[{
Cell[406775, 7049, 178, 6, 70, "Input",
 CellID->536059591],
Cell[406956, 7057, 25164, 420, 70, "Output",
 CellID->505793958]
}, Open  ]],
Cell[432135, 7480, 81, 1, 70, "Text",
 CellID->225545386],
Cell[CellGroupData[{
Cell[432241, 7485, 334, 11, 70, "Input",
 CellID->38762],
Cell[432578, 7498, 159, 5, 70, "Output",
 CellID->20259369]
}, Open  ]],
Cell[432752, 7506, 220, 5, 70, "Text",
 CellID->7671447],
Cell[432975, 7513, 1040, 34, 70, "Input",
 CellID->104056813],
Cell[434018, 7549, 60, 1, 70, "Text",
 CellID->43858913],
Cell[CellGroupData[{
Cell[434103, 7554, 753, 24, 70, "Input",
 CellID->119666659],
Cell[434859, 7580, 1305, 38, 70, "Output",
 CellID->409666894]
}, Open  ]],
Cell[436179, 7621, 349, 6, 70, "Text",
 CellID->180721139],
Cell[436531, 7629, 133, 4, 70, "Input",
 CellID->884755071],
Cell[CellGroupData[{
Cell[436689, 7637, 955, 27, 70, "Input",
 CellID->362765852],
Cell[437647, 7666, 222, 7, 70, "Output",
 CellID->29366755]
}, Open  ]],
Cell[437884, 7676, 179, 4, 70, "Text",
 CellID->260533583],
Cell[CellGroupData[{
Cell[438088, 7684, 170, 5, 70, "Input",
 CellID->204999252],
Cell[438261, 7691, 226, 7, 70, "Output",
 CellID->212991824]
}, Open  ]],
Cell[438502, 7701, 70, 1, 70, "Text",
 CellID->66761881],
Cell[CellGroupData[{
Cell[438597, 7706, 791, 26, 70, "Input",
 CellID->89390494],
Cell[439391, 7734, 480, 15, 70, "Output",
 CellID->228164427]
}, Open  ]],
Cell[439886, 7752, 248, 5, 70, "Text",
 CellID->2871894],
Cell[440137, 7759, 327, 11, 70, "Input",
 CellID->300249759],
Cell[440467, 7772, 69, 1, 70, "Text",
 CellID->94961639],
Cell[CellGroupData[{
Cell[440561, 7777, 329, 11, 70, "Input",
 CellID->128794562],
Cell[440893, 7790, 159, 5, 70, "Output",
 CellID->195355857]
}, Open  ]],
Cell[441067, 7798, 115, 3, 70, "Text",
 CellID->138717722],
Cell[CellGroupData[{
Cell[441207, 7805, 581, 19, 70, "Input",
 CellID->13096728],
Cell[441791, 7826, 32408, 550, 70, "Output",
 CellID->12470274]
}, Open  ]],
Cell[474214, 8379, 188, 4, 70, "Text",
 CellID->161860483],
Cell[CellGroupData[{
Cell[474427, 8387, 1393, 41, 70, "Input",
 CellID->96069006],
Cell[475823, 8430, 1891, 38, 70, "Output",
 CellID->763173756]
}, Open  ]],
Cell[477729, 8471, 196, 4, 70, "Text",
 CellID->155939414],
Cell[CellGroupData[{
Cell[477950, 8479, 1523, 46, 70, "Input",
 CellID->360042820],
Cell[479476, 8527, 5242, 93, 70, "Output",
 CellID->499018242]
}, Open  ]],
Cell[484733, 8623, 162, 4, 70, "Text",
 CellID->15451953],
Cell[CellGroupData[{
Cell[484920, 8631, 1823, 52, 70, "Input",
 CellID->8661810],
Cell[486746, 8685, 2512, 49, 70, "Output",
 CellID->121469648]
}, Open  ]],
Cell[489273, 8737, 65, 1, 70, "Text",
 CellID->176476148],
Cell[CellGroupData[{
Cell[489363, 8742, 144, 4, 70, "Input",
 CellID->74866521],
Cell[489510, 8748, 6084, 107, 70, "Output",
 CellID->752506209]
}, Open  ]],
Cell[495609, 8858, 88, 1, 70, "Text",
 CellID->47837066],
Cell[CellGroupData[{
Cell[495722, 8863, 1598, 48, 70, "Input",
 CellID->105252577],
Cell[497323, 8913, 1272, 26, 70, "Output",
 CellID->103116570]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[498656, 8946, 417, 12, 70, "SeeAlsoSection",
 CellID->1255426704],
Cell[499076, 8960, 2436, 76, 70, "SeeAlso",
 CellID->929782353]
}, Open  ]],
Cell[CellGroupData[{
Cell[501549, 9041, 419, 12, 70, "TutorialsSection",
 CellID->250839057],
Cell[501971, 9055, 183, 4, 70, "Tutorials",
 CellID->341631938],
Cell[502157, 9061, 185, 4, 70, "Tutorials",
 CellID->294894982]
}, Open  ]],
Cell[CellGroupData[{
Cell[502379, 9070, 419, 12, 70, "MoreAboutSection",
 CellID->38303248],
Cell[502801, 9084, 146, 3, 70, "MoreAbout",
 CellID->606611808]
}, Open  ]],
Cell[502962, 9090, 23, 0, 70, "FooterCell"]
}
]
*)

(* End of internal cache information *)

