(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     32972,        893]
NotebookOptionsPosition[     27931,        747]
NotebookOutlinePosition[     30540,        807]
CellTagsIndexPosition[     30497,        804]
WindowTitle->Scattered Point Interpolation - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[" ", "TutorialColorBar",
 CellMargins->{{Inherited, Inherited}, {-5, 0}}],

Cell[TextData[{
 StyleBox[ButtonBox["Mathematica",
  BaseStyle->{"Link", "LinkTrail"},
  ButtonData->"paclet:guide/Mathematica"],
  FontSlant->"Italic"],
 StyleBox[" > ", "LinkTrailSeparator"]
}], "LinkTrail"],

Cell[BoxData[GridBox[{
   {Cell["OBTUSE TUTORIAL", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"Related Tutorials \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"Obtuse Angle Shadowing Networks\"\>":>
       Documentation`HelpLookup[
       "paclet:Obtuse/tutorial/Obtuse Angle Shadowing Networks"], \
"\<\"Interpolation interactive demo\"\>":>Documentation`HelpLookup[
       "paclet:Obtuse/tutorial/Interpolation interactive demo"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"Functions \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"Interpolation\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/Interpolation"], "\<\"Interpolation, Method -> \
\\\"Delaunay\\\"\"\>":>Documentation`HelpLookup[
       "paclet:Obtuse/ref/InterpolationMethodDelaunay"], "\<\"Interpolation, \
Method -> \\\"Voronoi\\\"\"\>":>Documentation`HelpLookup[
       "paclet:Obtuse/ref/InterpolationMethodVoronoi"], "\<\"Interpolation, \
Method -> \\\"ObtuseAngle\\\"\"\>":>Documentation`HelpLookup[
       "paclet:Obtuse/ref/InterpolationMethodObtuseAngle"], \
"\<\"Interpolation, Method -> \\\"RBF\\\"\"\>":>Documentation`HelpLookup[
       "paclet:Obtuse/ref/InterpolationMethodRBF"], "\<\"Interpolation, \
Method -> \\\"Shepard\\\"\"\>":>Documentation`HelpLookup[
       "paclet:Obtuse/ref/InterpolationMethodShepard"], \
"\<\"InterpolationCofficients\"\>":>Documentation`HelpLookup[
       "paclet:Obtuse/ref/InterpolationCofficients"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"Options \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"ConnectionsToExclude\"\>":>
       Documentation`HelpLookup[
       "paclet:Obtuse/ref/ConnectionsToExclude"], "\<\"CutoffRadius\"\>":>
       Documentation`HelpLookup[
       "paclet:Obtuse/ref/CutoffRadius"], "\<\"CutoffValue\"\>":>
       Documentation`HelpLookup[
       "paclet:Obtuse/ref/CutoffValue"], "\<\"DistanceFunction\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/DistanceFunction"], "\<\"InterpolationOrder\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/InterpolationOrder"], "\<\"NeighborLevel\"\>":>
       Documentation`HelpLookup[
       "paclet:Obtuse/ref/NeighborLevel"], "\<\"RadialBasisFunction\"\>":>
       Documentation`HelpLookup[
       "paclet:Obtuse/ref/RadialBasisFunction"], "\<\"ShepardPower\"\>":>
       Documentation`HelpLookup[
       "paclet:Obtuse/ref/ShepardPower"], "\<\"SmoothenDistance\"\>":>
       Documentation`HelpLookup[
       "paclet:Obtuse/ref/SmoothenDistance"], "\<\"Type\"\>":>
       Documentation`HelpLookup["paclet:ref/Type"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"More About \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"Obtuse Package\"\>":>
       Documentation`HelpLookup[
       "paclet:Obtuse/guide/ObtusePackage"], \
"\<\"http://www.familydahl.se/mathematica\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL["http://www.familydahl.se/mathematica/"], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"URL \[RightGuillemet]\"\>",
        StripOnInput->
         False], {"\<\"Obtuse/tutorial/Scattered point interpolation\"\>":>
       None, "\<\"Copy Mathematica url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["Obtuse/tutorial/Scattered point interpolation"]}, Visible -> 
            False]]; SelectionMove[
         DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://www.familydahl.se/mathematica/Obtuse/tutorial/\
Scattered point interpolation.html"], StandardForm]], "Input", 
              TextClipboardType -> "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web url\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://www.familydahl.se/mathematica/", 
             "Obtuse/tutorial/Scattered point interpolation", ".html"]], 
           None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell["Scattered Point Interpolation", "Title",
 CellID->509267359],

Cell[TextData[{
 "Interpolation in one dimension is a very common operation, and is \
implemented in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", both for equal-distance points and for scattered points. Interpolation in \
two or more dimensions requires tabular data, with the function argument \
values on a grid. (Scattered-point interpolation of the Delaunay type \
(\"Voronoi region interpolation\") is integrated internally in the ListPlot3D \
command in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 7.) It is quite common to have data for scattered points in several \
dimensions, and quite useful to have some kind of interpolation defined."
}], "Text",
 CellID->1534169418],

Cell["\<\
The Obtuse package adds four interpolation methods to the Interpolation \
command:\
\>", "Text",
 CellID->3244020],

Cell[BoxData[GridBox[{
   {
    ButtonBox[
     RowBox[{"Interpolation", "[", 
      StyleBox[
       RowBox[{"funcvaluelist", ",", 
        RowBox[{"Method", "\[Rule]", "\"\<Delaunay\>\""}], ",", 
        RowBox[{"(", "options", ")"}]}], "TI",
       FontSlant->"Italic"], "]"}],
     BaseStyle->"Link",
     ButtonData->"paclet:Obtuse/ref/InterpolationMethodDelaunay"], Cell[
    TextData[{
     "interpolation utilizing ",
     ButtonBox["Delaunay triangulation ",
      BaseStyle->"Link",
      ButtonData->"paclet:ComputationalGeometry/ref/DelaunayTriangulation"],
     "where ",
     StyleBox["funcvaluelist", "TI",
      FontSlant->"Italic"],
     " is a list of 2D scattered control points together with the function \
values in these points."
    }], "TableText"]},
   {
    ButtonBox[
     RowBox[{"Interpolation", "[", 
      StyleBox[
       RowBox[{"funcvaluelist", ",", 
        RowBox[{"Method", "\[Rule]", "\"\<Voronoi\>\""}], ",", 
        RowBox[{"(", "options", ")"}]}], "TI",
       FontSlant->"Italic"], "]"}],
     BaseStyle->"Link",
     ButtonData->"paclet:Obtuse/ref/InterpolationMethodVoronoi"], Cell[
    TextData[{
     "interpolation, using Voronoi triangulation, where ",
     StyleBox["funcvaluelist", "TI",
      FontSlant->"Italic"],
     " is a list of scattered control points together with the function \
values in these points."
    }], "TableText"]},
   {
    ButtonBox[
     RowBox[{"Interpolation", "[", 
      StyleBox[
       RowBox[{"funcvaluelist", ",", 
        RowBox[{"Method", "\[Rule]", "\"\<ObtuseAngle\>\""}], ",", 
        RowBox[{"(", "options", ")"}]}], "TI",
       FontSlant->"Italic"], "]"}],
     BaseStyle->"Link",
     ButtonData->"paclet:Obtuse/ref/InterpolationMethodObtuseAngle"], Cell[
    TextData[{
     "interpolation, using obtuse angle shadowing networks, where ",
     StyleBox["funcvaluelist", "TI",
      FontSlant->"Italic"],
     " is a list of scattered control points together with the function \
values in these points."
    }], "TableText"]},
   {
    ButtonBox[
     RowBox[{"Interpolation", "[", 
      StyleBox[
       RowBox[{"funcvaluelist", ",", 
        RowBox[{"Method", "\[Rule]", "\"\<RBF\>\""}], ",", 
        RowBox[{"(", "options", ")"}]}], "TI",
       FontSlant->"Italic"], "]"}],
     BaseStyle->"Link",
     ButtonData->"paclet:Obtuse/ref/InterpolationMethodRBF"], Cell[TextData[{
     "interpolation utilizing ",
     ButtonBox["radial basis functions",
      BaseStyle->"Hyperlink",
      ButtonData->{
        URL["http://en.wikipedia.org/wiki/Radial_basis_function"], None}],
     " where ",
     StyleBox["funcvaluelist", "TI",
      FontSlant->"Italic"],
     " is a list of scattered control points together with the function \
values in these points."
    }], "TableText"]},
   {
    ButtonBox[
     RowBox[{"Interpolation", "[", 
      StyleBox[
       RowBox[{"funcvaluelist", ",", 
        RowBox[{"Method", "\[Rule]", "\"\<Shepard\>\""}], ",", 
        RowBox[{"(", "options", ")"}]}], "TI",
       FontSlant->"Italic"], "]"}],
     BaseStyle->"Link",
     ButtonData->"paclet:Obtuse/ref/InterpolationMethodShepard"], Cell[
    TextData[{
     "interpolation according to ",
     ButtonBox["Shepard's method",
      BaseStyle->"Hyperlink",
      ButtonData->{
        URL["http://en.wikipedia.org/wiki/Inverse_distance_weighting"], None}],
     ", where ",
     StyleBox["funcvaluelist", "TI",
      FontSlant->"Italic"],
     " is a list of scattered control points together with the function \
values in these points."
    }], "TableText"]}
  }]], "DefinitionBox",
 CellID->2096742444],

Cell["Interpolation methods implemented in the Obtuse package.", "Caption",
 CellID->1891092685],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["Delaunay interpolation",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Obtuse/ref/InterpolationMethodDelaunay"]], "Subsubsection",
 CellID->44385959],

Cell[TextData[{
 "The Delaunay interpolation method to the Interpolation command is a \
coordinate-based interpolation method, here allowing only 2D-points. The \
method is based on ",
 ButtonBox["Delaunay",
  BaseStyle->"Link",
  ButtonData->"paclet:ComputationalGeometry/ref/DelaunayTriangulation"],
 " triangulation (from the ",
 ButtonBox["Computational Geometry Package",
  BaseStyle->"Link",
  ButtonData->
   "paclet:ComputationalGeometry/guide/ComputationalGeometryPackage"],
 ") of the control points and triangular interpolation inside the Delaunay \
triangles. The ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " routines were initially written by Tom Wickham-Jones and modified by \
Daniel Huber (Switzerland) and Frank Iannarilli. I have modified them \
further, by introducing an extrapolation method to avoid error messages for \
extrapolated values, and by changing the calls to the routine to agree with \
the Interpolation command. "
}], "Text",
 CellID->581166958],

Cell["\<\
The other four implemented methods are distance-based, and they interact with \
the control points via a distance matrix and a distance function. The \
distance-based interpolation methods could be applied to a large set of \
geometries, including multi-dimensional, periodic and regions with cuts, as \
long as the relevant distance function is specified.\
\>", "Text",
 CellID->29086272]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["Voronoi interpolation",
 BaseStyle->"Link",
 ButtonData->"paclet:Obtuse/ref/InterpolationMethodVoronoi"]], "Subsubsection",
 CellID->97639925],

Cell[TextData[{
 "The Voronoi interpolation method to the Interpolation command returns the \
function value of the nearest control point from the interpolation point. If \
two control points are at the same minimum distance, the function value of \
the first is returned. The function is thus constant in regions. The function \
values could thus be almost any kind of valid ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " statements. This function is useful if you want to construct answers to \
questions like \"What is the name and address of the closest restaurant\", \
but could also be useful in machine learning. "
}], "Text",
 CellID->728254919]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["Shepard interpolation",
 BaseStyle->"Link",
 ButtonData->"paclet:Obtuse/ref/InterpolationMethodShepard"]], "Subsubsection",
 CellID->340466154],

Cell[TextData[{
 "The Shepard interpolation is included here just for comparison, and should \
not be used for serious work without careful consideration. The Shepard \
interpolation is using the distance to a control point, raised to the inverse \
",
 Cell[BoxData[
  ButtonBox["ShepardPower",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/ShepardPower"]],
  GridBoxOptions->{
  GridBoxDividers->{
   "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
    "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}}}],
 " parameter, as a weight for the function value in the control point. The \
weights are then normalized to have 1 as their sum. If the value of ",
 Cell[BoxData[
  ButtonBox["ShepardPower",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/ShepardPower"]],
  GridBoxOptions->{
  GridBoxDividers->{
   "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
    "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}}}],
 " is less than the dimension of the point set plus one, the distant points \
will dominate the interpolated value, and this makes it difficult to use the \
method if the dimensionality of the control point set is high. However, what \
is important here is the real dimensionality of the control point set, which \
might be lower than the dimensionality of the embedding coordinate system (if \
we have such a system). The method gives nice linear interpolation between \
two points if ",
 Cell[BoxData[
  ButtonBox["ShepardPower",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/ShepardPower"]],
  GridBoxOptions->{
  GridBoxDividers->{
   "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
    "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}}}],
 " is one, but only for this value. Thus we might conclude that the Shepard \
interpolation is working best for interpolation in one-dimensional data sets. \
The Shepard interpolation method does not require any length scale parameter."
}], "Text",
 CellID->268066077]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["RBF interpolation",
 BaseStyle->"Link",
 ButtonData->"paclet:Obtuse/ref/InterpolationMethodRBF"]], "Subsubsection",
 CellID->108006383],

Cell["\<\
The RBF interpolation can be seen as an improvement of the Shepard \
interpolation. We let each control point be the center for one radial base \
function (a function where the value is determined by the distance to the \
center), and form a linear combination of all these functions. We choose the \
weights in this linear combination in such a way that it takes the function \
values in the control points. Since we have the same number of weight as we \
have function values, we should in general have a well-specified equation \
system to solve. The radial base functions could be chosen in various ways, \
but a fundamental property should be that they are finite but non-zero at \
origin and smoothly decreasing or increasing outwards. In the definition of \
the radial base function there is as a rule a length scale parameter \
included, so if the length scale vary strongly there might be a problem to \
choose one single appropriate value. For smooth functions the accuracy of the \
RBF interpolation can be amazingly good.  \
\>", "Text",
 CellID->502840966],

Cell[TextData[{
 "The RBF interpolation method is translated from MATLAB routines described \
by William Press in the course ",
 ButtonBox["\"Computational Statistics with Application to Bioinformatics\"",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://nr.com/CS395T/lectures2009/2009_ 24_MultidimenInterp.pdf"], 
    None}],
 "."
}], "Text",
 CellID->600371750]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["ObtuseAngle interpolation",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Obtuse/ref/InterpolationMethodObtuseAngle"]], "Subsubsection",
 CellID->818049428],

Cell["\<\
The ObtuseAngle interpolation is based on the ObtuseAngle connection list. \
One starts with a weight function for each control point that is one \
everywhere. Then, if there is a connection from control point 1 to control \
point 2, the weight function for control point two is multiplied by a \
\"shadow\" function, varying only in a direction parallel to the connection. \
In the case that InterpolationOrder is one, this function is zero from point \
1 and beyond, one from point 2 and beyond, and increases linearly from point \
1 to point 2. In this way, the weight function will be zero in all points \
shadowed by point 1 from point 2, according to the Obtuse Angle shadowing \
rule. The same operation is applied to all connections. Then the weight for \
all control point are normalized to have 1 as their sum at the interpolation \
point. For InterpolationOrder equal to one, we always know that the \
interpolation coefficients are in the closed interval 0 to 1. For some \
applications this is essential.\
\>", "Text",
 CellID->394262481],

Cell["\<\
In the case that InterpolationOrder is two, the shadow function is chosen in \
such a way that it has a continuous derivative. At the same time it loses its \
ability to shadow points behind the from-point in the connections, and we \
have to introduce a second-level shadowing function for the second-level \
connections to zero the weight function for more distant points. If \
InterpolationOrder is three, the shadow function has second order continuous \
derivative, both the first-level, second-level and the third-level \
connections are used.\
\>", "Text",
 CellID->36684362],

Cell["\<\
As long as the options CutoffRadius and SmoothenDistance are not set, the \
ObtuseAngle interpolation method is scale-independent and does not need any \
scale parameter.\
\>", "Text",
 CellID->454249583],

Cell["\<\
The ObtuseAngle interpolation method is my invention, and the method has some \
qualities that should make it into an interesting alternative to RBF \
interpolation in some applications.\
\>", "Text",
 CellID->166741]
}, Open  ]],

Cell[CellGroupData[{

Cell["General", "Subsubsection",
 CellID->83692607],

Cell["\<\
The function values for the control points could be any kind of mathematical \
objects that are such that they can be linearly combined.\
\>", "Text",
 CellID->506437463],

Cell["\<\
The Delaunay and ObtuseAngle interpolation methods are typically local \
interpolation methods, where the function value in one control point often \
influence only the local neighborhood. The RBF interpolation is more of a \
global interpolation method, where the function value in one control point \
might influence the interpolated value almost everywhere.\
\>", "Text",
 CellID->640027072],

Cell[TextData[{
 "See an ",
 ButtonBox["Interpolation interactive demo",
  BaseStyle->"Link",
  ButtonData->"paclet:Obtuse/tutorial/Interpolation interactive demo"],
 ", to see the influence of the function value in one control point for the \
different methods."
}], "Text",
 CellID->70611174],

Cell[BoxData[GridBox[{
   {Cell["option name", "TableHeader"], Cell["default value", "TableHeader"], 
    " "},
   {
    ButtonBox["ConnectionsToExclude",
     BaseStyle->"Link",
     ButtonData->"paclet:Obtuse/ref/ConnectionsToExclude"], 
    RowBox[{"{", "}"}], Cell["\<\
Connections to exclude in the evaluation. (For method \"ObtuseAngle\".)\
\>", "TableText"]},
   {
    ButtonBox["CutoffRadius",
     BaseStyle->"Link",
     ButtonData->"paclet:Obtuse/ref/CutoffRadius"], 
    ButtonBox["Infinity",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/Infinity"], Cell[TextData[{
     "Points separated by twice the ",
     Cell[BoxData[
      ButtonBox["CutoffRadius",
       BaseStyle->"Link",
       ButtonData->"paclet:Obtuse/ref/CutoffRadius"]], "InlineFormula"],
     " or more are not connected. ",
     "(For method \"ObtuseAngle\".)"
    }], "TableText"]},
   {
    ButtonBox["CutoffValue",
     BaseStyle->"Link",
     ButtonData->"paclet:Obtuse/ref/CutoffValue"], "0.0`", Cell[TextData[{
     "The interpolated value in points more distant than ",
     Cell[BoxData[
      ButtonBox["CutoffRadius",
       BaseStyle->"Link",
       ButtonData->"paclet:Obtuse/ref/CutoffRadius"]], "InlineFormula"],
     " from all control points will be this value. ",
     "(For method \"ObtuseAngle\".)"
    }], "TableText"]},
   {
    ButtonBox["DistanceFunction",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/DistanceFunction"], 
    ButtonBox["Automatic",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/Automatic"], Cell["\<\
Distance function to use in calculation of the distance matrix and the \
calculation of the distance from the interpolation point to the control \
points. Note, that the function here is expected to return the square of the \
distance. (For method \"ObtuseAngle\", \"RBF\" and \"Shepard\")\
\>", "TableText"]},
   {
    ButtonBox["InterpolationOrder",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/InterpolationOrder"], "1", Cell["\<\
The order of interpolation to use. (For native interpolation and for method \
\"ObtuseAngle\".)\
\>", "TableText"]},
   {
    ButtonBox["NeighborLevel",
     BaseStyle->"Link",
     ButtonData->"paclet:Obtuse/ref/NeighborLevel"], "1", Cell[TextData[{
     "All connected points for lower values of ",
     Cell[BoxData[
      ButtonBox["NeighborLevel",
       BaseStyle->"Link",
       ButtonData->"paclet:Obtuse/ref/NeighborLevel"]], "InlineFormula"],
     " are excluded in the evaluation. ",
     "(For method \"ObtuseAngle\".)"
    }], "TableText"]},
   {
    ButtonBox["RadialBasisFunction",
     BaseStyle->"Link",
     ButtonData->"paclet:Obtuse/ref/RadialBasisFunction"], 
    ButtonBox["Automatic",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/Automatic"], Cell["\<\
Radial Basis Function required by the RBF interpolation method. (For method \
\"RBF\".)\
\>", "TableText"]},
   {
    ButtonBox["ShepardPower",
     BaseStyle->"Link",
     ButtonData->"paclet:Obtuse/ref/ShepardPower"], "6", Cell["\<\
Power parameter to use in the weight function in the Shepard method. (For \
method \"Shepard\".)\
\>", "TableText"]},
   {
    ButtonBox["SmoothenDistance",
     BaseStyle->"Link",
     ButtonData->"paclet:Obtuse/ref/SmoothenDistance"], "0.", Cell[TextData[
    Cell[BoxData[Cell[TextData[{
      "Points separated by ",
      Cell[BoxData[
       ButtonBox["SmoothenDistance",
        BaseStyle->"Link",
        ButtonData->"paclet:Obtuse/ref/SmoothenDistance"]], "InlineFormula"],
      " or less are not connected. ",
      "(For method \"ObtuseAngle\".)"
     }], "TableText",
      FontSize->10]],
     Editable->True,
     GridBoxOptions->{
     GridBoxBackground->{
      "Columns" -> {{None}}, "ColumnsIndexed" -> {}, 
       "Rows" -> {
        None, None, None, None, None, None, None, None, None, None, None, 
         None, None, None, None, None, None, None, None, None, None, None, {
         None}}, "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Rows" -> {{
         True, True, True, True, True, True, True, True, True, True, True, 
          True, True, True, True, True, True, True, True, True, True, True, 
          True, True}}}}]], "TableText"]},
   {
    ButtonBox["Type",
     BaseStyle->"Link",
     ButtonData->"paclet:Obtuse/ref/Type"], 
    ButtonBox["Directed",
     BaseStyle->"Link",
     ButtonData->"paclet:Combinatorica/ref/Directed"], Cell[TextData[{
     "The connection graph can be ",
     Cell[BoxData[
      ButtonBox["Directed",
       BaseStyle->"Link",
       ButtonData->"paclet:Combinatorica/ref/Directed"]], "InlineFormula"],
     " or ",
     Cell[BoxData[
      ButtonBox["Undirected",
       BaseStyle->"Link",
       ButtonData->"paclet:Combinatorica/ref/Undirected"]], "InlineFormula"],
     ". ",
     "(For method \"ObtuseAngle\".)"
    }], "TableText"]}
  }]], "DefinitionBox3Col",
 GridBoxOptions->{
 GridBoxDividers->{
  "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
   "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}}},
 CellID->2017],

Cell["Options for Interpolation ", "Text",
 CellID->59754064],

Cell[BoxData[GridBox[{
   {
    ButtonBox[
     RowBox[{"InterpolationCoefficients", "[", 
      StyleBox[
       RowBox[{
       "interpolationpoint", ",", "controlpointlist", ",", "distmat", ",", 
        "conlistslist", ",", "interpolationorder", ",", 
        RowBox[{"(", "options", ")"}]}], "TI",
       FontSlant->"Italic"], "]"}],
     BaseStyle->"Link",
     ButtonData->"paclet:Obtuse/ref/InterpolationCoefficients"], Cell[
    TextData[{
     "gives a vector of interpolation coefficients for the point ",
     StyleBox["interpolationpoint", "TI",
      FontSlant->"Italic"],
     " for ",
     Cell[BoxData[
      RowBox[{"Method", "\[Rule]", "\"\<ObtuseAngle\>\""}]]],
     "."
    }], "TableText"]}
  }]], "DefinitionBox",
 CellID->77984384],

Cell[TextData[{
 StyleBox[ButtonBox["InterpolationCoefficients",
  BaseStyle->"Link",
  ButtonData->"paclet:Obtuse/ref/InterpolationCoefficients"],
  FontSize->11],
 StyleBox[" is a helper function for ",
  FontSize->11],
 Cell[BoxData[
  ButtonBox[
   RowBox[{"Method", "\[Rule]", "\"\<ObtuseAngle\>\""}],
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/InterpolationMethodObtuseAngle"]],
  FontFamily->"Courier New",
  FontSize->11],
 "."
}], "Caption",
 CellID->106274544]
}, Open  ]],

Cell[CellGroupData[{

Cell["RELATED TUTORIALS", "RelatedTutorialsSection",
 CellID->415694126],

Cell[TextData[ButtonBox["Obtuse Angle Shadowing Networks",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Obtuse/tutorial/Obtuse Angle Shadowing Networks"]], \
"RelatedTutorials",
 CellID->806871991],

Cell[TextData[ButtonBox["Interpolation interactive demo",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Obtuse/tutorial/Interpolation interactive demo"]], \
"RelatedTutorials",
 CellID->96903843]
}, Open  ]],

Cell[CellGroupData[{

Cell["MORE ABOUT", "TutorialMoreAboutSection",
 CellID->23220180],

Cell[TextData[{
 "Copyright Ingolf Dahl 2010, ingolf.dahl@telia.com, ",
 ButtonBox["http://www.familydahl.se/mathematica",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.familydahl.se/mathematica"], None}]
}], "TutorialMoreAbout",
 CellID->78426474]
}, Open  ]]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"Scattered Point Interpolation - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, 
  "Metadata" -> {
   "built" -> "{2010, 5, 20, 23, 19, 55.6494227}", "context" -> "Obtuse`", 
    "keywords" -> {
     "Obtuse Angle Shadowing", "Obtuse Angle", "Shadowing", 
      "Scattered Points", "n-dimensional", "Multidimensional", 
      "Interpolation", "Obtuse Angle Interpolation", "RBF", 
      "Radial Basis Function", "Shepard", "Voronoi", "Delaunay", 
      "distance-based"}, "index" -> True, "label" -> "Obtuse Tutorial", 
    "language" -> "en", "paclet" -> "Obtuse", "status" -> "None", "summary" -> 
    "Interpolation in one dimension is a very common operation, and is \
implemented in Mathematica, both for equal-distance points and for scattered \
points. Interpolation in two or more dimensions requires tabular data, with \
the function argument values on a grid. (Scattered-point interpolation of the \
Delaunay type (\"Voronoi region interpolation\") is integrated internally in \
the ListPlot3D command in Mathematica 7.) It is quite common to have data for \
scattered points in several dimensions, and quite useful to have some kind of \
interpolation defined. The Obtuse package adds four interpolation methods to \
the Interpolation command: Interpolation methods implemented in the Obtuse \
package.", "synonyms" -> {}, "title" -> "Scattered Point Interpolation", 
    "type" -> "Tutorial", "uri" -> 
    "Obtuse/tutorial/Scattered point interpolation"}, "SearchTextTranslated" -> 
  ""},
FrontEndVersion->"7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> FrontEnd`FileName[{"Wolfram"}, "Reference.nb"]]], 
   Cell[
    StyleData["Input"], CellContext -> "Global`"], 
   Cell[
    StyleData["Output"], CellContext -> "Global`"], 
   Cell[
    StyleData["TutorialMoreAboutSection"], 
    CellGroupingRules -> {"SectionGrouping", 30}], 
   Cell[
    StyleData["RelatedTutorialsSection"], 
    CellGroupingRules -> {"SectionGrouping", 30}], 
   Cell[
    StyleData["TutorialRelatedLinksSection"], 
    CellGroupingRules -> {"SectionGrouping", 30}]}, Visible -> False, 
  FrontEndVersion -> "7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
   StyleDefinitions -> "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[610, 21, 78, 1, 3, "TutorialColorBar"],
Cell[691, 24, 209, 6, 19, "LinkTrail"],
Cell[903, 32, 5540, 120, 46, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[6468, 156, 66, 1, 51, "Title",
 CellID->509267359],
Cell[6537, 159, 702, 15, 130, "Text",
 CellID->1534169418],
Cell[7242, 176, 124, 4, 30, "Text",
 CellID->3244020],
Cell[7369, 182, 3594, 100, 302, "DefinitionBox",
 CellID->2096742444],
Cell[10966, 284, 96, 1, 31, "Caption",
 CellID->1891092685],
Cell[CellGroupData[{
Cell[11087, 289, 172, 4, 30, "Subsubsection",
 CellID->44385959],
Cell[11262, 295, 990, 22, 170, "Text",
 CellID->581166958],
Cell[12255, 319, 399, 7, 70, "Text",
 CellID->29086272]
}, Open  ]],
Cell[CellGroupData[{
Cell[12691, 331, 167, 3, 70, "Subsubsection",
 CellID->97639925],
Cell[12861, 336, 661, 12, 70, "Text",
 CellID->728254919]
}, Open  ]],
Cell[CellGroupData[{
Cell[13559, 353, 168, 3, 70, "Subsubsection",
 CellID->340466154],
Cell[13730, 358, 1991, 42, 70, "Text",
 CellID->268066077]
}, Open  ]],
Cell[CellGroupData[{
Cell[15758, 405, 160, 3, 70, "Subsubsection",
 CellID->108006383],
Cell[15921, 410, 1079, 16, 70, "Text",
 CellID->502840966],
Cell[17003, 428, 373, 10, 70, "Text",
 CellID->600371750]
}, Open  ]],
Cell[CellGroupData[{
Cell[17413, 443, 179, 4, 70, "Subsubsection",
 CellID->818049428],
Cell[17595, 449, 1061, 16, 70, "Text",
 CellID->394262481],
Cell[18659, 467, 592, 10, 70, "Text",
 CellID->36684362],
Cell[19254, 479, 214, 5, 70, "Text",
 CellID->454249583],
Cell[19471, 486, 227, 5, 70, "Text",
 CellID->166741]
}, Open  ]],
Cell[CellGroupData[{
Cell[19735, 496, 51, 1, 70, "Subsubsection",
 CellID->83692607],
Cell[19789, 499, 180, 4, 70, "Text",
 CellID->506437463],
Cell[19972, 505, 404, 7, 70, "Text",
 CellID->640027072],
Cell[20379, 514, 294, 8, 70, "Text",
 CellID->70611174],
Cell[20676, 524, 5020, 137, 70, "DefinitionBox3Col",
 CellID->2017],
Cell[25699, 663, 61, 1, 70, "Text",
 CellID->59754064],
Cell[25763, 666, 755, 22, 70, "DefinitionBox",
 CellID->77984384],
Cell[26521, 690, 483, 16, 70, "Caption",
 CellID->106274544]
}, Open  ]],
Cell[CellGroupData[{
Cell[27041, 711, 72, 1, 70, "RelatedTutorialsSection",
 CellID->415694126],
Cell[27116, 714, 196, 5, 70, "RelatedTutorials",
 CellID->806871991],
Cell[27315, 721, 193, 5, 70, "RelatedTutorials",
 CellID->96903843]
}, Open  ]],
Cell[CellGroupData[{
Cell[27545, 731, 65, 1, 70, "TutorialMoreAboutSection",
 CellID->23220180],
Cell[27613, 734, 264, 7, 70, "TutorialMoreAbout",
 CellID->78426474]
}, Open  ]]
}, Open  ]],
Cell[27904, 745, 23, 0, 70, "FooterCell"]
}
]
*)

(* End of internal cache information *)

